package com.huaxia.hx_sell_commission.config.sso;

import com.cfld.sso.client.servlet.*;
import lombok.extern.log4j.Log4j;

import javax.servlet.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.MalformedURLException;
import java.util.HashMap;
import java.util.Map;

/**
 * @author YanChengLong
 * @date 2019/7/9
 * @desc 重写 CheckLoginFilter包方法
 */
@Log4j
public class CheckLoginFilterConfig implements Filter {

    private CheckLoginBeanConfig checkLoginBean = new CheckLoginBeanConfig();

    public CheckLoginFilterConfig() {
    }

    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {

        HttpServletRequest request = (HttpServletRequest) servletRequest;
        HttpServletResponse response = (HttpServletResponse) servletResponse;
        String logon_page;
        if (SsoClientUtils.IS_FORBIDDEN) {
            String request_uri = ((HttpServletRequest) request).getRequestURI();
            String ctxPath = ((HttpServletRequest) request).getContextPath();
            logon_page = request_uri.substring(ctxPath.length());
            if (!logon_page.contains("/updateIsForbidden.axd") && !logon_page.contains("/cfld_sso_Quartz_FileUpdate.axd") && !logon_page.contains("/cfld_sso_Quartz_KeyUpdate.axd")) {
                this.RedirectTipUrl(response);
                return;
            }
        }
        request.getHeader("cookie");
        CookiesUtil cookiesUtil = new CookiesUtil((HttpServletRequest) request, response);
        int returnValue = 0;
        String tempurl;
        if (SsoClientUtils.AD_OR_DB_MODE.equals("SSO")) {
            String[] returnUrl = new String[1];
            if (SsoClientUtils.TOOKEN_SAVE_MODE.equals("head")) {
                request = new SSOHttpServletRequest((HttpServletRequest) request, new HashMap());
                returnValue = this.getCheckLoginBean().processLogin((HttpServletRequest) request, response, true);
            } else if (SsoClientUtils.TOOKEN_SAVE_MODE.equals("attr")) {
                returnValue = this.getCheckLoginBean().processLogin((HttpServletRequest) request, response, false);
            }

            if (returnValue == 6) {
                filterChain.doFilter((ServletRequest) request, response);
            } else if (returnValue == 1) {
                this.exeCheckPoint("SSO", "success", cookiesUtil);
                filterChain.doFilter((ServletRequest) request, response);
            } else if (returnValue == 7) {
                this.exeCheckPoint("SSO", "for_value", cookiesUtil);
                tempurl = ((HttpServletRequest) request).getServletPath() + "?" + ((HttpServletRequest) request).getQueryString();
                RequestDispatcher rdsp = ((HttpServletRequest) request).getRequestDispatcher(tempurl);
                rdsp.forward((ServletRequest) request, response);
            } else if (returnValue == 4 || returnValue == 3 || returnValue == 5) {
                this.exeCheckPoint("SSO", "false", cookiesUtil);
            }
        } else if (SsoClientUtils.AD_OR_DB_MODE.equals("AD") || SsoClientUtils.AD_OR_DB_MODE.equals("DB")) {
            if (SsoClientUtils.TOOKEN_SAVE_MODE.equals("head")) {
                request = new SSOHttpServletRequest((HttpServletRequest) request, new HashMap());
                returnValue = this.getCheckLoginBean().localModelFilter((HttpServletRequest) request, response, true);
            } else if (SsoClientUtils.TOOKEN_SAVE_MODE.equals("attr")) {
                returnValue = this.getCheckLoginBean().localModelFilter((HttpServletRequest) request, response, false);
            }

            logon_page = SsoClientUtils.LOGON_URL;
            tempurl = SsoClientUtils.DEFAULT_URL;
            String strReturnUrl = ((HttpServletRequest) request).getParameter("ReturnUrl");
            if (strReturnUrl == null || strReturnUrl.equals("")) {
                strReturnUrl = ((HttpServletRequest) request).getRequestURL().toString();
                if (((HttpServletRequest) request).getQueryString() != null && !((HttpServletRequest) request).getQueryString().equals("")) {
                    strReturnUrl = strReturnUrl + "?" + ((HttpServletRequest) request).getQueryString();
                }
            }

            if (logon_page == null || tempurl == null) {
                log.error("没有指定登录页面或主页！");
            }

            if (returnValue == 6) {
                filterChain.doFilter((ServletRequest) request, response);
            } else if (returnValue == 1) {
                this.exeCheckPoint("AD", "success", cookiesUtil);
                filterChain.doFilter((ServletRequest) request, response);
            } else {
                //String tempurl;
                if (returnValue == 7) {
                    this.exeCheckPoint("AD", "for_value", cookiesUtil);
                    tempurl = ((HttpServletRequest) request).getServletPath() + "?" + ((HttpServletRequest) request).getQueryString();
                    RequestDispatcher rdsp = ((HttpServletRequest) request).getRequestDispatcher(tempurl);
                    rdsp.forward((ServletRequest) request, response);
                } else {
                    this.exeCheckPoint("AD", "false", cookiesUtil);
                    tempurl = ((HttpServletRequest) request).getContextPath() + logon_page + "?ReturnUrl=" + URLTool.encodeURL(strReturnUrl);
                    response.sendRedirect(tempurl);
                }
            }
        }

    }

    private boolean exeCheckPoint(String Config, String CheckPoint, CookiesUtil cookiesUtil) {
        //System.out.print(SsoClientUtils.CHECKJOB_LIST.size());
        for (int i = 0; i < SsoClientUtils.CHECKJOB_LIST.size(); ++i) {
            Map map = (Map) SsoClientUtils.CHECKJOB_LIST.get(i);
            if (map.get("UserConfig").toString().contains(Config) && map.get("checkpoint").toString().contains(CheckPoint)) {
                if (map.get("operator").toString().equalsIgnoreCase("assign")) {
                    cookiesUtil.assignCookies(map.get("cookies").toString(), map.get("domain").toString());
                } else if (map.get("operator").toString().equalsIgnoreCase("delete")) {
                    cookiesUtil.deleteCookies(map.get("cookies").toString(), map.get("domain").toString());
                } else if (map.get("operator").toString().equalsIgnoreCase("clear")) {
                    cookiesUtil.setCookiesValue(map.get("cookies").toString(), map.get("domain").toString(), "");
                }
            }
        }

        return false;
    }

    public void destroy() {
    }

    public void init(FilterConfig filterConfig) throws ServletException {
        String containerType = filterConfig.getInitParameter("containerType");
        String configLocation;
        if (containerType != null && containerType.toUpperCase().contains("WEBLOGIC")) {
            configLocation = "";

            try {
                configLocation = filterConfig.getServletContext().getResource("/").getPath();
                configLocation = this.getClass().getClassLoader().getResource("/").getPath();
                configLocation = configLocation.substring(0, configLocation.indexOf("classes"));
                configLocation = configLocation.substring(0, configLocation.indexOf("WEB-INF"));
                SsoClientUtils.CONTENT_PAHT = configLocation;
            } catch (MalformedURLException var6) {
                log.error(var6);
            }
        } else {
            SsoClientUtils.CONTENT_PAHT = filterConfig.getServletContext().getRealPath("/");
        }

        configLocation = filterConfig.getInitParameter("configLocation");
        if (configLocation != null && configLocation.trim().length() > 0) {
            SsoClientUtils.CONFIG_LOCATION = configLocation;
        }

        this.getCheckLoginBean().init();

        try {
            ConnnectDbTools bean = new ConnnectDbTools();
            SsoClientUtils.ACCOUNT_POLICY = bean.getDbPasswordAccountPolicy();
        } catch (Exception var5) {
            log.error(var5);
        }

    }

    protected CheckLoginBeanConfig getCheckLoginBean() {
        return this.checkLoginBean;
    }

    public void RedirectTipUrl(HttpServletResponse response) {
        response.setContentType("text/html");
        response.setCharacterEncoding("utf-8");
        PrintWriter out = null;

        try {
            out = response.getWriter();
        } catch (IOException var4) {
            var4.printStackTrace();
        }

        out.println("<html xmlns='http://www.w3.org/1999/xhtml'>");
        out.println("<head><title>该系统被禁用，无法访问</title>");
        out.println("<meta http-equiv='Content-Type' content='text/html'; charset='utf-8' />");
        out.println("<style type='text/css'>");
        out.println(".jumpStyle { text-align: center; font-weight: bold; font-size: 44px; color: #e9e8e8;}");
        out.println(".copyrightStyle { text-align: center; font-size: 18px; color: #e9e8e8; margin-top:70px;}");
        out.println("</style></head>");
        out.println("<body><form id='form1'>");
        out.println("<div class='jumpStyle' style='color:#000; padding-top:100px;font-size:20px;'>系统被禁用，无法访问！</div>");
        out.println("<div class='copyrightStyle'>华夏幸福基业\t</div>");
        out.println("</form></body></html>");
        out.close();
    }
}
