package com.huaxia.hx_sell_commission.config.sso;

import com.cfld.sso.client.servlet.ConfigUtil;
import com.cfld.sso.client.servlet.DES3Tools;
import com.cfld.sso.client.servlet.SsoClientUtils;
import lombok.extern.log4j.Log4j;
import org.apache.commons.io.FileUtils;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;
import org.springframework.stereotype.Component;
import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import java.io.File;
import java.io.IOException;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

/**
 * @author YanChengLong
 * @date 2019/7/9
 * @desc 重写 ConfigUtil 包方法
 */
@Component
@Log4j
public class ConfigUtilConfig extends ConfigUtil {

    private static long allowAccessTime = 0L;
//    //业态ID
//    @Value(value = "${project.sso.setting.file.name}")
//    private String url;

    protected void loadConfig() {
        Calendar cal = Calendar.getInstance();
        long currentTime = cal.getTimeInMillis();
        if (currentTime < allowAccessTime) {
            return;
        }
        synchronized (this) {
            if (currentTime < allowAccessTime) {
                return;
            }
            cal.add(12, 5);
            allowAccessTime = cal.getTimeInMillis();
        }
        File file = new File(SsoClientUtils.CONTENT_PAHT + SsoClientUtils.CONFIG_LOCATION);
        if (!file.exists()) {
            try {
                //file = ResourceUtils.getFile(SsoClientUtils.CONFIG_LOCATION);
                Resource res = new ClassPathResource(SsoClientUtils.CONFIG_LOCATION);
                FileUtils.copyInputStreamToFile(res.getInputStream(),file);
            } catch (IOException e) {
                throw new RuntimeException("File do not exist - File Name:" + SsoClientUtils.CONFIG_LOCATION);
            }
        }


//        //String fileTemplatepath = Thread.currentThread().getContextClassLoader().getResource("setting.xml").getPath();


//        File file = null;
//        try {
//            System.out.println("SSO获取配置文件路径" + SsoClientUtils.CONFIG_LOCATION);
//            log.warn("SSO获取配置文件路径" + SsoClientUtils.CONFIG_LOCATION);
//            file = ResourceUtils.getFile(SsoClientUtils.CONFIG_LOCATION);
//        } catch (FileNotFoundException e) {
//            e.printStackTrace();
//            throw new RuntimeException("File do not exist - File Name:" + SsoClientUtils.CONFIG_LOCATION);
//        }
//        if (!file.exists()) {
//            throw new RuntimeException("File do not exist - File Name:" + SsoClientUtils.CONFIG_LOCATION);
//        }
        long lasttime = file.lastModified();
        if (lasttime > SsoClientUtils.SETTING_LAST_UPDATETIME) {
            parseFile(file);
            SsoClientUtils.SETTING_LAST_UPDATETIME = lasttime;
        }
    }

    protected void parseFile(File file) {
        try {
            DocumentBuilder dombuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
            parseDocument(dombuilder.parse(file));
        } catch (SAXException e) {
            log.error(e);
        } catch (IOException e) {
            log.error(e);
        } catch (ParserConfigurationException e) {
            log.error(e);
        }
    }

    protected void parseDocument(Document doc) {
        Element root = doc.getDocumentElement();

        NodeList connectionString = root.getElementsByTagName("ConnectionString");
        if ((connectionString != null) && (connectionString.getLength() > 0)) {
            parseConnectionString((Element) connectionString.item(0));
        }
        NodeList adConfiguration = root.getElementsByTagName("ActiveDirectoryConfiguration");
        if ((adConfiguration != null) && (adConfiguration.getLength() > 0)) {
            parseADConfiguration((Element) adConfiguration.item(0));
        }
        NodeList currentSite = root.getElementsByTagName("CurrentSite");
        if ((currentSite != null) && (currentSite.getLength() > 0)) {
            parseCurrentSite((Element) currentSite.item(0));
        }
        NodeList cookieDomains = root.getElementsByTagName("CookieDomains");
        if ((cookieDomains != null) && (cookieDomains.getLength() > 0)) {
            parseCookieDomains((Element) cookieDomains.item(0));
        }
        NodeList cookieCheckJobs = root.getElementsByTagName("CookieCheckJobs");
        if ((cookieCheckJobs != null) && (cookieCheckJobs.getLength() > 0)) {
            parseCookieCheckJobs((Element) cookieCheckJobs.item(0));
        }
        NodeList urls = root.getElementsByTagName("Urls");
        if ((urls != null) && (urls.getLength() > 0)) {
            parseUrls((Element) urls.item(0));
        }
        NodeList dbAssemblyDefinition = root.getElementsByTagName("DBAssemblyDefinition");
        if ((dbAssemblyDefinition != null) && (dbAssemblyDefinition.getLength() > 0)) {
            parseDBAssemblyDefinition((Element) dbAssemblyDefinition.item(0));
        }
        NodeList userConfiguration = root.getElementsByTagName("UserConfiguration");
        if ((userConfiguration != null) && (userConfiguration.getLength() > 0)) {
            parseUserConfiguration((Element) userConfiguration.item(0));
        }
        NodeList tookenSaveModel = root.getElementsByTagName("TookenSaveModel");
        if ((tookenSaveModel != null) && (tookenSaveModel.getLength() > 0)) {
            parseTookenSaveModel((Element) tookenSaveModel.item(0));
        }
        NodeList includeFileExtension = root.getElementsByTagName("IncludeFileExtension");
        if ((includeFileExtension != null) && (includeFileExtension.getLength() > 0)) {
            parseIncludeFileExtension((Element) includeFileExtension.item(0));
        }
        try {
            SsoClientUtils.CONNECTION_USER = DES3Tools.getECBDecodeStr(SsoClientUtils.CONNECTION_USER);
            SsoClientUtils.CONNECTION_PASSWORD = DES3Tools.getECBDecodeStr(SsoClientUtils.CONNECTION_PASSWORD);
            SsoClientUtils.AD_ADMIN_USERID = DES3Tools.getECBDecodeStr(SsoClientUtils.AD_ADMIN_USERID);
            SsoClientUtils.AD_ADMIN_USERPW = DES3Tools.getECBDecodeStr(SsoClientUtils.AD_ADMIN_USERPW);
        } catch (Exception e) {
            log.error(e);
        }
    }

    private void parseConnectionString(Element element) {
        SsoClientUtils.CONNECTION_DATASOURCE = element.getAttributeNode("dataSource").getValue();
        SsoClientUtils.CONNECTION_PROVIDER_NAME = element.getAttributeNode("providerName").getValue();
        SsoClientUtils.CONNECTION_USER = element.getAttributeNode("userID").getValue();
        SsoClientUtils.CONNECTION_PASSWORD = element.getAttributeNode("password").getValue();
        SsoClientUtils.CONNECTION_DBNAME = element.getAttributeNode("dbName").getValue();
    }

    private void parseADConfiguration(Element element) {
        SsoClientUtils.AD_SERVER_IP = element.getAttributeNode("server").getValue();

        Attr port = element.getAttributeNode("port");
        if (port != null) {
            SsoClientUtils.AD_SERVER_PORT = port.getValue();
        }
        SsoClientUtils.AD_SERVER_DOMAIN = "@" + element.getAttributeNode("domain").getValue().replace("@", "");
        SsoClientUtils.AD_DIRECTORYPATH = element.getAttributeNode("directoryPath").getValue();
        SsoClientUtils.AD_ADMIN_USERID = element.getAttributeNode("userName").getValue();
        SsoClientUtils.AD_ADMIN_USERPW = element.getAttributeNode("password").getValue();
        SsoClientUtils.AD_PD_WARN_EXPIREDAYS = element.getAttributeNode("passwordWarnExpireDays").getValue();
    }

    private void parseCurrentSite(Element element) {
        SsoClientUtils.SYSTEM_CODE = element.getAttributeNode("systemCode").getValue();
        SsoClientUtils.KEY = element.getAttributeNode("key").getValue();
        SsoClientUtils.DATETIMEFORMAT = element.getAttributeNode("dateTimeFormat").getValue();
        SsoClientUtils.SESSIONID_NAME = element.getAttributeNode("sessionIdName").getValue();
        if (element.getAttributeNode("IsForbidden").getValue().equals("true")) {
            SsoClientUtils.IS_FORBIDDEN = true;
        } else if (element.getAttributeNode("IsForbidden").getValue().equals("fasle")) {
            SsoClientUtils.IS_FORBIDDEN = false;
        }
        if (element.hasAttribute("IsToolbarForceVisible")) {
            if (element.getAttributeNode("IsToolbarForceVisible").getValue().equals("true")) {
                SsoClientUtils.IS_TOOLBARVISIBLE = true;
            } else if (element.getAttributeNode("IsToolbarForceVisible").getValue().equals("fasle")) {
                SsoClientUtils.IS_TOOLBARVISIBLE = false;
            }
        } else {
            SsoClientUtils.IS_TOOLBARVISIBLE = false;
        }
    }

    private void parseCookieDomains(Element element) {
        Attr cookiePath = element.getAttributeNode("path");
        if (cookiePath != null) {
            SsoClientUtils.COOKIES_PATH = cookiePath.getValue();
        }
        NodeList domainList = element.getElementsByTagName("domain");
        for (int i = 0; i < domainList.getLength(); i++) {
            Map map = new HashMap();
            Element domainElement = (Element) domainList.item(i);
            map.put("name", domainElement.getAttributeNode("name").getValue());
            map.put("regex", Pattern.compile(domainElement.getAttributeNode("regex").getValue()));
            map.put("myHost", domainElement.getAttributeNode("myHost").getValue());
            map.put("loginUrl", domainElement.getAttributeNode("loginUrl").getValue());
            map.put("crossdomainUrl", domainElement.getAttributeNode("crossdomainUrl").getValue());
            map.put("defaultSite", domainElement.getAttributeNode("defaultSite").getValue());
            SsoClientUtils.DOMAIN_LIST.add(map);
        }
    }

    private void parseCookieCheckJobs(Element element) {
        NodeList domainList = element.getElementsByTagName("CheckJob");
        for (int i = 0; i < domainList.getLength(); i++) {
            Map map = new HashMap();
            Element domainElement = (Element) domainList.item(i);
            map.put("checkpoint", domainElement.getAttributeNode("checkpoint").getValue());
            map.put("operator", Pattern.compile(domainElement.getAttributeNode("operator").getValue()));
            map.put("UserConfig", domainElement.getAttributeNode("UserConfig").getValue());
            map.put("domain", domainElement.getAttributeNode("domain").getValue());
            map.put("cookies", domainElement.getAttributeNode("cookies").getValue());
            SsoClientUtils.CHECKJOB_LIST.add(map);
        }
    }

    private void parseUrls(Element element) {
        SsoClientUtils.ERROR_URL = element.getAttributeNode("errorUrl").getValue();

        SsoClientUtils.LOGON_URL = element.getAttributeNode("loginUrl").getValue();
        SsoClientUtils.DEFAULT_URL = element.getAttributeNode("defaulteurl").getValue();
    }

    private void parseUserConfiguration(Element element) {
        Attr mode = element.getAttributeNode("value");
        if (mode != null) {
            SsoClientUtils.AD_OR_DB_MODE = mode.getValue();
        }
    }

    private void parseTookenSaveModel(Element element) {
        Attr mode = element.getAttributeNode("value");
        if (mode != null) {
            SsoClientUtils.TOOKEN_SAVE_MODE = mode.getValue();
        }
    }

    private void parseDBAssemblyDefinition(Element element) {
        Attr mode = element.getAttributeNode("TypeName");
        if (mode != null) {
            SsoClientUtils.LocalModel_DB_Validataion = mode.getValue();
        }
    }

    private void parseIncludeFileExtension(Element element) {
        SsoClientUtils.SSO_FILTER_EXT = Pattern.compile(element.getAttributeNode("ext_value").getValue());
        SsoClientUtils.SSO_FILTER_CONTENTEXT = Pattern.compile(element.getAttributeNode("content_value").getValue());
        SsoClientUtils.SSO_FILTER_FORWARDEXT = Pattern.compile(element.getAttributeNode("for_value").getValue());
    }

    protected boolean UpdateSecretyKey(String secretyKey, String DBDataSource, String DBName, String DBUserID, String DBPassword, String ADServer, String ADDomain, String ADDirectoryPath, String ADUserName, String ADPassword) {
        File file = new File(SsoClientUtils.CONTENT_PAHT + SsoClientUtils.CONFIG_LOCATION);
        if (!file.exists()) {
            try {
                //file = ResourceUtils.getFile(SsoClientUtils.CONFIG_LOCATION);
                Resource res = new ClassPathResource(SsoClientUtils.CONFIG_LOCATION);
                FileUtils.copyInputStreamToFile(res.getInputStream(), file);
            } catch (IOException e) {
                throw new RuntimeException("File do not exist - File Name:" + SsoClientUtils.CONFIG_LOCATION);
            }
        }
        try {
            DocumentBuilder dombuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
            Document doc = dombuilder.parse(file);
            Element root = doc.getDocumentElement();

            Element elementSite = (Element) root.getElementsByTagName("CurrentSite").item(0);
            elementSite.getAttributeNode("key").setValue(secretyKey);

            Element elementDBConn = (Element) root.getElementsByTagName("ConnectionString").item(0);
            elementDBConn.getAttributeNode("dataSource").setValue(DBDataSource);
            elementDBConn.getAttributeNode("dbName").setValue(DBName);
            elementDBConn.getAttributeNode("userID").setValue(DBUserID);
            elementDBConn.getAttributeNode("password").setValue(DBPassword);

            Element elementADConn = (Element) root.getElementsByTagName("ActiveDirectoryConfiguration").item(0);
            elementADConn.getAttributeNode("server").setValue(ADServer);
            elementADConn.getAttributeNode("domain").setValue(ADDomain);
            elementADConn.getAttributeNode("directoryPath").setValue(ADDirectoryPath);
            elementADConn.getAttributeNode("userName").setValue(ADUserName);
            elementADConn.getAttributeNode("password").setValue(ADPassword);
            if (doc2XmlFile(doc, file)) {
                return true;
            }
            return false;
        } catch (SAXException e) {
            log.error(e);
            return false;
        } catch (IOException e) {
            log.error(e);
            return false;
        } catch (ParserConfigurationException e) {
            log.error(e);
        }
        return false;
    }

    protected boolean UpdateForbidden(boolean isForbidden) {
        File file = new File(SsoClientUtils.CONTENT_PAHT + SsoClientUtils.CONFIG_LOCATION);
        if (!file.exists()) {
            try {
                //file = ResourceUtils.getFile(SsoClientUtils.CONFIG_LOCATION);
                Resource res = new ClassPathResource(SsoClientUtils.CONFIG_LOCATION);
                FileUtils.copyInputStreamToFile(res.getInputStream(), file);
            } catch (IOException e) {
                throw new RuntimeException("File do not exist - File Name:" + SsoClientUtils.CONFIG_LOCATION);
            }
        }
        try {
            DocumentBuilder dombuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
            Document doc = dombuilder.parse(file);
            Element root = doc.getDocumentElement();

            Element elementSite = (Element) root.getElementsByTagName("CurrentSite").item(0);
            if (isForbidden) {
                elementSite.getAttributeNode("IsForbidden").setValue("true");
            } else {
                elementSite.getAttributeNode("IsForbidden").setValue("false");
            }
            if (doc2XmlFile(doc, file)) {
                return true;
            }
            return false;
        } catch (SAXException e) {
            log.error(e);
            return false;
        } catch (IOException e) {
            log.error(e);
            return false;
        } catch (ParserConfigurationException e) {
            log.error(e);
        }
        return false;
    }

    public static boolean doc2XmlFile(Document document, File file) {
        boolean flag = true;
        try {
            TransformerFactory tFactory = TransformerFactory.newInstance();
            Transformer transformer = tFactory.newTransformer();


            DOMSource source = new DOMSource(document);


            StreamResult result = new StreamResult(file.toURI().getPath());
            transformer.transform(source, result);
        } catch (Exception ex) {
            flag = false;
            ex.printStackTrace();
        }
        return flag;
    }

}
