package com.huaxia.hx_sell_commission.config.sso;

import com.cfld.sso.client.servlet.*;
import com.huaxia.hx_sell_commission.filter.ThirdAuthenticationFilter;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.boot.web.servlet.ServletRegistrationBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.DependsOn;

import java.util.ArrayList;
import java.util.List;

/**
 * @author YanChengLong
 * @date 2019/7/9
 * @desc sso注入bean
 */
@Configuration
public class SsoBeanConfig {

//    // 测试 正式 修改环境
//    @Value(value = "${project.sso.setting.file.name}")
//    private String url;

    /**
     * @author YanChengLong
     * @date 2019/7/9
     * @desc sso 过滤器
     */
    @Bean
    public FilterRegistrationBean checkLoginFilterConfig() {
        FilterRegistrationBean registrationBean = new FilterRegistrationBean();
        CheckLoginFilterConfig checkLoginFilter = new CheckLoginFilterConfig();
        registrationBean.setFilter(checkLoginFilter);
        List<String> urlPatterns = new ArrayList<String>();
//        urlPatterns.add("/*");
        urlPatterns.add("/api/*");
        registrationBean.setUrlPatterns(urlPatterns);
        registrationBean.addInitParameter("containerType", "Tomcat");
        registrationBean.addInitParameter("configLocation", "/Setting.xml");
        return registrationBean;
    }

    /**
     * @Desc 第三方调用接口鉴权
     * @Author shilei
     * @Date 2020/12/23
     */
    @Bean
    public FilterRegistrationBean<ThirdAuthenticationFilter> ThirdAuthenticationFilterConfig() {

        FilterRegistrationBean<ThirdAuthenticationFilter> registration = new FilterRegistrationBean<>();

        registration.setFilter(new ThirdAuthenticationFilter());
        registration.addUrlPatterns("/workflow/*");
        registration.addUrlPatterns("/Report/*");
        registration.setName("thirdAuthenticationFilter");
        return registration;
    }

    /**
     * @author YanChengLong
     * @date 2019/7/9
     * @desc sso servlet 配置
     */
    @Bean
    public ServletRegistrationBean VerifyImageServlet() {
        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
        SsoLocalModelCodeAndPwdServlet ssoLocalModelCodeAndPwdServlet = new SsoLocalModelCodeAndPwdServlet();
        registrationBean.setServlet(ssoLocalModelCodeAndPwdServlet);
        registrationBean.setName("verifyImageServlet");
        List<String> urlMappings = new ArrayList<String>();
        urlMappings.add("/VerifyCodeAndRememberPwd");
        registrationBean.setUrlMappings(urlMappings);
        return registrationBean;
    }

    @Bean
    public ServletRegistrationBean SsoLoginServlet() {
        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
        SsoLocalModelLoginServlet ssoLoginServlet = new SsoLocalModelLoginServlet();
        registrationBean.setServlet(ssoLoginServlet);
        registrationBean.setName("ssoLoginServlet");
        List<String> urlMappings = new ArrayList<String>();
        urlMappings.add("/cfld_sso_localmodel_login");
        registrationBean.setUrlMappings(urlMappings);
        return registrationBean;
    }

    @Bean
    public ServletRegistrationBean SsoLogoutServlet() {
        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
        SsoLocalModelLogoutServlet ssoLogoutServlet = new SsoLocalModelLogoutServlet();
        registrationBean.setServlet(ssoLogoutServlet);
        registrationBean.setName("ssoLogoutServlet");
        List<String> urlMappings = new ArrayList<String>();
        urlMappings.add("/cfld_sso_localmodel_exit.axd");
        registrationBean.setUrlMappings(urlMappings);
        return registrationBean;
    }

    @Bean
    public ServletRegistrationBean ClientGetCookiesServlet() {
        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
        ClientGetCookiesServlet clientGetCookiesServlet = new ClientGetCookiesServlet();
        registrationBean.setServlet(clientGetCookiesServlet);
        registrationBean.setName("clientGetCookiesServlet");
        List<String> urlMappings = new ArrayList<String>();
        urlMappings.add("/clientGetCookiesServlet");
        registrationBean.setUrlMappings(urlMappings);
        return registrationBean;
    }

    @Bean
    public ServletRegistrationBean SsoSecurityKeyUpdateServlet() {
        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
        SsoSecurityKeyUpdateServlet ssoSecurityKeyUpdateServlet = new SsoSecurityKeyUpdateServlet();
        registrationBean.setServlet(ssoSecurityKeyUpdateServlet);
        registrationBean.setName("ssoSecurityKeyUpdateServlet");
        List<String> urlMappings = new ArrayList<String>();
        urlMappings.add("/cfld_sso_Quartz_KeyUpdate.axd");
        registrationBean.setUrlMappings(urlMappings);
        return registrationBean;
    }

//    @Bean
//    public ServletRegistrationBean SsoSecurityFileUpdateServlet() {
//        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
//        SsoSecurityFileUpdateServlet ssoSecurityFileUpdateServlet = new SsoSecurityFileUpdateServlet();
//        registrationBean.setServlet(ssoSecurityFileUpdateServlet);
//        registrationBean.setName("ssoSecurityFileUpdateServlet");
//        List<String> urlMappings = new ArrayList<String>();
//        urlMappings.add("/cfld_sso_Quartz_FileUpdate.axd");
//        registrationBean.setUrlMappings(urlMappings);
//        return registrationBean;
//    }

    @Bean
    public ServletRegistrationBean SsoForbiddenSystemServlet() {
        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
        SsoForbiddenSystemServlet ssoForbiddenSystemServlet = new SsoForbiddenSystemServlet();
        registrationBean.setServlet(ssoForbiddenSystemServlet);
        registrationBean.setName("ssoForbiddenSystemServlet");
        List<String> urlMappings = new ArrayList<String>();
        urlMappings.add("/updateIsForbidden.axd");
        registrationBean.setUrlMappings(urlMappings);
        return registrationBean;
    }

    @Bean
    public ServletRegistrationBean ssoLogoutClean() {
        ServletRegistrationBean registrationBean = new ServletRegistrationBean();
        SsoLogoutClean ssoLogoutClean = new SsoLogoutClean();
        registrationBean.setServlet(ssoLogoutClean);
        registrationBean.setName("ssoLogoutClean");
        List<String> urlMappings = new ArrayList<String>();
        urlMappings.add("/cfld_sso_client_exit.axd");
        registrationBean.setUrlMappings(urlMappings);
        return registrationBean;
    }

    //跨域  可以不用这么设置 项目中有跨域的方式
   /* @Bean
    public FilterRegistrationBean  filterRegistrationBean() {
        FilterRegistrationBean registrationBean = new FilterRegistrationBean();
        CORSFilter corsFilter = new CORSFilter();
        registrationBean.setFilter(corsFilter);
        List<String> urlPatterns = new ArrayList<String>();
        urlPatterns.add("/*");
        registrationBean.setUrlPatterns(urlPatterns);
        registrationBean.addInitParameter("cors.allowOrigin", "*");
        //, PUT, GET, OPTIONS, HEAD
        registrationBean.addInitParameter("cors.supportedMethods", "POST");
        registrationBean.addInitParameter("cors.supportedHeaders", "Origin, X-Requested-With, Content-Type, Accept, client_id, uuid");
        registrationBean.addInitParameter("cors.supportsCredentials", "true");
        return registrationBean;
    }*/

    /**
     * @author YanChengLong
     * @date 2019/7/12
     * @desc 问题：Spring Boot使用的内嵌Tomcat不能开箱即用的支持Version 0的Cookie格式
     * 解决思路：使用 LegacyCookieProcessor即可解决。协议换了
     */
//    @Bean
//    public EmbeddedServletContainerCustomizer cookieProcessorCustomizer() {
//        return new EmbeddedServletContainerCustomizer() {
//            @Override
//            public void customize(ConfigurableEmbeddedServletContainer container) {
//                if (container instanceof TomcatEmbeddedServletContainerFactory) {
//                    ((TomcatEmbeddedServletContainerFactory) container)
//                            .addContextCustomizers(new TomcatContextCustomizer() {
//                                @Override
//                                public void customize(Context context) {
//                                    context.setCookieProcessor(new LegacyCookieProcessor());
//                                }
//                            });
//                }
//            }
//
//        };
//    }
}
