package com.huaxia.hx_sell_commission.controller;

import cn.hutool.core.util.StrUtil;
import com.huaxia.hx_sell_commission.config.ServerConfig;
import com.huaxia.hx_sell_commission.config.SysConfig;
import com.huaxia.hx_sell_commission.constant.Constants;
import com.huaxia.hx_sell_commission.exception.CustomException;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.StringUtils;
import com.huaxia.hx_sell_commission.utils.file.FileUploadUtils;
import com.huaxia.hx_sell_commission.utils.file.FileUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 通用请求处理
 * 
 * @author shilei
 */
@RestController
@RequestMapping("/api/common")
@Api(tags = "通用上传下载请求")
@Slf4j
public class CommonController {

    @Autowired
    private ServerConfig serverConfig;

    /**
     * 通用下载请求
     * 
     * @param url 文件下载地址
     * @param fileName 文件名
     * @param delete 是否删除
     */
    @GetMapping("/download")
    @ApiOperation(value = "通用下载请求")
    public void fileDownload(String url, String fileName, Boolean delete, HttpServletResponse response, HttpServletRequest request) {
        try {
//            if (!FileUtils.isValidFilename(fileName)) {
//                throw new CustomException(StringUtils.format("文件名称({})非法，不允许下载。 ", fileName), Constants.ERROR);
//            }
//            String filePath = SysConfig.getDownloadPath() + fileName;
            if(StrUtil.isBlank(url)){
                throw new CustomException(StringUtils.format("文件下载地址不能为空。url:{} ", url), Constants.ERROR);
            }
            response.setCharacterEncoding("utf-8");
            response.setContentType("multipart/form-data");
            response.setHeader("Content-Disposition",
                    "attachment;fileName=" + FileUtils.setFileDownloadHeader(request, fileName));
            FileUtils.writeBytes(url, response.getOutputStream());
            if (delete) {
                FileUtils.deleteFile(url);
            }
        }
        catch (Exception e) {
            log.error("下载文件失败", e);
        }
    }

    /**
     * 通用上传请求
     */
    @PostMapping("/upload")
    @ApiOperation(value = "通用上传请求")
    public AjaxResult uploadFile(MultipartFile file) {
        try {
            // 上传文件路径
            String filePath = SysConfig.getUploadPath();
            // 上传并返回新文件名称
            String fileName = FileUploadUtils.upload(filePath, file);
//            String url = serverConfig.getUrl() + fileName;
            String url = SysConfig.getDownloadPath() + fileName;
            AjaxResult ajax = AjaxResult.success();
            String[] name = fileName.split("/");
            ajax.put("fileName", name[name.length -1]);
            ajax.put("url", url);
            return ajax;
        } catch (Exception e) {
            log.error("上传失败：{}", e.getMessage());
            throw new CustomException("上传失败", Constants.ERROR);
        }
    }

}
