package com.huaxia.hx_sell_commission.controller;

import com.alibaba.fastjson.JSONObject;
import com.cfld.sso.client.servlet.SsoUserUtil;
import com.huaxia.hx_sell_commission.domain.csm.*;
import com.huaxia.hx_sell_commission.domain.csm.CsmSOrganization;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.page.TableDataInfo;
import com.huaxia.hx_sell_commission.vo.CsmSUserVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.huaxia.hx_sell_commission.service.ICsmSUserService;

import java.util.List;
import java.util.Map;

/**
 * 用户信息Controller
 *
 * @author shilei
 * @date 2020-11-16
 */
@RestController
@RequestMapping("/api/user")
@Api(tags = "用户信息接口")
@Slf4j
public class CsmSUserController extends BaseController {
    @Autowired
    private ICsmSUserService csmSUserService;

    /**
     * 获取用户详细信息
     */
    @GetMapping(value = "/getUserInfo")
    @ApiOperation(value = "获取用户详细信息")
    public AjaxResult getInfo() {
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        log.info("\n 获取用户详细信息[/user/getUserInfo]返回参数：{}", JSONObject.toJSON(csmSUser));
        return AjaxResult.success("获取用户详细信息成功", csmSUser);
    }

    /**
     * 单点请求头数据
     */
    @GetMapping(value = "/getloginInfo")
    @ApiOperation(value = "获取单点请求头数据")
    public AjaxResult getloginInfo() {
        Map<String, String> stringObjectMap = csmSUserService.getloginInfo();
        log.info("\n 获取单点请求头数据[/user/getloginInfo]返回参数：{}", JSONObject.toJSON(stringObjectMap));
        return AjaxResult.success("获取单点请求头数据成功", stringObjectMap);
    }

    @GetMapping("/userCompanyList")
    @ApiOperation(value = "查询用户分公司列表")
    public AjaxResult userCompanyList(String examineId) {
        log.info("\n 查询用户分公司列表[/user/userCompanyList]请求参数：{}", examineId);
        List<CsmSOrganization> csmSOrganizations = csmSUserService.userCompanyList(examineId);
        log.info("\n 查询用户分公司列表[/user/userCompanyList]返回参数：{}", JSONObject.toJSON(csmSOrganizations));
        return AjaxResult.success("查询用户分公司列表成功", csmSOrganizations);
    }

    @GetMapping("/userProjectList")
    @ApiOperation(value = "根据公司ID查询用户项目列表")
    public AjaxResult userProjectList(String buguId, String examineId) {
        log.info("\n 根据公司ID查询用户项目列表[/user/userProjectList]请求参数：{}{}", buguId, examineId);
        List<CsmSProject> csmSProjectList = csmSUserService.userProjectList(buguId, examineId);
        log.info("\n 根据公司ID查询用户项目列表[/user/userProjectList]返回参数：{}", JSONObject.toJSON(csmSProjectList));
        return AjaxResult.success("根据公司ID查询用户项目列表成功", csmSProjectList);
    }

    @GetMapping("/projGUList")
    @ApiOperation(value = "根据项目ID查询用户项目分期列表")
    public AjaxResult projGUList(String projectId) {
        log.info("\n 根据项目ID查询用户项目分期列表[/user/projGUList]请求参数：{}", projectId);
        List<CsmSMyproject> csmSMyProjectList = csmSUserService.projGUList(projectId);
        log.info("\n 根据项目ID查询用户项目分期列表[/user/projGUList]返回参数：{}", JSONObject.toJSON(csmSMyProjectList));
        return AjaxResult.success("根据项目ID查询用户项目分期列表成功", csmSMyProjectList);
    }

    @GetMapping("/getUserByProjectId")
    @ApiOperation(value = "根据项目ID查询用户列表")
    public TableDataInfo getUserByProjectId(CsmSUserVo csmSUserVo) {
        log.info("\n 根据项目ID查询用户列表[/user/getUserByProjectId]请求参数：{}", JSONObject.toJSON(csmSUserVo));
        startPage();
        List<CsmSUser> csmSUserList = csmSUserService.getUserByProjectId(csmSUserVo);
        log.info("\n 根据项目ID查询用户列表[/user/getUserByProjectId]返回参数：{}", JSONObject.toJSON(csmSUserList));
        return getDataTable(csmSUserList);
    }

    @GetMapping("/userMenuTree")
    @ApiOperation(value = "查询用户菜单功能树")
    public AjaxResult userMenuTree() {
        Map<String, Object> map = csmSUserService.selectUserMenuList();
        log.info("\n 查询用户菜单功能树[/user/userMenuList]返回参数：{}", JSONObject.toJSON(map));
        return AjaxResult.success("查询用户菜单功能树成功", map);
    }

    @GetMapping("/userTreeList")
    @ApiOperation(value = "查询用户分公司项目列表")
    public AjaxResult userTreeList() {
        List<CsmSOrganization> csmSOrganizations = csmSUserService.userTreeList();
        log.info("\n 查询用户分公司项目列表[/user/userCompanyList]返回参数：{}", JSONObject.toJSON(csmSOrganizations));
        return AjaxResult.success("查询用户分公司项目列表成功", csmSOrganizations);
    }

}
