package com.huaxia.hx_sell_commission.controller;

import cn.hutool.core.io.IoUtil;
import cn.hutool.http.HttpResponse;
import cn.hutool.poi.excel.ExcelUtil;
import cn.hutool.poi.excel.ExcelWriter;
import cn.hutool.poi.excel.StyleSet;
import com.alibaba.fastjson.JSONObject;
import com.huaxia.hx_sell_commission.constant.Constants;
import com.huaxia.hx_sell_commission.domain.ExamineBill;
import com.huaxia.hx_sell_commission.domain.ExaminebillPayment;
import com.huaxia.hx_sell_commission.service.ExamineBillService;
import com.huaxia.hx_sell_commission.service.IPaymenttempService;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.ValidResultUtil;
import com.huaxia.hx_sell_commission.utils.file.FileUtils;
import com.huaxia.hx_sell_commission.vo.ExamineBillVo;
import com.huaxia.hx_sell_commission.vo.ExcelExamineBill;
import com.huaxia.hx_sell_commission.vo.ExcelExamineBillSummaryVo;
import com.huaxia.hx_sell_commission.vo.TradeVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.xssf.usermodel.XSSFCellStyle;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 核算单接口信息Controller
 *
 * @author qjcui
 * @date 2020-11-23
 */
@RestController
@RequestMapping("/api/examineBill")
@Api(tags = "核算单接口信息")
@Slf4j
public class ExamineBillController extends BaseController {

    /**
     * 核算单接口
     */
    @Autowired
    private ExamineBillService examineBillService;

    /**
     * 核算单接口
     */
    @Autowired
    private IPaymenttempService iPaymenttempService;

    @PostMapping("/updateExamineBill")
    @ApiOperation(value = "核算单状态修改")
    public AjaxResult updateExamineBill(@RequestBody ExamineBill examineBill) {
        log.info("\n 核算单状态修改[/examineBill/updateExamineBill]请求参数：{}", JSONObject.toJSON(examineBill));
//         examineBillService.updateExamineBill(examineBill);
        return examineBillService.updateExamineBill(examineBill);
    }

    @PostMapping("/addExamineBill")
    @ApiOperation(value = "核算单添加")
    public AjaxResult addExamineBill(@RequestBody @Valid ExamineBill examineBill, BindingResult bindingResult) {
        log.info("\n 核算单添加[/examineBill/addExamineBill]请求参数：{}", JSONObject.toJSON(examineBill));
        if (bindingResult.hasErrors()) {
            return AjaxResult.error(Constants.ERROR, ValidResultUtil.resultMsg(bindingResult));
        }
        return examineBillService.addExamineBill(examineBill);
    }

    @PostMapping("/addExamineBillName")
    @ApiOperation(value = "核算单添加核算单名")
    public AjaxResult addExamineBillName(@RequestBody @Valid ExamineBill examineBill, BindingResult bindingResult) {
        log.info("\n 核算单添加核算单名[/examineBill/addExamineBillName]请求参数：{}", JSONObject.toJSON(examineBill));
        if (bindingResult.hasErrors()) {
            return AjaxResult.error(Constants.ERROR, ValidResultUtil.resultMsg(bindingResult));
        }

        return examineBillService.addExamineBillName(examineBill);
    }

    @PostMapping("/examineBillGenerateShow")
    @ApiOperation(value = "生成核算单列表展示")
    public AjaxResult examineBillGenerateShow(@RequestBody ExamineBill examineBill) {
        log.info("\n 生成核算单列表展示[/examineBill/examineBillGenerateShow]请求参数：{}", JSONObject.toJSON(examineBill));
        List<TradeVo> tradeVoList = iPaymenttempService.selectPaymenttempAllByPayId(examineBill);
        return AjaxResult.success("生成核算单列表展示", tradeVoList);
    }

    @GetMapping("/examineBillShow")
    @ApiOperation(value = "核算单列表展示")
    public AjaxResult examineBillShow(ExamineBillVo examineBillVo) {
        log.info("\n 核算单列表展示[/examineBill/examineBillShow]请求参数：{}", JSONObject.toJSON(examineBillVo));
        startPage();
        List<ExamineBill> examineBillList = examineBillService.examineBillShow(examineBillVo);
        return AjaxResult.success("核算单列表展示", getDataTable(examineBillList));
    }

    @PostMapping("/examineBillDetailsShow")
    @ApiOperation(value = "查看核算单")
    public AjaxResult examineBillDetailsShow(@RequestBody ExamineBillVo examineBillVo,HttpServletResponse response) {
        log.info("\n 查看核算单[/examineBill/examineBillShow]请求参数：{}", JSONObject.toJSON(examineBillVo));
        List<ExcelExamineBill> examineBillList = iPaymenttempService.examineBillDetailsFind(examineBillVo);
        if(examineBillList.size()>0)
        {
            return AjaxResult.success("查看核算单", examineBillList);
        }
        else
        {
            return AjaxResult.error("统计视图正在计算中，请稍后重试！");
        }
        /*
        response.setHeader("data-v", "1");
        return AjaxResult.success("查看核算单", examineBillList);
        */
    }

    @PostMapping("/examineBillExport")
    @ApiOperation(value = "核算单导出")
    public AjaxResult examineBillExport(@RequestBody ExamineBillVo examineBillVo, HttpServletResponse response){
        AjaxResult res = new AjaxResult();

        logger.info("request params : {}" , JSONObject.toJSON(examineBillVo));
        try {
            String dateString = new SimpleDateFormat("yyyyMMddHHmmss").format(new Date());
            String fileName =   "统计视图" + "-" + dateString ;
            response.reset();
            try {
                fileName = URLEncoder.encode(fileName, "UTF-8");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            response.setHeader("Content-Disposition", "attachment; filename=" + fileName + ".xlsx");
//            response.setContentType("application/vnd.ms-excel; charset=utf-8");

            ServletOutputStream out = response.getOutputStream();
            iPaymenttempService.examineBillExport(examineBillVo,out);
        } catch (IOException e) {
            e.printStackTrace();
        }
        logger.info("result params : {}" , JSONObject.toJSON(res));
        return res;

    }


    @PostMapping("/updateExamineBillDetail")
    @ApiOperation(value = "修改核算单展示回带交易id[修改核算单的交易回显]")
    public AjaxResult updateExamineBillDetail(@RequestBody ExamineBill examineBill) {
        log.info("\n 修改核算单展示回带交易id[/examineBill/examineBillShow]请求参数：{}", JSONObject.toJSON(examineBill));
        //判断登陆人有没有编辑权限
        Integer i = examineBillService.isEditable(examineBill.getExamineId());
        if(i == 0){
            return AjaxResult.success("您不是创建人，无法修改", 0);
        }
        Map<String, Object> list = examineBillService.selectTradeList(examineBill);
        return AjaxResult.success("修改核算单展示回带交易id", list);
    }

    @PostMapping("/updateExamineBillDetailShow")
    @ApiOperation(value = "修改核算单展示[修改核算单的佣金明细回显]")
    public AjaxResult updateExamineBillDetailShow(@RequestBody TradeVo trade) {
        log.info("\n 修改核算单展示[修改核算单的佣金明细回显][/examineBill/examineBillShow]请求参数：{}", JSONObject.toJSON(trade));
        if(trade.getTradeguidList() == null || trade.getTradeguidList().size() <= 0){
            return AjaxResult.success("交易id不能为空", 0);
        }
        List<TradeVo> list = examineBillService.updateExamineBillDetailShow(trade);
        return AjaxResult.success("查看核算单", list);
    }

    @GetMapping("/examineTradeShow")
    @ApiOperation(value = "核算单交易展示---选择交易和新增时交易页面")
    public AjaxResult examineTradeShow(TradeVo trade) {
        log.info("\n 核算单交易展示[修改核算单的佣金明细回显]修改时回显2[/examineBill/examineTradeShow]请求参数：{}", JSONObject.toJSON(trade));
        startPage();
        List<TradeVo> list = examineBillService.examineTradeShow(trade);
        return AjaxResult.success("核算单交易展示，修改时回显2", getDataTable(list));
    }

    @GetMapping("/deleteTrade")
    @ApiOperation(value = "删除交易")
    public AjaxResult deleteTrade(ExaminebillPayment examinebillPayment) {
        log.info("\n 删除交易[/examineBill/deleteTrade]请求参数：{}", JSONObject.toJSON(examinebillPayment));
        startPage();
        return examineBillService.deleteTrade(examinebillPayment);

    }

    @PostMapping("/examineBillUserSummaryShow")
    @ApiOperation(value = "核算单人员核发汇总展示")
    public AjaxResult examineBillUserSummaryShow(@RequestBody ExamineBillVo examineBillVo) {
        log.info("\n 核算单人员核发汇总展示[/examineBill/examineBillUserSummaryShow]请求参数：{}", JSONObject.toJSON(examineBillVo));
        Map<String, Object> data = examineBillService.examineBillUserSummaryShow(examineBillVo);
        return AjaxResult.success("核算单人员核发汇总展示", data);
    }

    @PostMapping("/examineBillSummaryExport")
    @ApiOperation(value = "核算单核发汇总导出")
    public void examineBillSummaryExport(@RequestBody ExamineBillVo examineBillVo, HttpServletResponse response,
                                         HttpServletRequest request) throws IOException {
        logger.info("request params : {}" , JSONObject.toJSON(examineBillVo));

        String dateString = new SimpleDateFormat("yyyyMMddHHmmss").format(new Date());
        response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;charset=utf-8");
        response.setHeader("Content-Disposition","attachment;filename=" +
                FileUtils.setFileDownloadHeader(request, "汇总核发视图"+ "-" + dateString) + ".xlsx");

        ServletOutputStream out= response.getOutputStream();
        examineBillService.examineBillSummaryExport(examineBillVo,out);
    }


    @PostMapping("/examineBillUserSummaryExportNew")
    @ApiOperation(value = "核算单列表人员核发汇总报表导出")
    public AjaxResult examineBillUserSummaryExportNew(@RequestBody ExamineBillVo examineBillVo, HttpServletResponse response) {
        log.info("\n 核算单列表人员核发汇总报表导出[/examineBill/examineBillUserSummaryExportNew]请求参数：{}", JSONObject.toJSON(examineBillVo));
        AjaxResult res = new AjaxResult();
        try {
            String dateString = new SimpleDateFormat("yyyyMMddHHmmss").format(new Date());
            String fileName =   "核算单核发表" + "-" + dateString ;
            response.reset();
            try {
                fileName = URLEncoder.encode(fileName, "UTF-8");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            response.setHeader("Content-Disposition", "attachment; filename=" + fileName + ".xlsx");
            ServletOutputStream out = response.getOutputStream();
            examineBillService.examineBillShowUserSummary(examineBillVo,out);
        } catch (IOException e) {
            e.printStackTrace();
        }
        log.info("result params : {}" , JSONObject.toJSON(res));
        return res;
    }


    @PostMapping("/examineBillSummaryExportNew")
    @ApiOperation(value = "核算单统计试图报表导出")
    public AjaxResult examineBillSummaryExportNew(@RequestBody ExamineBillVo examineBillVo, HttpServletResponse response){
        log.info("\n 核算单统计试图报表导出[/examineBill/examineBillSummaryExportNew]请求参数：{}", JSONObject.toJSON(examineBillVo));
        AjaxResult res = new AjaxResult();
        try {
            String dateString = new SimpleDateFormat("yyyyMMddHHmmss").format(new Date());
            String fileName =   "核算单统计表" + "-" + dateString ;
            response.reset();
            try {
                fileName = URLEncoder.encode(fileName, "UTF-8");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
            response.setHeader("Content-Disposition", "attachment; filename=" + fileName + ".xlsx");
            ServletOutputStream out = response.getOutputStream();
            examineBillService.examineBillShowSummary(examineBillVo,out);
        } catch (IOException e) {
            e.printStackTrace();
        }
        log.info("result params : {}" , JSONObject.toJSON(res));
        return res;
        //List<ExcelExamineBill> examineBillList = examineBillService.examineBillShowSummary(examineBillVo,out);
        //return AjaxResult.success("核算单列表展示", examineBillList);
    }

}
