package com.huaxia.hx_sell_commission.controller;

import java.util.List;

import com.alibaba.fastjson.JSONObject;
import com.huaxia.hx_sell_commission.constant.Constants;
import com.huaxia.hx_sell_commission.domain.Paymentdetails;
import com.huaxia.hx_sell_commission.domain.Trade;
import com.huaxia.hx_sell_commission.domain.YxGroupFeePlan;
import com.huaxia.hx_sell_commission.domain.csm.CsmSUser;
import com.huaxia.hx_sell_commission.mapper.db2.CsmSProjectMapper;
import com.huaxia.hx_sell_commission.service.ICsmSUserService;
import com.huaxia.hx_sell_commission.service.IPaymenttempFileService;
import com.huaxia.hx_sell_commission.utils.ValidResultUtil;
import com.huaxia.hx_sell_commission.vo.TradeVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import com.huaxia.hx_sell_commission.domain.Paymenttemp;
import com.huaxia.hx_sell_commission.service.IPaymenttempService;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.page.TableDataInfo;

import javax.validation.Valid;

/**
 * 方案模板管理Controller
 *
 * @author shilei
 * @date 2020-11-16
 */
@RestController
@RequestMapping("/api/paymenttemp")
@Api(tags = "佣金方案模板管理接口")
@Slf4j
public class PaymenttempController extends BaseController {
    @Autowired
    private IPaymenttempService paymenttempService;

    @Autowired
    private IPaymenttempFileService paymenttempFileService;

    @Autowired
    private ICsmSUserService csmSUserService;

    @Autowired
    private CsmSProjectMapper csmSProjectMapper;

    @GetMapping("/payNodeList")
    @ApiOperation(value = "查询支付节点")
    public AjaxResult payNodeList() {
        return paymenttempService.selectPayNodeList();
    }

    @GetMapping("/userTypeList")
    @ApiOperation(value = "查询岗位类别集合")
    public AjaxResult userTypeList() {
        return paymenttempService.selectUserTypeList();
    }


    @PostMapping("/businessDetailList")
    @ApiOperation(value = "查询电商项目列表详情")
    public AjaxResult businessDetailList(@RequestBody YxGroupFeePlan yxGroupFeePlan) {
        //updateByCui---start
        log.info("\n 查询电商项目列表详情[/paymenttemp/businessDetailList]请求参数：{}", JSONObject.toJSON(yxGroupFeePlan));
        if(yxGroupFeePlan.getProjectId() == null || yxGroupFeePlan.getProjectId().equals("")){
            if(yxGroupFeePlan.getYxGroupFeePlanGuid() == null || yxGroupFeePlan.getYxGroupFeePlanGuid().equals("")){
                return AjaxResult.error("必须选择项目", 0);
            }


        }
        List<YxGroupFeePlan> list = paymenttempService.selectProjectList(yxGroupFeePlan);
        log.info("\n 查询电商项目列表详情[/paymenttemp/businessDetailList]返回参数：{}", JSONObject.toJSON(list));
        //updateByCui---end
        return AjaxResult.success("查询电商项目列表详情成功", list);
    }



    @GetMapping("/list")
    @ApiOperation(value = "查询方案模板列表")
    public TableDataInfo list(Paymenttemp paymenttemp) {
        log.info("\n 查询方案模板列表[/paymenttemp/list]请求参数：{}", JSONObject.toJSON(paymenttemp));
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        List<String> projectIds = csmSProjectMapper.getProject(csmSUser == null ? "maowei" : csmSUser.getUsername());
        startPage();
        List<Paymenttemp> list = paymenttempService.selectPaymenttempList(paymenttemp, projectIds);
        log.info("\n 查询方案模板列表[/paymenttemp/list]返回参数：{}", JSONObject.toJSON(list));
        return getDataTable(list);
    }

    @PostMapping("/getList")
    @ApiOperation(value = "根据交易ID查询方案模板列表")
    public TableDataInfo getList(@RequestBody List<String> tradeguId) {
        log.info("\n 根据交易ID查询方案模板列表[/paymenttemp/getList]请求参数：{}", JSONObject.toJSON(tradeguId));
        startPage();
        List<Paymenttemp> list = paymenttempService.selectListByTradeguId(tradeguId);
        log.info("\n 根据交易ID查询方案模板列表[/paymenttemp/getList]返回参数：{}", JSONObject.toJSON(list));
        return getDataTable(list);
    }

    @GetMapping(value = "/getInfo")
    @ApiOperation(value = "获取方案模板详细信息")
    public AjaxResult getInfo(@RequestParam(value = "tempid") String tempid) {
        log.info("\n 获取方案模板详细信息[/paymenttemp/getInfo]请求参数：{}", tempid);
        Paymenttemp paymenttemp = paymenttempService.selectPaymenttempAllById(tempid);
        log.info("\n 获取方案模板详细信息[/paymenttemp/getInfo]返回参数：{}", JSONObject.toJSON(paymenttemp));
        return AjaxResult.success("获取方案模板详细信息成功", paymenttemp);
    }

    @PostMapping("/add")
    @ApiOperation(value = "新增方案模板")
    public AjaxResult add(@RequestBody @Valid Paymenttemp paymenttemp, BindingResult bindingResult) {
        log.info("\n 新增方案模板[/paymenttemp/add]请求参数：{}", JSONObject.toJSON(paymenttemp));
        if (bindingResult.hasErrors()) {
            return AjaxResult.error(Constants.ERROR, ValidResultUtil.resultMsg(bindingResult));
        }
        return paymenttempService.insertPaymenttemp(paymenttemp);
    }

    @PostMapping("/edit")
    @ApiOperation(value = "修改方案模板")
    public AjaxResult edit(@RequestBody Paymenttemp paymenttemp) {
        log.info("\n 修改方案模板[/paymenttemp/edit]请求参数：{}", JSONObject.toJSON(paymenttemp));
        return paymenttempService.updatePaymenttemp(paymenttemp);
    }

//    @GetMapping("/del")
//    @ApiOperation(value = "删除方案模板单个人员分配信息")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "tempid", value = "方案模板ID"),
//            @ApiImplicitParam(name = "userid", value = "人员ID")
//    })
//    public AjaxResult remove(String tempid, String userid) {
//        return toAjax(paymenttempService.deleteTempUser(tempid, userid));
//    }

    @PostMapping("/updateStatus")
    @ApiOperation(value = "启用、停用接口")
    public AjaxResult updateStatus(@RequestBody Paymenttemp paymenttemp) {
        log.info("\n 启用、停用接口[/paymenttemp/updateStatus]请求参数：{}", JSONObject.toJSON(paymenttemp));
        return toAjax(paymenttempService.updateStatus(paymenttemp));
    }

    @PostMapping("/stopUsing")
    @ApiOperation(value = "停用接口")
    public AjaxResult stopUsing(@RequestBody Paymenttemp paymenttemp) {
        log.info("\n 停用接口[/paymenttemp/stopUsing]请求参数：{}", JSONObject.toJSON(paymenttemp));
        return toAjax(paymenttempService.stopUsing(paymenttemp));
    }

    /*@GetMapping("/removeFile")
    @ApiOperation(value = "删除单个附件")
    public AjaxResult removeFile(String fileId) {
        return toAjax(paymenttempFileService.deletePaymenttempFileByFileId(fileId));
    }*/

    @PostMapping("/checkOut")
    @ApiOperation(value = "退房结算展示")
    public AjaxResult checkOut(@RequestBody List<String> tradeIds) {
        log.info("\n 退房结算展示[/paymenttemp/checkOut]请求参数：{}", JSONObject.toJSON(tradeIds));
        //根据交易id查佣金方案
        List<TradeVo> paymentdetailsList = paymenttempService.selectPaymenttempAllByTradeId(tradeIds);
        return AjaxResult.success("退房结算佣金方案详情", paymentdetailsList);
    }

    @PostMapping("/jumpOrNo")
    @ApiOperation(value = "是否跳转")
    public AjaxResult jumpOrNo(@RequestBody List<String> tradeIds) {
        log.info("\n 是否跳转[/paymenttemp/checkOut]请求参数：{}", JSONObject.toJSON(tradeIds));
        //根据交易id查佣金方案
        Integer i = paymenttempService.jumpOrNo(tradeIds);
        if(i == 0){
            return AjaxResult.success("需要跳转", "1");
        }else if(i == 1){
            return AjaxResult.success("退房成功", "0");
        }else if(i == 3){
            return AjaxResult.success("交易详情存在待审核状态，无法退房", "3");
        }else if(i == 4){
            return AjaxResult.success("退房状态为否不能退房", "4");
        }else{
            return AjaxResult.success("草稿和作废不能退房", "2");
        }

    }

    @PostMapping("/checkOutSubmit")
    @ApiOperation(value = "退房结算提交")
    public AjaxResult checkOutSubmit(@RequestBody List<String> tradeIds) {
        log.info("\n 退房结算展示[/paymenttemp/checkOut]请求参数：{}", JSONObject.toJSON(tradeIds));
        //根据交易id查佣金方案房结算提交
        int i = paymenttempService.checkOutSubmit(tradeIds);
        return AjaxResult.success("退房结算提交完成", null);
    }

    /*
    方案追加模板
    */
    @PostMapping("/getAppendList")
    @ApiOperation(value = "根据交易ID查询待追加的方案模板列表")
    public TableDataInfo getAppendList(@RequestBody String tradeguId) {
        log.info("\n 根据交易ID查询方案模板列表[/paymenttemp/getList]请求参数：{}", JSONObject.toJSON(tradeguId));
        startPage();

        List<Paymenttemp> list = paymenttempService.selectAppendListByTradeguId(tradeguId);
        log.info("\n 根据交易ID查询方案模板列表[/paymenttemp/getList]返回参数：{}", JSONObject.toJSON(list));
        return getDataTable(list);
    }
}
