package com.huaxia.hx_sell_commission.controller;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson.JSONObject;
import com.huaxia.hx_sell_commission.domain.Planfee;
import com.huaxia.hx_sell_commission.vo.TradeVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.huaxia.hx_sell_commission.domain.Plan;
import com.huaxia.hx_sell_commission.service.IPlanService;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.page.TableDataInfo;

/**
 * 佣金方案详情Controller
 *
 * @author shilei
 * @date 2020-11-18
 */
@RestController
@RequestMapping("/api/plan")
@Api(tags = "佣金方案管理接口")
@Slf4j
public class PlanController extends BaseController {

    @Autowired
    private IPlanService planService;

    /**
     * 查询方案列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询佣金方案管理列表")
    public TableDataInfo list(TradeVo trade) {
        log.info("\n 查询佣金方案管理列表[/plan/list]请求参数：{}", JSONObject.toJSON(trade));
        startPage();
        List<TradeVo> list = planService.selectTradeList(trade);
        log.info("\n 查询佣金方案管理列表[/plan/list]返回参数：{}", JSONObject.toJSON(list));
        return getDataTable(list);
    }

    @PostMapping("/addFirst")
    @ApiOperation(value = "新增佣金方案-1.保存修改佣金方案模板")
    public AjaxResult addFirst(@RequestBody List<Plan> plan) {
        log.info("\n 新增佣金方案-1.保存修改佣金方案模板[/plan/addFirst]请求参数：{}", JSONObject.toJSON(plan));
        return planService.insertPlan(plan);
    }

    @GetMapping("/regulateBrokerage")
    @ApiOperation(value = "新增佣金方案-2.查询调整佣金")
    public AjaxResult regulateBrokerage(@RequestParam(value ="tradeguidList") List<String> tradeguidList) {
        log.info("\n 新增佣金方案-2.查询调整佣金[/plan/regulateBrokerage]请求参数：{}", JSONObject.toJSON(tradeguidList));
        List<TradeVo> list = planService.getRegulateBrokerage(tradeguidList);
        log.info("\n 新增佣金方案-2.查询调整佣金[/plan/regulateBrokerage]返回参数：{}", JSONObject.toJSON(list));
        return AjaxResult.success("新增佣金方案-2.查询调整佣金成功", list);
    }

    @PostMapping("/addOrUpdateSecond")
    @ApiOperation(value = "新增佣金方案-2.保存修改调整佣金")
    public AjaxResult addOrUpdateSecond(@RequestBody List<Planfee> planfees) {
        log.info("\n 新增佣金方案-2.保存修改调整佣金[/plan/addOrUpdateSecond]请求参数：{}", JSONObject.toJSON(planfees));
        return planService.insertPlanfee(planfees);
    }

    @GetMapping("/settlePlan")
    @ApiOperation(value = "新增佣金方案-3.查询结算方案")
    public AjaxResult settlePlan(@RequestParam List<String> tradeguidList) {
        log.info("\n 新增佣金方案-3.查询结算方案[/plan/settlePlan]请求参数：{}", JSONObject.toJSON(tradeguidList));
        List<TradeVo> list = planService.getSettlePlan(tradeguidList);
        log.info("\n 新增佣金方案-3.查询结算方案[/plan/settlePlan]返回参数：{}", JSONObject.toJSON(list));
        return AjaxResult.success("新增佣金方案-3.查询结算方案成功", list);
    }

    @PostMapping("/planCalculation")
    @ApiOperation(value = "新增佣金方案-3.方案试算")
    public AjaxResult planCalculation(@RequestBody List<TradeVo> tradeVoList) {
        log.info("\n 新增佣金方案-3.方案试算[/plan/planCalculation]请求参数：{}", JSONObject.toJSON(tradeVoList));
        List<TradeVo> list = planService.planCalculation(tradeVoList);
        log.info("\n 新增佣金方案-3.方案试算[/plan/planCalculation]返回参数：{}", JSONObject.toJSON(list));
        return AjaxResult.success("新增佣金方案-3.方案试算成功", list);
    }

    @PostMapping("/addOrUpdateSettlePlan")
    @ApiOperation(value = "新增佣金方案-3.保存修改结算方案")
    public AjaxResult addOrUpdateSettlePlan(@RequestBody List<TradeVo> tradeVoList) {
        log.info("\n 新增佣金方案-3.保存修改结算方案[/plan/addOrUpdateSettlePlan]请求参数：{}", JSONObject.toJSON(tradeVoList));
        return planService.insertSettlePlan(tradeVoList);
    }

    @GetMapping("/findPlanDetails")
    @ApiOperation(value = "佣金方案-查看、预览")
    public AjaxResult findPlanDetails(@RequestParam List<String> tradeguids) {
        log.info("\n 佣金方案-查看、预览[/plan/findPlanDetails]请求参数：{}", JSONObject.toJSON(tradeguids));
        List<TradeVo> planDetails = planService.findPlanDetails(tradeguids);
        log.info("\n 佣金方案-查看、预览[/plan/findPlanDetails]返回参数：{}", JSONObject.toJSON(planDetails));
        return AjaxResult.success("佣金方案-查看成功", planDetails);
    }

    @GetMapping("/delTradePlan")
    @ApiOperation(value = "佣金方案-作废")
    public AjaxResult delTradePlan(@RequestParam String tradeguid) {
        log.info("\n 佣金方案-作废[/plan/delTradePlan]请求参数：{}", JSONObject.toJSON(tradeguid));
        return planService.delTradePlan(tradeguid);
    }

    @GetMapping("/tradePlanSubmit")
    @ApiOperation(value = "佣金方案-提交")
    public AjaxResult tradePlanSubmit(@RequestParam List<String> planIds) {
        log.info("\n 佣金方案-提交[/plan/tradePlanSubmit]请求参数：{}", JSONObject.toJSON(planIds));
        return planService.tradePlanSubmit(planIds);
    }

    /*
    方案追加模板
    */
    //完成
    @PostMapping("/AppendaddFirst")
    @ApiOperation(value = "新增佣金方案-1.追加模板")
    public AjaxResult AppendaddFirst(@RequestBody Plan plan) {
        log.info("\n 新增佣金方案-1.保存修改佣金方案模板[/plan/AppendaddFirst]请求参数：{}", JSONObject.toJSON(plan));
        return planService.AppendTemp(plan);
    }

    //完成
    @GetMapping("/AppendregulateBrokerage")
    @ApiOperation(value = "新增佣金方案-2.查询调整佣金")
    public AjaxResult AppendregulateBrokerage(@RequestParam(value ="tradeguidList") String tradeguid) {
        List<String> tradeguidList=new ArrayList<String>();
        tradeguidList.add(tradeguid);
        log.info("\n 新增佣金方案-2.查询调整佣金[/plan/AppendregulateBrokerage]请求参数：{}", JSONObject.toJSON(tradeguidList));
        List<TradeVo> list = planService.AppendgetRegulateBrokerage(tradeguidList);
        log.info("\n 新增佣金方案-2.查询调整佣金[/plan/AppendregulateBrokerage]返回参数：{}", JSONObject.toJSON(list));
        return AjaxResult.success("新增佣金方案-2.查询调整佣金成功", list);
    }

    //完成【待测试】
    @PostMapping("/AppendaddOrUpdateSecond")
    @ApiOperation(value = "新增佣金方案-2.保存修改调整佣金")
    public AjaxResult AppendaddOrUpdateSecond(@RequestBody Planfee planfees) {
        List<Planfee> planfeeList=new ArrayList<Planfee>();
        planfeeList.add(planfees);
        log.info("\n 新增佣金方案-2.保存修改调整佣金[/plan/AppendaddOrUpdateSecond]请求参数：{}", JSONObject.toJSON(planfees));
        return planService.insertPlanfee(planfeeList);
    }

    //完成【待测试】
    @GetMapping("/AppendsettlePlan")
    @ApiOperation(value = "新增佣金方案-3.查询结算方案")
    public AjaxResult AppendsettlePlan(@RequestParam String tradeguid) {
        List<String> tradeguidList=new ArrayList<>();
        tradeguidList.add(tradeguid);
        log.info("\n 新增佣金方案-3.查询结算方案[/plan/AppendsettlePlan]请求参数：{}", JSONObject.toJSON(tradeguidList));
        List<TradeVo> list = planService.AppendgetSettlePlan(tradeguidList);
        log.info("\n 新增佣金方案-3.查询结算方案[/plan/AppendsettlePlan]返回参数：{}", JSONObject.toJSON(list));
        return AjaxResult.success("新增佣金方案-3.查询结算方案成功", list);
    }

    //完成【待测试】
    @PostMapping("/AppendplanCalculation")
    @ApiOperation(value = "新增佣金方案-3.方案试算")
    public AjaxResult AppendplanCalculation(@RequestBody List<TradeVo> tradeVoList) {
        log.info("\n 新增佣金方案-3.方案试算[/plan/AppendplanCalculation]请求参数：{}", JSONObject.toJSON(tradeVoList));
        List<TradeVo> list = planService.planCalculation(tradeVoList);
        log.info("\n 新增佣金方案-3.方案试算[/plan/AppendplanCalculation]返回参数：{}", JSONObject.toJSON(list));
        return AjaxResult.success("新增佣金方案-3.方案试算成功", list);
    }

    //待处理
    @PostMapping("/AppendaddOrUpdateSettlePlan")
    @ApiOperation(value = "新增佣金方案-3.保存修改结算方案")
    public AjaxResult AppendaddOrUpdateSettlePlan(@RequestBody List<TradeVo> tradeVoList) {
        log.info("\n 新增佣金方案-3.保存修改结算方案[/plan/AppendaddOrUpdateSettlePlan]请求参数：{}", JSONObject.toJSON(tradeVoList));
        return planService.AppendinsertSettlePlan(tradeVoList);
    }

}
