package com.huaxia.hx_sell_commission.controller;

import com.alibaba.fastjson.JSONObject;
import com.huaxia.hx_sell_commission.domain.*;
import com.huaxia.hx_sell_commission.enums.SettleEnum;
import com.huaxia.hx_sell_commission.service.*;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.ExcelUtil;
import com.huaxia.hx_sell_commission.utils.page.TableDataInfo;
import com.huaxia.hx_sell_commission.vo.ExamineBillVo;
import com.huaxia.hx_sell_commission.vo.SettleBillVo;
import com.huaxia.hx_sell_commission.vo.SettlebillPaydetailsVo;
import com.huaxia.hx_sell_commission.vo.TradeVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.iterators.EntrySetMapIterator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.springframework.web.bind.annotation.*;

import java.util.*;

/**
 * 描述:
 * 结算单接口信息Controller
 * @author: zcj
 * @Date: 2020/11/30 15:43
 */
@RestController
@RequestMapping("/api/settlebill")
@Api(tags = "结算单接口信息")
@Slf4j
public class SettleBillController extends BaseController{

    @Autowired
    private SettlebillService settlebillService;

    /**
     * 结算单管理
     * @param settleBillVo
     * @return
     */
    @GetMapping("/settleBillShow")
    @ApiOperation(value = "结算单管理")
    public TableDataInfo settleBillShow(SettleBillVo settleBillVo){
        log.info("\n 结算单管理[/settlebill/settleBillShow]请求参数：{}", JSONObject.toJSON(settleBillVo));
        // startPage();
        List<SettleBillVo> list=settlebillService.settleBillShow(settleBillVo);
        log.info("\n 结算单管理[/settlebill/settleBillShow]请求参数：{}", JSONObject.toJSON(list));
        return getDataTable(list);
    }

    /**
     * 查询结算单中核算单
     * @param examineBillVo
     * @return
     */
    @GetMapping("/settlebillDetails")
    @ApiOperation(value = "查询结算单中核算单")
    public TableDataInfo settlebillDetails(ExamineBillVo examineBillVo){
        log.info("\n 查询结算单中核算单[/settlebill/settlebillDetails]请求参数：{}", JSONObject.toJSON(examineBillVo));
        startPage();
        List<ExamineBill> list=settlebillService.ExamineBilDetails(examineBillVo);
        return getDataTable(list);
    }

    /**
     * 查询结算单是否存在并添加结算单名称
     * @param settleBillVo
     * @return
     */
    @PostMapping("/selectSettlebillByName")
    @ApiOperation(value = "查询结算单是否存在并添加结算单名称")
    public AjaxResult settlebillexits(@RequestBody SettleBillVo settleBillVo){
        log.info("\n 查询结算单是否存在并添加结算单名称[/settlebill/selectSettlebillByName]请求参数：{}", JSONObject.toJSON(settleBillVo));
        return settlebillService.settlebillexits(settleBillVo);
    }

    /**
     * 新增/编辑结算单回显
     * @return
     */
    @PostMapping("/settleBillPayDetailsShow0")
    @ApiOperation(value = "新增/编辑结算单回显")
    public AjaxResult settleBillPayDetailsShow0(@RequestBody SettleBillVo settleBillVo){
        log.info("\n 新增/编辑结算单回显[/settlebill/settleBillPayDetailsShow0]请求参数：{}", JSONObject.toJSON(settleBillVo));
        Map<String, Object> map = settlebillService.settleBillPayDetailsShow0(settleBillVo);
        log.info("\n 新增/编辑结算单回显[/settlebill/settleBillPayDetailsShow0]请求参数：{}", JSONObject.toJSON(map));
        return AjaxResult.success("结算单中核算单展示带交易id", map);
    }

    /**
     * 新增结算单及结算单中核算单
     */
    @PostMapping("/add")
    @ApiOperation(value = "新增结算单及结算单中核算单")
    public AjaxResult add(@RequestBody SettleBillVo settleBillVo) {
        log.info("\n 新增结算单及结算单中核算单[/settlebill/add]请求参数：{}", JSONObject.toJSON(settleBillVo));
        return settlebillService.insertSettlebill(settleBillVo);
    }

    /**
     * 新增结算单交易条目及明细
     */
    @PostMapping("/addTrade")
    @ApiOperation(value = "新增结算单交易条目及明细")
    public AjaxResult addTrade(@RequestBody List<SettleBillVo> settleBillVo) {
        log.info("\n 新增结算单交易条目及明细[/settlebill/addTrade]请求参数：{}", JSONObject.toJSON(settleBillVo));
        return settlebillService.insertSettlebillTrade(settleBillVo);
    }

    /**
     * 新增结算单明细（补充银行卡）
     */
    @PostMapping("/addPayDetails")
    @ApiOperation(value = "新增结算单明细（补充银行卡）")
    public AjaxResult addPayDetails(@RequestBody SettleBillVo settleBill) {
        log.info("\n 新增结算单明细（银行卡）[/settlebill/addPayDetails]请求参数：{}", JSONObject.toJSON(settleBill));
        return settlebillService.insertSettlebillPayDetails(settleBill);
    }

    /**
     * 选择交易条目-结算单人员结算明细
     * @return
     */
    @PostMapping("/settlebillTradeShow")
    @ApiOperation(value = "选择交易条目-结算单人员结算明细")
    public AjaxResult settlebillTradeShow(@RequestBody SettleBillVo settleBillVo){
        log.info("\n 选择交易条目-结算单人员结算明细[/settlebill/settlebillTradeShow]请求参数：{}", JSONObject.toJSON(settleBillVo));
        List<TradeVo> list=settlebillService.settlebillTradeShow(settleBillVo);
        return AjaxResult.success(list);
    }

    /**
     * 编辑结算单回显/查询结算单明细/查看结算单/审核结算单展示
     * @return
     */
    @PostMapping("/settleBillPayDetailsShow")
    @ApiOperation(value = "编辑结算单回显/查询结算单明细/查看结算单/审核结算单展示")
    public TableDataInfo settleBillPayDetailsShow(@RequestBody SettlebillPaydetailsVo settleBillVo){
        log.info("\n 编辑结算单回显/查询结算单明细/查看结算单/审核结算单展示[/settlebill/settleBillPayDetailsShow]请求参数：{}", JSONObject.toJSON(settleBillVo));
        List<SettlebillPaydetailsVo> list=settlebillService.settleBillPayDetailsShow(settleBillVo);
        return getDataTable(list);
    }

    /**
     * 修改结算单
     */
    @PostMapping("/edit")
    @ApiOperation(value = "修改结算单")
    public AjaxResult edit(@RequestBody SettleBillVo settlebillVo) {
        log.info("\n 修改结算单[/settlebill/edit]请求参数：{}", JSONObject.toJSON(settlebillVo));
        return toAjax(settlebillService.updateSettlebill(settlebillVo));
    }

    /**
     * 审核中
     * @param settleBillVo
     * @return
     */
    @PostMapping("/updateFlowerStatus")
    @ApiOperation(value = "审核中")
    public AjaxResult updateFlowerStatus(@RequestBody SettleBillVo settleBillVo){
        settleBillVo.setFlowstatus(SettleEnum.ThirdStatus.STATUS_S.getCode());
        return toAjax(settlebillService.updateSettlebillFlowStatus(settleBillVo));
    }

    /**
     * 删除结算单
     */
    @GetMapping("/delete/{settleid}")
    @ApiOperation(value = "删除结算单")
    public AjaxResult delete(@PathVariable String settleid) {
        log.info("\n 删除结算单[/settlebill/remove/{settleid}]请求参数：{}", JSONObject.toJSON(settleid));
        return settlebillService.deleteSettlebill2(settleid);
    }

    /**
     * 作废结算单
     */
    @GetMapping("/remove/{settleid}")
    @ApiOperation(value = "作废结算单")
    public AjaxResult remove(@PathVariable String settleid) {
        log.info("\n 作废结算单[/settlebill/remove/{settleid}]请求参数：{}", JSONObject.toJSON(settleid));
        return settlebillService.deleteSettlebill(settleid);
    }

    /**
     * 删除结算单中的核算单
     */
    @GetMapping("/deleteEmail")
    @ApiOperation(value = "删除结算单中的核算单")
    public AjaxResult remove(SettleBillVo settleBillVo) {
        log.info("\n 作废结算单[/settlebill/deleteEmail]请求参数：{}", JSONObject.toJSON(settleBillVo));
        return settlebillService.deleteEmail(settleBillVo);
    }

}
