package com.huaxia.hx_sell_commission.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.huaxia.hx_sell_commission.utils.annotation.Excel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import javax.validation.constraints.NotNull;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 核算单 ExamineBill
 *
 * @author qjcui
 * @date 2020-11-23
 */
@Data
public class ExamineBill implements Serializable {

        /*
     *  @Null    被注释的元素必须为 null
        @NotNull     被注释的元素必须不为 null
        @AssertTrue  被注释的元素必须为 true
        @AssertFalse     被注释的元素必须为 false
        @Min(value)  被注释的元素必须是一个数字，其值必须大于等于指定的最小值
        @Max(value)  被注释的元素必须是一个数字，其值必须小于等于指定的最大值
        @DecimalMin(value)   被注释的元素必须是一个数字，其值必须大于等于指定的最小值
        @DecimalMax(value)   被注释的元素必须是一个数字，其值必须小于等于指定的最大值
        @Size(max, min)  被注释的元素的大小必须在指定的范围内
        @Digits (integer, fraction)  被注释的元素必须是一个数字，其值必须在可接受的范围内
        @Past    被注释的元素必须是一个过去的日期
        @Future  被注释的元素必须是一个将来的日期

     *
     *
     * message属性  验证失败提示的信息
     *
     */

    /** 核算单ID*/
    @Excel(name = "核算单ID")
    @ApiModelProperty(value = "核算单ID")
    private  String examineId;

    /** 核算单名称 */
    @Excel(name = "核算单名称")
    @ApiModelProperty(value = "核算单名称")
    @NotNull
    private  String examineName;

    /** 状态 201草稿 202作废 203待审核 204通过 205驳回 */
    @Excel(name = "状态")
    @ApiModelProperty(value = "状态")
    private  Integer status;

    /** 核算单总金额 */
    @Excel(name = "核算单总金额")
    @ApiModelProperty(value = "核算单总金额")
    private BigDecimal total;

    /** 审核人 */
    @Excel(name = "审核人")
    @ApiModelProperty(value = "审核人")
    private  String approve;

    /** 审核人ID */
    @Excel(name = "审核人ID")
    @ApiModelProperty(value = "审核人ID")
    private  String approveId;

    /** 审核时间 */
    @Excel(name = "审核时间")
    @ApiModelProperty(value = "审核时间")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date approveDate;

    /** 作废人 */
    @Excel(name = "作废人")
    @ApiModelProperty(value = "作废人")
    private  String cancel;

    /** 作废人ID */
    @Excel(name = "作废人ID")
    @ApiModelProperty(value = "作废人ID")
    private  String cancelId;

    /** 作废时间 */

    @Excel(name = "作废时间")
    @ApiModelProperty(value = "作废时间")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date cancelDate;

    /** 创建人ID */
    @Excel(name = "创建人ID")
    @ApiModelProperty(value = "创建人ID")
    private String createId;

    /** 创建时间 */
    @Excel(name = "创建时间")
    @ApiModelProperty(value = "创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date createDate;

    /** 创建人 */
    @Excel(name = "创建人")
    @ApiModelProperty(value = "创建人")
    private String create;

    /** 公司id */
    @Excel(name = "公司id")
    @ApiModelProperty(value = "公司id")
    private String companyGuid;

    /** 公司名 */
    @Excel(name = "公司名")
    @ApiModelProperty(value = "公司名")
    private String companyName;

    /** 项目id */
    @Excel(name = "项目id")
    @ApiModelProperty(value = "项目id")
    private String hxProjectId;

    /** 项目名称 */
    @Excel(name = "项目名称")
    @ApiModelProperty(value = "项目名称")
    private String hxProjectName;

    /** 提交人id */
    @Excel(name = "提交人id")
    @ApiModelProperty(value = "提交人id")
    private String submitterId;

    /** 提交人时间 */
    @Excel(name = "提交人时间")
    @ApiModelProperty(value = "提交人时间")
    private Date submitterDate;

    /** 提交人 */
    @Excel(name = "提交人")
    @ApiModelProperty(value = "提交人")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private String submitter;


    //==================非数据库字段==============================
    /** 项目名称 */
    @ApiModelProperty(value = "项目名称")
    private String projName;

    /** 交易id的集合 */
    @ApiModelProperty(value = "交易id的集合")
    private List<String> tradeGUIDS;

    /** 佣金明细ID */
    @ApiModelProperty(value = "佣金明细ID")
    private List<String> payId;

    /** 状态变更时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @ApiModelProperty(value = "状态变更时间")
    private Date updatedate;

    /** 状态变更原因 */
    @ApiModelProperty(value = "状态变更原因")
    private String updatereason;

    @ApiModelProperty(value = "创建开始时间")
    private Date startDate;

    @ApiModelProperty(value = "创建结束时间")
    private Date endDate;

    @ApiModelProperty(value = "交易ID")
    private String tradeguid;

    @ApiModelProperty(value = "佣金明细集合")
    private List<Paymentdetails> paymentdetails;

    @ApiModelProperty(value = "是否勾选")
    private String isChecked;

    @ApiModelProperty(value = "按钮")
    private List<String> button;

    /** 统计视图数据生成状态 */
    private  Integer reportstatus;
}
