package com.huaxia.hx_sell_commission.filter;

import com.alibaba.fastjson.serializer.ValueFilter;
import com.huaxia.hx_sell_commission.enums.SensitiveTypeEnum;
import com.huaxia.hx_sell_commission.utils.DesensitizedUtils;
import com.huaxia.hx_sell_commission.utils.annotation.Desensitized;
import lombok.extern.slf4j.Slf4j;

import java.lang.reflect.Field;

/**
 * 在fastjson中使用此过滤器进行脱敏操作
 */
@Slf4j
public class ValueDesensitizeFilter implements ValueFilter {

    @Override
    public Object process(Object object, String name, Object value) {
        if (null == value || !(value instanceof String) || ((String) value).length() == 0) {
            return value;
        }
        try {
            Field field = object.getClass().getDeclaredField(name);
            Desensitized desensitization;
            if (String.class != field.getType() || (desensitization = field.getAnnotation(Desensitized.class)) == null) {
                return value;
            }
            String valueStr = (String) value;
            SensitiveTypeEnum type = desensitization.type();
            switch (type) {
                case ID_CARD:
                    return DesensitizedUtils.idCardNum(valueStr);
                default:
            }
        } catch (Exception e) {
//            log.error("当前数据类型为{},值为{}", object.getClass(), value);
            return value;
        }
        return value;

    }

}
