package com.huaxia.hx_sell_commission.service.impl;

import cn.hutool.core.util.StrUtil;
import com.cfld.sso.client.servlet.SsoUserUtil;
import com.huaxia.hx_sell_commission.domain.csm.*;
import com.huaxia.hx_sell_commission.mapper.db2.*;
import com.huaxia.hx_sell_commission.utils.redis.RedisCache;
import com.huaxia.hx_sell_commission.vo.CsmSUserVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.huaxia.hx_sell_commission.service.ICsmSUserService;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Service业务层处理
 * 
 * @author shilei
 * @date 2020-11-16
 */
@Service
@Slf4j
public class CsmSUserServiceImpl implements ICsmSUserService 
{
    @Autowired
    private CsmSUserMapper csmSUserMapper;

    @Autowired
    private CsmSMenusMapper csmSMenusMapper;

    @Autowired
    private CsmSMenufunctionMapper csmSMenufunctionMapper;

    @Autowired
    private CsmSProjectMapper csmSProjectMapper;

    @Autowired
    private CsmSMyprojectMapper csmSMyprojectMapper;

    @Autowired
    private CsmSOrganizationMapper csmSOrganizationMapper;

    @Autowired
    private HttpServletRequest request;

    @Autowired
    private RedisCache redisCache;

    /**
     * 获取用户详细信息
     *
     * @return CsmSUser
     */
    @Override
    public CsmSUser selectCsmSUserByUserName() {
        String userName = SsoUserUtil.getCurrentUser(request);
//        userName = "yuanchangling";
        log.info("\n 获取用户详细信息>>>>>>>>>>>>>>>>>登录用户userName:{}", userName);
        if(StrUtil.isBlank(userName)){
            return null;
        }
        // 从缓存中获取
//        CsmSUser csmSUser = redisCache.getCacheObject(Constants.SELL_USER + userName);
//        if(csmSUser != null){
//            return csmSUser;
//        }
        // 查询用户基本信息
        CsmSUser csmSUser = csmSUserMapper.selectCsmSUserByUserName(userName);
//        if(csmSUser != null){
//            // 重新添加缓存
//            redisCache.setCacheObject(Constants.SELL_USER + userName, csmSUser,10, TimeUnit.MINUTES);
//        }
        return csmSUser;
    }

    /**
     * 获取单点请求头数据
     *
     * @return  map
     */
    @Override
    public Map<String, String> getloginInfo() {
        Map<String, String> map = new HashMap<>();
        map.put("userid", (String)request.getAttribute("loginid"));
        map.put("headid", (String)request.getHeader("loginid"));
        map.put("ssoMenuInfo", (String)request.getAttribute("wd_sso_menuInfo"));
        map.put("ssoMenuInfo2", (String)request.getHeader("wd_sso_menuInfo"));
        map.put("session_userid", (String)request.getSession().getAttribute("CFLD_SSO_UserName"));
        map.put("url", request.getContextPath() + "/cfld_sso_localmodel_login");
        map.put("cur_userid", SsoUserUtil.getCurrentUser(request));
        return map;
    }

    /**
     * 查询用户菜单功能权限
     *
     * @return  List<CsmSMenus>
     */
    @Override
    public Map<String, Object> selectUserMenuList() {
        Map<String, Object> map = new HashMap<>();
        String userName = SsoUserUtil.getCurrentUser(request);
//        userName = "yuanchangling";
        // 查询菜单树
        List<CsmSMenus> csmSMenusList = csmSMenusMapper.selectUserMenuList(userName);
        // 查询权限List
        List<String> menusfunctionList = csmSMenufunctionMapper.selectUserMenufunctionList(userName);
        map.put("menusList", csmSMenusList);
        map.put("buttonList", menusfunctionList);
        return map;
    }

    /**
     * 查询用户分公司列表
     *
     * @return  List<CsmSOrganization>
     */
    @Override
    public List<CsmSOrganization> userCompanyList(String examineId) {
        String userName = SsoUserUtil.getCurrentUser(request);
//        userName = "yuanchangling";
        // 查询项目列表
        List<String> projectIds = csmSProjectMapper.getProject(userName);
        return csmSOrganizationMapper.userCompanyList(projectIds, examineId);
    }

    /**
     * 查询用户分公司项目列表
     *
     * @return  List<CsmSOrganization>
     */
    @Override
    public List<CsmSOrganization> userTreeList() {
        String userName = SsoUserUtil.getCurrentUser(request);
//        userName = "yuanchangling";
        // 查询项目列表
        List<String> projectIds = csmSProjectMapper.getProject(userName);
        return csmSOrganizationMapper.userTreeList(projectIds);
    }

    /**
     * 根据公司ID查询用户项目列表
     *
     * @return  List<CsmSProject>
     */
    @Override
    public List<CsmSProject> userProjectList(String buguId, String examineId) {
        String userName = SsoUserUtil.getCurrentUser(request);
//        userName = "yuanchangling";
        // 查询项目列表
        List<String> projectIds = csmSProjectMapper.getProject(userName);
        return csmSProjectMapper.userProjectList(projectIds, buguId, examineId);
    }

    /**
     * 根据项目ID查询用户项目分期列表
     *
     * @return  List<CsmSMyproject>
     */
    @Override
    public List<CsmSMyproject> projGUList(String projectId) {
        return csmSMyprojectMapper.projGUList(projectId);
    }

    /**
     * 根据项目ID查询用户列表
     * @Param csmSUser
     * @return List<CsmSUser>
     */
    @Override
    public List<CsmSUser> getUserByProjectId(CsmSUserVo csmSUserVo) {
        return csmSUserMapper.getUserByProjectId(csmSUserVo);
    }

}
