package com.huaxia.hx_sell_commission.service.impl;

import java.io.*;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;
import java.util.stream.Collectors;

import cn.hutool.core.io.resource.ClassPathResource;
import cn.hutool.core.lang.UUID;
import cn.hutool.core.util.IdUtil;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.huaxia.hx_sell_commission.constant.Constants;
import com.huaxia.hx_sell_commission.domain.*;
import com.huaxia.hx_sell_commission.domain.csm.CsmSUser;
import com.huaxia.hx_sell_commission.enums.ButtonEnum;
import com.huaxia.hx_sell_commission.enums.PaymenttempEnum;
import com.huaxia.hx_sell_commission.enums.PlanEnum;
import com.huaxia.hx_sell_commission.enums.SettleEnum;
import com.huaxia.hx_sell_commission.exception.CustomException;
import com.huaxia.hx_sell_commission.mapper.db1.*;
import com.huaxia.hx_sell_commission.mapper.db2.CsmSProjectMapper;
import com.huaxia.hx_sell_commission.mapper.db3.BusinessDetailMapper;
import com.huaxia.hx_sell_commission.service.ICsmSUserService;
import com.huaxia.hx_sell_commission.service.IPlanService;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.MoneyUtils;
import com.huaxia.hx_sell_commission.utils.StringUtils;
import com.huaxia.hx_sell_commission.vo.*;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.ss.util.CellRangeAddress;
import org.apache.poi.ss.util.RegionUtil;
import org.apache.poi.xssf.usermodel.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.huaxia.hx_sell_commission.service.IPaymenttempService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;

import javax.swing.filechooser.FileSystemView;

import static java.util.stream.Collectors.groupingBy;


/**
 * Service业务层处理
 *
 * @author shilei
 * @date 2020-11-16
 */
@Service
@Slf4j
public class PaymenttempServiceImpl implements IPaymenttempService {
    @Autowired
    private PaymenttempMapper paymenttempMapper;

    @Autowired
    private PaynodeMapper paynodeMapper;

    @Autowired
    private PlanMapper planMapper;

    @Autowired
    private IPlanService planService;

    @Autowired
    private PaymenttempNodeMapper paymenttempNodeMapper;

    @Autowired
    private PaymentdetailsMapper paymentdetailsMapper;

    @Autowired
    private PaymentdetailsLogMapper paymentdetailsLogMapper;

    @Autowired
    private PaymenttempFileMapper paymenttempFileMapper;

    @Autowired
    private PaymenttempDistributionMapper paymenttempDistributionMapper;

    @Autowired
    private BusinessDetailMapper businessDetailMapper;

    @Autowired
    private TradeMapper tradeMapper;

    @Autowired
    private UsertypeMapper usertypeMapper;

    @Autowired
    private ICsmSUserService csmSUserService;

    @Autowired
    private ExamineReportDetailsMapper examineReportDetailsMapper;


    @Autowired
    private ExamineBillMapper examinebillMapper;
    /**
     * 查询支付节点
     *
     * @return
     */
    @Override
    public AjaxResult selectPayNodeList() {
        Paynode node = new Paynode();
        node.setStatus(1L);
        return new AjaxResult(Constants.SUCCESS, "查询成功", paynodeMapper.selectPaynodeList(node));
    }

    /**
     * 查询岗位类别集合
     *
     * @return
     */
    @Override
    public AjaxResult selectUserTypeList() {
        Usertype usertype = new Usertype();
        usertype.setStatus(1L);
        return new AjaxResult(Constants.SUCCESS, "查询成功", usertypeMapper.selectUsertypeList(usertype));
    }

    /**
     * 查询方案详情
     *
     * @param tempid ID
     * @return
     */
    @Override
    public Paymenttemp selectPaymenttempAllById(String tempid) {
        return paymenttempMapper.selectPaymenttempAllById(tempid);
    }

    /**
     * 查询方案列表
     *
     * @param paymenttemp
     * @return
     */
    @Override
    public List<Paymenttemp> selectPaymenttempList(Paymenttemp paymenttemp, List<String> projectIds) {
        paymenttemp.setProjectIds(projectIds);
        List<Paymenttemp> paymenttemps = paymenttempMapper.selectPaymenttempList2(paymenttemp);
        if (paymenttemps != null && paymenttemps.size() > 0) {
            CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
//            CsmSUser csmSUser = null;
            paymenttemps.stream().forEach(p -> {
                getButtonList(p, csmSUser);
                if (PaymenttempEnum.PlanStatus.STATUS_STOP_USING.getCode() == p.getStopUsing()) {
                    p.setStatus(p.getStopUsing());
                }
            });
        }
        return paymenttemps;
    }

    /**
     * 查询按钮权限
     *
     * @param p
     * @return
     */
    private Paymenttemp getButtonList(Paymenttemp p, CsmSUser csmSUser) {
        List<String> button = new ArrayList<>();
        if (p.getStatus() != null) {
            if (PaymenttempEnum.PlanStatus.STATUS_STOP_USING.getCode() == p.getStopUsing()) { // 停用
                button.add(ButtonEnum.PlanBtn.VIEW_BTN.getCode());
            }else { // 没停用
                if (PaymenttempEnum.PlanStatus.STATUS_CG.getCode() == p.getStatus()) { // 草稿
                    if (p.getCreateuserid().equals(csmSUser != null ? csmSUser.getId() : "")) {
                        button.add(ButtonEnum.PlanBtn.UPDATE_BTN.getCode());
                    }
                } else if (PaymenttempEnum.PlanStatus.STATUS_DISABLE.getCode() == p.getStatus()) { // 禁用
                    if (p.getCreateuserid().equals(csmSUser != null ? csmSUser.getId() : "")) {
                        button.add(ButtonEnum.PlanBtn.UPDATE_BTN.getCode());
                    }
                    button.add(ButtonEnum.PlanBtn.ENABLE_BTN.getCode());
                } else if (PaymenttempEnum.PlanStatus.STATUS_ENABLE.getCode() == p.getStatus()) { // 启用
                    button.add(ButtonEnum.PlanBtn.DISABLE_BTN.getCode());
                    button.add(ButtonEnum.PlanBtn.VIEW_BTN.getCode());
                    button.add(ButtonEnum.PlanBtn.STOP_USING_BTN.getCode());
                }
            }
        }
        p.setButton(button);
        return p;
    }

    /**
     * 根据交易ID查询方案模板列表
     *
     * @param tradeguId
     * @return 集合
     */
    @Override
    public List<Paymenttemp> selectListByTradeguId(List<String> tradeguId) {
        List<Paymenttemp> paymenttemps = paymenttempMapper.selectListByTradeguId(tradeguId);
        List<Paymenttemp> collect = paymenttemps.stream().filter(paymenttemp ->
                paymenttemp.getStopUsing() != PaymenttempEnum.PlanStatus.STATUS_STOP_USING.getCode() ||
                        paymenttemp.getTempid().equals(paymenttemp.getTgtempid()) ||
                        paymenttemp.getTempid().equals(paymenttemp.getDlftempid())
        ).collect(Collectors.toList());
        return collect;
    }

    /**
     * 判断名称是否重复
     *
     * @return
     */
    private boolean checkName(Paymenttemp paymenttemp) {
        List<Paymenttemp> paymenttemps = paymenttempMapper.selectPaymenttempListByName(paymenttemp);
        return (paymenttemps == null || paymenttemps.size() < 1) ? false : true;
    }

    /**
     * 新增方案模板信息
     *
     * @param paymenttemp
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult insertPaymenttemp(Paymenttemp paymenttemp) {
        if (checkName(paymenttemp)) {
            throw new CustomException("方案模板名称重复，请修改", Constants.ERROR);
        }
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        Date date = new Date();
        // 保存方案模板信息
        paymenttemp.setTempid(IdUtil.simpleUUID());
        paymenttemp.setCreateuserid(csmSUser != null ? csmSUser.getId() : "");
        paymenttemp.setCreatedate(date);
        paymenttempMapper.insertPaymenttemp(paymenttemp);
        // 保存方案附件信息
        if (paymenttemp.getTempFiles() != null && paymenttemp.getTempFiles().size() > 0) {
            paymenttemp.getTempFiles().stream().forEach(file -> {
                PaymenttempFile f = file;
                f.setFileId(IdUtil.simpleUUID());
                f.setCreateuserid(csmSUser != null ? csmSUser.getId() : "");
                f.setFiletype(f.getFilename().split("\\.")[1]);
                f.setTempid(paymenttemp.getTempid());
                f.setCreateTime(date);
                paymenttempFileMapper.insertPaymenttempFile(f);
            });
        }
        // 保存支付节点信息
        if (paymenttemp.getNodes() == null || paymenttemp.getNodes().size() < 1) {
            log.error("支付节点不能为空");
            throw new CustomException("支付节点不能为空", Constants.ERROR);
        }

        BigDecimal count = paymenttemp.getNodes().stream().
                filter(n -> n.getPayratio() != null).map(n -> n.getPayratio()).reduce(BigDecimal.ZERO, BigDecimal::add);
        paymenttemp.getNodes().stream().forEach(node -> {
//            count.add(node.getPayratio());
            PaymenttempNode n = node;
            n.setTempid(paymenttemp.getTempid());
            paymenttempNodeMapper.insertPaymenttempNode(n);
        });
        if (count.compareTo(new BigDecimal(100)) != 0) {
            log.error("方案模板保存失败,支付节点相加不等于100%");
            throw new CustomException("方案模板保存失败,支付节点相加不等于100%", Constants.ERROR);
        }
        BigDecimal proportion = new BigDecimal(0);
        //人员分配保存
        if (paymenttemp.getDistributions() != null && paymenttemp.getDistributions().size() > 0) {
            paymenttemp.getDistributions().stream().forEach(d -> {
//                proportion.addAndGet(d.getPayratio().longValue());
                PaymenttempDistribution dis = d;
                if ((d.getSfratio() != null ? d.getSfratio().longValue() : 0L) +
                        (d.getMfratio() != null ? d.getMfratio().longValue() : 0L) != 100) {
                    log.error("首批+末批不等于100");
                    throw new CustomException("首批+末批不等于100", Constants.ERROR);
                }
                dis.setTempid(paymenttemp.getTempid());
                dis.setStatus(1L);
//                if(StrUtil.isBlank(dis.getUser()) || StrUtil.isBlank(dis.getUserid())){
//                    throw new CustomException("引入人员信息不能为空", Constants.ERROR);
//                }
                paymenttempDistributionMapper.insertPaymenttempDistribution(dis);
            });
            proportion = paymenttemp.getDistributions().stream().
                    filter(d -> d.getPayratio() != null).map(d -> d.getPayratio()).reduce(BigDecimal.ZERO, BigDecimal::add);
        }

        if (null != paymenttemp.getFixedratio()) {
            proportion = proportion.add(paymenttemp.getFixedratio());
        }
        if (null != paymenttemp.getNopay()) {
            proportion = proportion.add(paymenttemp.getNopay());
        }
        if (proportion.compareTo(new BigDecimal(100)) != 0) {
            log.error("人员分配总额度不等于100");
            throw new CustomException("人员分配总额度不等于100", Constants.ERROR);
        }
        return new AjaxResult(Constants.SUCCESS, "保存成功");
    }

    /**
     * 修改方案模板信息
     *
     * @param paymenttemp
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult updatePaymenttemp(Paymenttemp paymenttemp) {
        Paymenttemp paymenttemp1 = paymenttempMapper.selectPaymenttempById(paymenttemp.getTempid());
        if (paymenttemp1 != null && paymenttemp1.getStopUsing() != null && paymenttemp1.getStopUsing() == PaymenttempEnum.PlanStatus.STATUS_STOP_USING.getCode()) {
            log.error("模板停用，不能编辑");
            throw new CustomException("模板停用，不能编辑", Constants.ERROR);
        }
        if (checkName(paymenttemp)) {
            throw new CustomException("方案模板名称重复，请修改", Constants.ERROR);
        }
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        Date date = new Date();
        // 修改方案模板信息
        paymenttemp.setUpdateuserid(csmSUser != null ? csmSUser.getId() : "");
        paymenttemp.setUpdatedate(date);
        paymenttempMapper.updatePaymenttemp(paymenttemp);
        // 修改方案附件信息
        // 删除历史附件
        paymenttempFileMapper.deletePaymenttempFileById(paymenttemp.getTempid());
        // 添加新附件
        if (paymenttemp.getTempFiles() != null && paymenttemp.getTempFiles().size() > 0) {
            paymenttemp.getTempFiles().stream().forEach(file -> {
                PaymenttempFile f = file;
                f.setFileId(IdUtil.simpleUUID());
                f.setCreateuserid(csmSUser != null ? csmSUser.getId() : "");
                f.setFiletype(f.getFilename().split("\\.")[1]);
                f.setTempid(paymenttemp.getTempid());
                f.setCreateTime(date);
                paymenttempFileMapper.insertPaymenttempFile(f);
            });
        }
        // 修改支付节点信息
        if (paymenttemp.getNodes() == null || paymenttemp.getNodes().size() < 1) {
            log.error("支付节点不能为空");
            throw new CustomException("支付节点不能为空", Constants.ERROR);
        }
        // 删除原支付节点
        paymenttempNodeMapper.deletePaymenttempNodeById(paymenttemp.getTempid());
        // 添加新支付节点
        BigDecimal count = paymenttemp.getNodes().stream().
                filter(n -> n.getPayratio() != null).map(n -> n.getPayratio()).reduce(BigDecimal.ZERO, BigDecimal::add);
        paymenttemp.getNodes().stream().forEach(node -> {
//            count.addAndGet(node.getPayratio().longValue());
            PaymenttempNode n = node;
            n.setTempid(paymenttemp.getTempid());
            paymenttempNodeMapper.insertPaymenttempNode(n);
        });
        if (count.compareTo(new BigDecimal(100)) != 0) {
            log.error("方案模板保存失败,支付节点相加不等于100%");
            throw new CustomException("方案模板保存失败,支付节点相加不等于100%", Constants.ERROR);
        }
        // 删除人员分配信息
        PaymenttempDistribution distribution = new PaymenttempDistribution();
        distribution.setTempid(paymenttemp.getTempid());
        distribution.setStatus(0L);
        paymenttempDistributionMapper.deleteTempUser(distribution);

        BigDecimal proportion = new BigDecimal(0);
        //保存新人员分配信息
        if (paymenttemp.getDistributions() != null && paymenttemp.getDistributions().size() > 0) {
            paymenttemp.getDistributions().stream().forEach(d -> {
                PaymenttempDistribution dis = d;
                if ((d.getSfratio() != null ? d.getSfratio().longValue() : 0L) +
                        (d.getMfratio() != null ? d.getMfratio().longValue() : 0L) != 100) {
                    log.error("首批+末批不等于100");
                    throw new CustomException("首批+末批不等于100", Constants.ERROR);
                }
                dis.setTempid(paymenttemp.getTempid());
                dis.setStatus(1L);
                paymenttempDistributionMapper.insertPaymenttempDistribution(dis);
            });
//            for (PaymenttempDistribution distribution1 : paymenttemp.getDistributions()) {
//                proportion.addAndGet(distribution1.getPayratio().longValue());
//            }
            proportion = paymenttemp.getDistributions().stream().
                    filter(d -> d.getPayratio() != null).map(d -> d.getPayratio()).reduce(BigDecimal.ZERO, BigDecimal::add);
        }
        if (null != paymenttemp.getFixedratio()) {
            proportion = proportion.add(paymenttemp.getFixedratio());
        }
        if (null != paymenttemp.getNopay()) {
            proportion = proportion.add(paymenttemp.getNopay());
        }
        if (proportion.compareTo(new BigDecimal(100)) != 0) {
            log.error("人员分配总额度不等于100");
            throw new CustomException("人员分配总额度不等于100", Constants.ERROR);
        }
        return new AjaxResult(Constants.SUCCESS, "修改成功");
    }

    /**
     * 启用、停用接口
     *
     * @param paymenttemp
     * @return 结果
     */
    @Override
    public int updateStatus(Paymenttemp paymenttemp) {
        Paymenttemp paymenttemp1 = paymenttempMapper.selectPaymenttempById(paymenttemp.getTempid());
        if (paymenttemp1 != null && paymenttemp1.getStopUsing() != null && paymenttemp1.getStopUsing() == PaymenttempEnum.PlanStatus.STATUS_STOP_USING.getCode()) {
            log.error("模板停用，不能启用或禁用");
            throw new CustomException("模板停用，不能启用或禁用", Constants.ERROR);
        }
        if (PaymenttempEnum.PlanStatus.STATUS_DISABLE.getCode() == paymenttemp.getStatus()) {
            // 禁用判断模板是否被使用
            Plan plan = new Plan();
            plan.setDlftempid(paymenttemp.getTempid());
            plan.setStatus(PlanEnum.PlanStatus.STATUS_ZF.getCode()); // 作废
            List<Plan> plans = planMapper.selectPlanListById(plan);
            if (plans != null && plans.size() > 0) {
                log.error("模板使用中，不能禁用");
                throw new CustomException("模板使用中，不能禁用", Constants.ERROR);
            }
        }
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        paymenttemp.setUpdatedate(new Date());
        paymenttemp.setUpdateuserid(csmSUser != null ? csmSUser.getId() : "");
        return paymenttempMapper.updatePaymenttemp(paymenttemp);
    }

    /**
     * 停用接口
     *
     * @param paymenttemp
     * @return 结果
     */
    @Override
    public int stopUsing(Paymenttemp paymenttemp) {
        if (StringUtils.isNotNull(paymenttemp.getTempid()) && PaymenttempEnum.PlanStatus.STATUS_STOP_USING.getCode() == paymenttemp.getStopUsing()) {
            Paymenttemp paymenttemp1 = new Paymenttemp();
            paymenttemp1.setTempid(paymenttemp.getTempid());
            paymenttemp1.setStopUsing(paymenttemp.getStopUsing());
            CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
            paymenttemp1.setUpdatedate(new Date());
            paymenttemp1.setUpdateuserid(csmSUser != null ? csmSUser.getId() : "");
            return paymenttempMapper.updatePaymenttemp(paymenttemp1);
        }
        return 0;
    }

    /**
     * 删除单个人员分配信息
     *
     * @param tempid 方案模板ID
     * @param userid 人员ID
     * @return 结果
     */
    @Override
    public int deleteTempUser(String tempid, String userid) {
        PaymenttempDistribution d = new PaymenttempDistribution();
        d.setTempid(tempid);
        d.setUserid(userid);
        d.setStatus(0L);
        return paymenttempDistributionMapper.deleteTempUser(d);
    }

    /**
     * 电商项目详细
     *
     * @param yxGroupFeePlan
     * @return
     */
    @Override
    public List<YxGroupFeePlan> selectProjectList(YxGroupFeePlan yxGroupFeePlan) {
        List<YxGroupFeePlan> list = businessDetailMapper.selectProjectList(yxGroupFeePlan);
        return list;
    }


    /**
     * 根据交易id查明细
     *
     * @param tradeIds
     * @return
     */
    @Override
    public List<TradeVo> selectPaymenttempAllByTradeId(List<String> tradeIds) {
//        List<TradeVo> list = paymentdetailsMapper.selectPaymentdetailsByTradeIds(tradeIds);
        List<TradeVo> list = tradeMapper.selectPaymentdetailsByTradeIdsShow(tradeIds);
        for (TradeVo tradeVo : list) {
            BigDecimal tSettled = new BigDecimal(0);
            BigDecimal dSettled = new BigDecimal(0);
            PlanVo planVo = tradeVo.getPlanVo();
            List<PaymentdetailsVo> paymentdetails = planVo.getPaymentdetails();
            List<PaymentdetailsVo> paymentdetails1 = new ArrayList<>();
            for (PaymentdetailsVo paymentdetail : paymentdetails) {
                if (paymentdetail.getStatusDetail() != null && paymentdetail.getStatusDetail().equals(PlanEnum.PaymentDetailsStatusDetail.STATUS_301.getCode())) {
                    if (paymentdetail.getPlantype().equals(1L)) {
                        tSettled = tSettled.add(paymentdetail.getPayable() == null ? paymentdetail.getPaytotal() : paymentdetail.getPayable());
                    } else {
                        dSettled = dSettled.add(paymentdetail.getPayable() == null ? paymentdetail.getPaytotal() : paymentdetail.getPayable());
                    }
                    PaymentdetailsVo paymentdetailsVoF = new PaymentdetailsVo();
                    paymentdetailsVoF.setStatusDetail(paymentdetail.getStatusDetail());
                    paymentdetailsVoF.setNodeTotalAmount(paymentdetail.getNodeTotalAmount());
                    paymentdetailsVoF.setStatus(paymentdetail.getStatus());
                    paymentdetailsVoF.setIsChecked(paymentdetail.getIsChecked());
                    paymentdetailsVoF.setPayid(paymentdetail.getPayid());
                    paymentdetailsVoF.setUpdatereason(paymentdetail.getUpdatereason());
                    paymentdetailsVoF.setPlanid(paymentdetail.getPlanid());
                    paymentdetailsVoF.setUpdatedate(paymentdetail.getUpdatedate());
                    paymentdetailsVoF.setJobname(paymentdetail.getJobname());
                    paymentdetailsVoF.setNodeid(paymentdetail.getNodeid());
                    paymentdetailsVoF.setNodename(paymentdetail.getNodename());
                    paymentdetailsVoF.setPaybatch(paymentdetail.getPaybatch());
                    paymentdetailsVoF.setIsDeficit("1");
                    paymentdetailsVoF.setPlantype(paymentdetail.getPlantype());
                    paymentdetailsVoF.setTradeguid(paymentdetail.getTradeguid());
                    paymentdetailsVoF.setUser(paymentdetail.getUser());
                    paymentdetailsVoF.setUserid(paymentdetail.getUserid());
                    paymentdetailsVoF.setUsertypeid(paymentdetail.getUsertypeid());
                    paymentdetailsVoF.setUsertypename(paymentdetail.getUsertypename());
                    if (paymentdetail.getPayable() != null) {
                        paymentdetailsVoF.setPayable(paymentdetail.getPayable().multiply(new BigDecimal(-1)).setScale(2, RoundingMode.HALF_EVEN));
                        paymentdetailsVoF.setPaytotal(paymentdetail.getPaytotal());
                    } else {
                        paymentdetailsVoF.setPaytotal(paymentdetail.getPaytotal().multiply(new BigDecimal(-1)).setScale(2, RoundingMode.HALF_EVEN));
                    }
                    paymentdetails1.add(paymentdetailsVoF);
                } else {
                    paymentdetails.remove(paymentdetail);
                }

            }

            Map<Long, List<PaymentdetailsVo>> map = paymentdetails.stream().collect(groupingBy(PaymentdetailsVo::getPlantype));
            map.entrySet().forEach(m -> {
                Map<String, List<PaymentdetailsVo>> collect = m.getValue().stream().collect(groupingBy(PaymentdetailsVo::getNodeid));
                collect.entrySet().forEach(p -> {
                    BigDecimal sum = new BigDecimal(0);
                    for (PaymentdetailsVo paymentdetailsVo : p.getValue()) {
                        sum = sum.add(paymentdetailsVo.getPayable() == null ? paymentdetailsVo.getPaytotal() : paymentdetailsVo.getPayable());
                    }
                    for (PaymentdetailsVo paymentdetailsVo : p.getValue()) {
                        paymentdetailsVo.setNodeTotalAmount(sum);
                    }
                });
            });

            Map<Long, List<PaymentdetailsVo>> map1 = paymentdetails1.stream().collect(groupingBy(PaymentdetailsVo::getPlantype));
            map1.entrySet().forEach(m -> {
                Map<String, List<PaymentdetailsVo>> collect = m.getValue().stream().collect(groupingBy(PaymentdetailsVo::getNodeid));
                collect.entrySet().forEach(p -> {
                    BigDecimal sum = new BigDecimal(0);
                    for (PaymentdetailsVo paymentdetailsVo : p.getValue()) {
                        sum = sum.add(paymentdetailsVo.getPayable() == null ? paymentdetailsVo.getPaytotal() : paymentdetailsVo.getPayable());
                    }
                    for (PaymentdetailsVo paymentdetailsVo : p.getValue()) {
                        paymentdetailsVo.setNodeTotalAmount(sum);
                    }
                });
            });
            paymentdetails.addAll(paymentdetails1);
            planVo.setDSettled(dSettled);
            planVo.setTSettled(tSettled);
        }
        return list;
    }

    /**
     * 提交
     *
     * @param tradeIds
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int checkOutSubmit(List<String> tradeIds) {
        List<TradeVo> list = paymentdetailsMapper.selectPaymentdetailsByTradeIds(tradeIds);
        List<Paymentdetails> paymentdetailsList = new ArrayList<>();
        List<PaymentdetailsLog> paymentdetailsListLog = new ArrayList<>();
        for (TradeVo trade1 : list) {
            for (Paymentdetails paymentdetail : trade1.getPaymentdetailsList()) {
                if (paymentdetail.getStatusDetail().equals(PlanEnum.PaymentDetailsStatusDetail.STATUS_301.getCode())) {
                    Paymentdetails paymentdetails = new Paymentdetails();
                    paymentdetails.setUsertypename(paymentdetail.getUsertypename());
                    paymentdetails.setUser(paymentdetail.getUser());
                    paymentdetails.setStatus(paymentdetail.getStatus());
                    paymentdetails.setUsertypeid(paymentdetail.getUsertypeid());
                    paymentdetails.setUserid(paymentdetail.getUserid());
                    paymentdetails.setTradeguid(paymentdetail.getTradeguid());
                    paymentdetails.setPlantype(paymentdetail.getPlantype());
                    paymentdetails.setPaybatch(paymentdetail.getPaybatch());
                    paymentdetails.setPaytotal(paymentdetail.getPaytotal());
                    paymentdetails.setNodeid(paymentdetail.getNodeid());
                    paymentdetails.setNodename(paymentdetail.getNodename());
                    paymentdetails.setJobname(paymentdetail.getJobname());
                    paymentdetails.setUpdatedate(new Date());
                    paymentdetails.setUpdatereason("退房结算提交");
                    paymentdetails.setPayid(UUID.randomUUID().toString().replace("-", ""));
                    paymentdetails.setPaytotal(paymentdetail.getPayable() == null ? paymentdetail.getPaytotal().multiply(new BigDecimal(-1)).setScale(2, RoundingMode.HALF_EVEN) : paymentdetail.getPaytotal());
                    paymentdetails.setPayable(paymentdetail.getPayable() == null ? null : paymentdetail.getPayable().multiply(new BigDecimal(-1)).setScale(2, RoundingMode.HALF_EVEN));
                    paymentdetails.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_102.getCode());
                    paymentdetails.setPlanid(paymentdetail.getPlanid());
                    paymentdetailsList.add(paymentdetails);
                    PaymentdetailsLog paymentdetailsLog = new PaymentdetailsLog();
                    paymentdetailsLog.setUsertypename(paymentdetail.getUsertypename());
                    paymentdetailsLog.setUser(paymentdetail.getUser());
                    paymentdetailsLog.setUsertypeid(paymentdetail.getUsertypeid());
                    paymentdetailsLog.setUserid(paymentdetail.getUserid());
                    paymentdetailsLog.setTradeguid(paymentdetail.getTradeguid());
                    paymentdetailsLog.setPlantype(paymentdetail.getPlantype());
                    paymentdetailsLog.setPaybatch(paymentdetail.getPaybatch());
                    paymentdetailsLog.setPaytotal(paymentdetail.getPaytotal());
                    paymentdetailsLog.setNodeid(paymentdetail.getNodeid());
                    paymentdetailsLog.setNodename(paymentdetail.getNodename());
                    paymentdetailsLog.setJobname(paymentdetail.getJobname());
                    paymentdetailsLog.setUpdatedate(new Date());
                    paymentdetailsLog.setUpdatereason("退房结算提交");
                    paymentdetailsLog.setPaytotal(paymentdetail.getPayable() == null ? paymentdetail.getPaytotal().multiply(new BigDecimal(-1)).setScale(2, RoundingMode.HALF_EVEN) : paymentdetail.getPaytotal());
                    paymentdetailsLog.setPayid(UUID.randomUUID().toString().replace("-", ""));
                    paymentdetailsLog.setPayable(paymentdetail.getPayable() == null ? null : paymentdetail.getPayable().multiply(new BigDecimal(-1)).setScale(2, RoundingMode.HALF_EVEN));
                    paymentdetailsLog.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_102.getCode());
                    paymentdetailsLog.setPlanid(paymentdetail.getPlanid());
                    paymentdetailsLog.setStatus(paymentdetail.getStatus());
                    paymentdetailsListLog.add(paymentdetailsLog);
                }
                //暂定退房状态
                paymentdetail.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_104.getCode());
                paymentdetailsMapper.updatePaymentdetails(paymentdetail);

            }
            paymentdetailsMapper.insertPaymentdetailsList(paymentdetailsList);
            paymentdetailsLogMapper.insertPaymentdetailsLogList(paymentdetailsListLog);
        }
        //将方案状态改为退房
        tradeMapper.updateStatusByTradeIds(tradeIds);

        return 1;
    }

    /**
     * 根据详情id查
     *
     * @param examineBill
     * @return
     */
    @Override
    public List<TradeVo> selectPaymenttempAllByPayId(ExamineBill examineBill) {
        List<TradeVo> tradeVoList = paymentdetailsMapper.selectPaymenttempAllByPayId(examineBill);
        if (tradeVoList == null || tradeVoList.size() <= 0) {
            return tradeVoList;
        }
        //根据交易分组
        Map<String, List<TradeVo>> collect = tradeVoList.stream().collect(groupingBy(TradeVo::getTradeguid));
        collect.entrySet().forEach(t -> {
            t.getValue().forEach(p -> {
                //根据方案类型分组
                Map<Long, List<Paymentdetails>> map = p.getPaymentdetailsList().stream().collect(groupingBy(Paymentdetails::getPlantype));
                map.entrySet().forEach(pl -> {
                    //根据节点分组
                    Map<String, List<Paymentdetails>> nodeList = pl.getValue().stream().collect(groupingBy(Paymentdetails::getNodeid));
                    nodeList.entrySet().forEach(np -> {
                        BigDecimal nodeSum = new BigDecimal(0);
                        for (Paymentdetails paymentdetails : np.getValue()) {
                            nodeSum = nodeSum.add(paymentdetails.getPayable() == null ? paymentdetails.getPaytotal() : paymentdetails.getPayable());
                        }
                        for (Paymentdetails paymentdetails : np.getValue()) {
                            paymentdetails.setNodeTotalAmount(nodeSum);
                        }
                    });
                });
            });
        });

//        paymentdetailsMapper.selectPaymenttempAllByPayId(examineBill);
        return tradeVoList;
    }

    /**
     * 根据核算单id查看佣金明细表
     *
     * @param examineBillVo
     * @return
     */
    @Override
    public List<ExcelExamineBill> examineBillDetailsShow(ExamineBillVo examineBillVo) {
        List<TradeVo> tradeVoList = paymentdetailsMapper.workTradeByExamineBillId(examineBillVo);
        if (tradeVoList == null || tradeVoList.size() <= 0) {
            return null;
        }
        // 根据核算单id查询交易id和方案类型
        List<TradeGuidPlanType> tradeGuidPlanTypes = paymentdetailsMapper.selectTradeGuidPlanTypeByExamineId(examineBillVo);
        //根据交易分组
        Map<String, List<TradeVo>> collect = tradeVoList.stream().collect(groupingBy(TradeVo::getTradeguid));
        List<ExcelExamineBill> list = new ArrayList<>();
        collect.entrySet().forEach(c -> {
            // 根据核算单id和交易id查询本次发放佣金包金额 20210518
            ExamineBillNodeTotal nodeSumMoneyTotal1 = paymentdetailsMapper.getNodeSumMoneyTotal(examineBillVo.getExamineId(), c.getKey());
            //2021.2.19调整开始：佣金占比=方案中的人员总额/方案中的节点总额（节点为该核算单中所选节点）
            //1、根据方案查详情
            List<String> tradeguids = new ArrayList<>();
            tradeguids.add(c.getKey());
            List<TradeVo> planDetails = planService.findPlanDetails(tradeguids);
            Map<Long, List<Paymentdetails>> collect4 = planDetails.get(0).getPlanVo().getPaymentdetails().stream().collect(groupingBy(Paymentdetails::getPlantype));

            //需要方案类型和方案类型对应的节点
            Map<Long, List<String>> planTypeAndNodes = new HashMap<>();
            c.getValue().forEach(tradeVo -> {
                //根据方案类型划分
                Map<Long, List<Paymentdetails>> longListMap = tradeVo.getPaymentdetailsList().stream().collect(groupingBy(Paymentdetails::getPlantype));
                longListMap.entrySet().forEach(longListEntry -> {
                    Map<String, List<Paymentdetails>> collect1 = longListEntry.getValue().stream().collect(groupingBy(Paymentdetails::getNodeid));
                    List<String> nodes = new ArrayList<>();
                    collect1.entrySet().forEach(cl ->
                            nodes.add(cl.getKey())
                    );
                    planTypeAndNodes.put(longListEntry.getKey(), nodes);
                });
            });
            //销售代表方案佣金和
            BigDecimal[] marketerPlanMoney = new BigDecimal[]{new BigDecimal(0)};
            //销售主管方案佣金和
            BigDecimal[] executivePlanMoney = new BigDecimal[]{new BigDecimal(0)};
            //自销负责人方案佣金和
            BigDecimal[] principalPlanMoney = new BigDecimal[]{new BigDecimal(0)};
            //销售经理方案佣金和
            BigDecimal[] managerPlanMoney = new BigDecimal[]{new BigDecimal(0)};
            //后台人员方案佣金和
            BigDecimal[] stagehandPlanMoney = new BigDecimal[]{new BigDecimal(0)};
            //策划人员方案佣金和
            BigDecimal[] plannerPlanMoney = new BigDecimal[]{new BigDecimal(0)};

            // 团购
            //销售代表方案比例和
            BigDecimal[] tgmarketerPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //销售主管方案比例和
            BigDecimal[] tgexecutivePlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //自销负责人方案比例和
            BigDecimal[] tgprincipalPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //销售经理方案比例和
            BigDecimal[] tgmanagerPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //后台人员方案比例和
            BigDecimal[] tgstagehandPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //策划人员方案比例和
            BigDecimal[] tgplannerPlanRatio = new BigDecimal[]{new BigDecimal(0)};

            // 代理
            //销售代表方案比例和
            BigDecimal[] dlmarketerPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //销售主管方案比例和
            BigDecimal[] dlexecutivePlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //自销负责人方案比例和
            BigDecimal[] dlprincipalPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //销售经理方案比例和
            BigDecimal[] dlmanagerPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //后台人员方案比例和
            BigDecimal[] dlstagehandPlanRatio = new BigDecimal[]{new BigDecimal(0)};
            //策划人员方案比例和
            BigDecimal[] dlplannerPlanRatio = new BigDecimal[]{new BigDecimal(0)};

            planTypeAndNodes.entrySet().forEach(p -> {
                collect4.get(p.getKey()).forEach(c4 -> {
                    if (p.getValue().contains(c4.getNodeid())) {
                        String userTypeId = "";
                        //销售代表
                        if (c4.getUsertypeid().equals("5a58ad4a9388420bb58e408f06259295") || c4.getUsertypeid().equals("8f2fc0d6-eeb3-4d7b-9a0a-971806cb7c51")) {
                            marketerPlanMoney[0] = marketerPlanMoney[0].add(c4.getPayable() == null ? c4.getPaytotal() : c4.getPayable());

                            if (c4.getStatusDetail() > 200) {
                                userTypeId = "5a58ad4a9388420bb58e408f06259295,8f2fc0d6-eeb3-4d7b-9a0a-971806cb7c51";
                                if (1 == c4.getPlantype() && tgmarketerPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 团购费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getTgtempid(), userTypeId);

                                    Paymenttemp paymenttemp = paymenttempMapper
                                            .selectPaymenttempById(planDetails.get(0).getPlanVo().getTgtempid());

                                    tgmarketerPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    if(paymenttemp != null && paymenttemp.getFixedratio()!= null
                                            && paymenttemp.getFixedratio().compareTo(new BigDecimal(0)) == 1){
                                        tgmarketerPlanRatio[0] = tgmarketerPlanRatio[0].add(paymenttemp.getFixedratio());
                                    }
                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 1, c.getKey());
                                    tgmarketerPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/
                                } else if (2 == c4.getPlantype() && dlmarketerPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 代理费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getDlftempid(), userTypeId);

                                    Paymenttemp paymenttemp = paymenttempMapper.selectPaymenttempById(planDetails.get(0).getPlanVo().getDlftempid());

                                    dlmarketerPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    if(paymenttemp != null && paymenttemp.getFixedratio()!= null
                                            && paymenttemp.getFixedratio().compareTo(new BigDecimal(0)) == 1){
                                        dlmarketerPlanRatio[0] = dlmarketerPlanRatio[0].add(paymenttemp.getFixedratio());
                                    }

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 2, c.getKey());
                                    dlmarketerPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/
                                }

                                // 核算单id  有效的佣金明细（状态100） usertypeID plantype || nodeid
                            }
                        }
                        //销售主管
                        if (c4.getUsertypeid().equals("53f9d01b5ff24e2d8781ffd29acfd009")) {
                            executivePlanMoney[0] = executivePlanMoney[0].add(c4.getPayable() == null ? c4.getPaytotal() : c4.getPayable());

                            if (c4.getStatusDetail() > 200) {
                                userTypeId = "53f9d01b5ff24e2d8781ffd29acfd009";
                                if (1 == c4.getPlantype() && tgexecutivePlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 团购费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getTgtempid(), userTypeId);
                                    tgexecutivePlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 1, c.getKey());
                                    tgexecutivePlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/

                                } else if (2 == c4.getPlantype() && dlexecutivePlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 代理费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getDlftempid(), userTypeId);
                                    dlexecutivePlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 2, c.getKey());
                                    dlexecutivePlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/
                                }
                            }
                        }
                        //自销负责人
                        if (c4.getUsertypeid().equals("51b52b21c1bc4e6e8eaad07c44b32303")) {
                            principalPlanMoney[0] = principalPlanMoney[0].add(c4.getPayable() == null ? c4.getPaytotal() : c4.getPayable());

                            if (c4.getStatusDetail() > 200) {
                                userTypeId = "51b52b21c1bc4e6e8eaad07c44b32303";
                                if (1 == c4.getPlantype() && tgprincipalPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 团购费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getTgtempid(), userTypeId);
                                    tgprincipalPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 1, c.getKey());
                                    tgprincipalPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/

                                } else if (2 == c4.getPlantype() && dlprincipalPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 代理费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getDlftempid(), userTypeId);
                                    dlprincipalPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 2, c.getKey());
                                    dlprincipalPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/
                                }
                            }
                        }
                        //销售经理
                        if (c4.getUsertypeid().equals("7f2fc0d6-eeb3-4d7b-9a0a-971806cb7c52")) {
                            managerPlanMoney[0] = managerPlanMoney[0].add(c4.getPayable() == null ? c4.getPaytotal() : c4.getPayable());

                            if (c4.getStatusDetail() > 200) {
                                userTypeId = "7f2fc0d6-eeb3-4d7b-9a0a-971806cb7c52";
                                if (1 == c4.getPlantype() && tgmanagerPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 团购费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getTgtempid(), userTypeId);
                                    tgmanagerPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 1, c.getKey());
                                    tgmanagerPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/

                                } else if (2 == c4.getPlantype() && dlmanagerPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 代理费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getDlftempid(), userTypeId);
                                    dlmanagerPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 2, c.getKey());
                                    dlmanagerPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/
                                }
                            }
                        }
                        //后台人员
                        if (c4.getUsertypeid().equals("e58ff7b907074a539f85ec8a3f05d149")) {
                            stagehandPlanMoney[0] = stagehandPlanMoney[0].add(c4.getPayable() == null ? c4.getPaytotal() : c4.getPayable());

                            if (c4.getStatusDetail() > 200) {
                                userTypeId = "e58ff7b907074a539f85ec8a3f05d149";
                                if (1 == c4.getPlantype() && tgstagehandPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 团购费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getTgtempid(), userTypeId);
                                    tgstagehandPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 1, c.getKey());
                                    tgstagehandPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/

                                } else if (2 == c4.getPlantype() && dlstagehandPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 代理费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getDlftempid(), userTypeId);
                                    dlstagehandPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 2, c.getKey());
                                    dlstagehandPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/
                                }
                            }
                        }
                        //策划人员
                        if (c4.getUsertypeid().equals("40bde8137914415eb141cbc65356784c")) {
                            plannerPlanMoney[0] = plannerPlanMoney[0].add(c4.getPayable() == null ? c4.getPaytotal() : c4.getPayable());

                            if (c4.getStatusDetail() > 200) {
                                userTypeId = "40bde8137914415eb141cbc65356784c";
                                if (1 == c4.getPlantype() && tgplannerPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 团购费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getTgtempid(), userTypeId);
                                    tgplannerPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 1, c.getKey());
                                    tgplannerPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/

                                } else if (2 == c4.getPlantype() && dlplannerPlanRatio[0].compareTo(new BigDecimal(0)) == 0) { // 代理费
                                    BigDecimal bigDecimal = paymentdetailsMapper.selectUserTypePayRatioSum(
                                            planDetails.get(0).getPlanVo().getDlftempid(), userTypeId);
                                    dlplannerPlanRatio[0] = bigDecimal != null ? bigDecimal : new BigDecimal(0);

                                    /** 20210617 修改开始 **/
                                    BigDecimal bigDecimal1 = paymentdetailsMapper.selectPayTotalRatioSum(examineBillVo.getExamineId(), userTypeId, 2, c.getKey());
                                    dlplannerPlanRatio[0] = bigDecimal1;
                                    /** 20210617 修改结束 **/
                                }
                            }
                        }
                    }
                });
            });
            //2021.2.19调整结束（后续修改为set佣金占比）

            ExcelExamineBill excelExamineBill = new ExcelExamineBill();
            c.getValue().forEach(e -> {

                //核算单名称
                excelExamineBill.setExamineName(e.getExamineName() + "核算明细表");
                //交易id
                excelExamineBill.setTradeguid(e.getTradeguid());
                //分公司
                excelExamineBill.setOrgName(e.getOrgName());
                //认购金额
                excelExamineBill.setCjtotal(e.getCjtotal());
                //签约金额
                excelExamineBill.setRmbhttotal(e.getRmbhttotal());
                //认购时间
                excelExamineBill.setOrderQsdate(e.getOrderQsdate());
                //签约时间
                excelExamineBill.setContractQsdate(e.getContractQsdate());
                //项目名称
                excelExamineBill.setProjname(e.getProjname());
                //房间号码
                excelExamineBill.setRoominfo(e.getRoominfo());
                //报备人公司
                excelExamineBill.setReferagentname(e.getReferagentname());
                //客户姓名
                excelExamineBill.setCstname(e.getCstname());
                //团购费佣金
                excelExamineBill.setTgfee(e.getTgfee());
                /*//代理费佣金手动
                excelExamineBill.setAgentfee(e.getAgentfee());*/
                //到账金额
                excelExamineBill.setOffsetMoney(e.getOffsetMoney());
                //全款到账日期
                if (e.getIsFullOffset() == null) {
                    excelExamineBill.setLastOffsetDate(null);
                } else {
                    excelExamineBill.setLastOffsetDate(e.getIsFullOffset() == 1 ? e.getLastOffsetDate() : null);
                }
                //付款方式
                excelExamineBill.setPayFormClass(e.getPayFormClass());
                //业态
                excelExamineBill.setProductName(e.getProductName());

                List<String> tradeguidList = new ArrayList<>();
                tradeguidList.add(e.getTradeguid());

                //服务费结算标准
                List<TradeVo> regulateBrokerage2 = planService.getRegulateBrokerage2(tradeguidList, examineBillVo);
                List<Paymenttemp> paymenttemps2 = regulateBrokerage2.get(0).getPaymenttemps();
                Map<Long, List<Paymenttemp>> c3 = paymenttemps2.stream().collect(groupingBy(Paymenttemp::getPlantype));
                if (c3 != null && c3.size() > 0) {
                    if (c3.get(1L) != null) {
                        c3.get(1L).forEach(pa -> {
                            excelExamineBill.setServiceFeeSettlementStandard(pa.getServiceFeeSettlementStandard());
                        });
                    }
                }

                //交易id就一个，所以返回值就一个
                List<TradeVo> regulateBrokerage = planService.getRegulateBrokerage3(tradeguidList, examineBillVo);
                List<Paymenttemp> paymenttemps = regulateBrokerage.get(0).getPaymenttemps();
                Map<Long, List<Paymenttemp>> collect1 = paymenttemps.stream().collect(groupingBy(Paymenttemp::getPlantype));
                //获取代理费
                if (collect1 != null && collect1.size() > 0) {

                    Integer planType = null;
                    for (TradeGuidPlanType tradeGuidPlanType : tradeGuidPlanTypes) {
                        if (tradeguidList.get(0).equals(tradeGuidPlanType.getTradeGuid())) {
                            planType = tradeGuidPlanType.getPlanType();
                            break;
                        }
                    }

                    if (planType != null && planType == 1) {
                        collect1.get(1L).forEach(pa -> {
                            //佣金自销管理费
                            excelExamineBill.setManageratioMoney(pa.getManageAmount());
                            //税金
                            excelExamineBill.setTaxesMoney(pa.getTaxesAmount());
                            //佣金包占比
                            excelExamineBill.setPaymentpackAmount(new BigDecimal(pa.getPaymentpack().toString()));
                            //代理费佣金手动
                            excelExamineBill.setAgentfee(e.getAgentfee());
                            //代理费结算标准
                            excelExamineBill.setAgencyFee(pa.getAgencyFeeRatio());
                            excelExamineBill.setAgencyfeetype(pa.getAgencyfeetype());
                            excelExamineBill.setTokerfee(pa.getTokerfee());
                            excelExamineBill.setControlratioMoneyTg(pa.getControlAmount());
                        });
                    } else {
                        if (collect1.get(1L) != null) {
                            collect1.get(1L).forEach(pa -> {
                                excelExamineBill.setTokerfee(pa.getTokerfee());
                                excelExamineBill.setControlratioMoneyTg(pa.getControlAmount());
                            });
                        }
                        collect1.get(2L).forEach(pa -> {
                            //佣金自销管理费
                            excelExamineBill.setManageratioMoney(pa.getManageAmount());
                            //税金
                            excelExamineBill.setTaxesMoney(pa.getTaxesAmount());
                            //佣金包占比
                            excelExamineBill.setPaymentpackAmount(new BigDecimal(pa.getPaymentpack().toString()));
                            //代理费佣金手动
                            excelExamineBill.setAgentfee(e.getAgentfee());
                            //代理费结算标准
                            if (pa.getAgencyfeetype() == 1) {
                                excelExamineBill.setAgencyFee(pa.getAgencyFeeRatio());
                            } else {
                                excelExamineBill.setAgencyFee(pa.getAgencyFee());
                            }
                            excelExamineBill.setAgencyfeetype(pa.getAgencyfeetype());

                            // 接待费总金额
                            excelExamineBill.setAgencyFeeSum(pa.getAgencyFee());

                            //入住保证金
                            excelExamineBill.setJfbond(pa.getJfbond());

                            BigDecimal subtract = pa.getAgencyFee().subtract(pa.getManageAmount()).subtract(pa.getTaxesAmount());

                            if (pa.getJfbondIsDeduct() != null && pa.getJfbondIsDeduct() == 1) { // 扣除交房保证金
                                subtract = subtract.subtract(pa.getJfbond());
                            }
                            //扣除自定义扣减部分
                            if(pa.getDeuctVal()!=null){
                                subtract = subtract.subtract(pa.getDeuctVal());
                            }
                            if (excelExamineBill.getAgencyFeeSum() != null) {
                                excelExamineBill.setForesightMoney(excelExamineBill.getAgencyFeeSum().subtract(pa.getJfbond()));
                            }else {
                                excelExamineBill.setForesightMoney(null);
                            }

                            excelExamineBill.setControlratioMoneyDl(subtract);
                        });
                    }
                }

                // 团购
                BigDecimal tgSum = tgmarketerPlanRatio[0].add(tgexecutivePlanRatio[0]).add(tgprincipalPlanRatio[0])
                        .add(tgmanagerPlanRatio[0]).add(tgstagehandPlanRatio[0]).add(tgplannerPlanRatio[0]);

                // 代理
                BigDecimal dlSum = dlmarketerPlanRatio[0].add(dlexecutivePlanRatio[0]).add(dlprincipalPlanRatio[0])
                        .add(dlmanagerPlanRatio[0]).add(dlstagehandPlanRatio[0]).add(dlplannerPlanRatio[0]);

                excelExamineBill.setControlratioMoney(new BigDecimal(0));

                if (excelExamineBill.getControlratioMoneyDl() != null
                        && excelExamineBill.getControlratioMoneyDl().compareTo(new BigDecimal(0)) == 1
                        && dlSum.compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setControlratioMoney(excelExamineBill.getControlratioMoney().add(excelExamineBill.getControlratioMoneyDl()));
                }
                if (excelExamineBill.getControlratioMoneyTg() != null
                        && excelExamineBill.getControlratioMoneyTg().compareTo(new BigDecimal(0)) == 1
                        && tgSum.compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setControlratioMoney(excelExamineBill.getControlratioMoney().add(excelExamineBill.getControlratioMoneyTg()));
                }

                //根据方案分组
                Map<Long, List<Paymentdetails>> collect2 = e.getPaymentdetailsList().stream().collect(groupingBy(Paymentdetails::getPlantype));

                //交房节点
                BigDecimal[] jiaofang = new BigDecimal[]{new BigDecimal(0)};
                //销售代表
                Set<String> marketerSet = new HashSet<>();
                //销售代表佣金总额
                BigDecimal[] marketerMoney = new BigDecimal[]{new BigDecimal(0)};
                //销售代表应发佣金总额
                BigDecimal[] marketerSalary = new BigDecimal[]{new BigDecimal(0)};
                //销售代表实发佣金总额
                BigDecimal marketerPayroll = new BigDecimal(0);
                //销售代表所在节点的节点总金额
                BigDecimal[] marketerRatioNode = new BigDecimal[]{new BigDecimal(0)};

                //销售主管
                Set<String> executiveSet = new HashSet<>();
                //销售主管佣金总额
                BigDecimal[] executiveMoney = new BigDecimal[]{new BigDecimal(0)};
                //销售主管应发佣金总额
                BigDecimal[] executiveSalary = new BigDecimal[]{new BigDecimal(0)};
                //销售主管实发佣金总额
                BigDecimal executivePayroll = new BigDecimal(0);
                //销售主管所在节点的节点总金额
                BigDecimal[] executiveRatioNode = new BigDecimal[]{new BigDecimal(0)};

                //销售经理
                Set<String> managerSet = new HashSet<>();
                //销售经理佣金总额
                BigDecimal[] managerMoney = new BigDecimal[]{new BigDecimal(0)};
                //销售经理应发佣金总额
                BigDecimal[] managerSalary = new BigDecimal[]{new BigDecimal(0)};
                //销售经理实发佣金总额
                BigDecimal managerPayroll = new BigDecimal(0);
                //销售经理所在节点的节点总金额
                BigDecimal[] managerRatioNode = new BigDecimal[]{new BigDecimal(0)};

                //后台人员
                Set<String> stagehandSet = new HashSet<>();
                //后台人员佣金总额
                BigDecimal[] stagehandMoney = new BigDecimal[]{new BigDecimal(0)};
                //后台人员应发佣金总额
                BigDecimal[] stagehandSalary = new BigDecimal[]{new BigDecimal(0)};
                //后台人员实发佣金总额
                BigDecimal stagehandPayroll = new BigDecimal(0);
                //后台人员所在节点的节点总金额
                BigDecimal[] stagehandRatioNode = new BigDecimal[]{new BigDecimal(0)};

                //策划人员
                Set<String> plannerSet = new HashSet<>();
                //策划人员佣金总额
                BigDecimal[] plannerMoney = new BigDecimal[]{new BigDecimal(0)};
                //策划人员应发佣金总额
                BigDecimal[] plannerSalary = new BigDecimal[]{new BigDecimal(0)};
                //策划人员实发佣金总额
                BigDecimal plannerPayroll = new BigDecimal(0);
                //策划人员所在节点的节点总金额
                BigDecimal[] plannerRatioNode = new BigDecimal[]{new BigDecimal(0)};

                //自销负责人
                Set<String> principalSet = new HashSet<>();
                //自销负责人佣金总额
                BigDecimal[] principalMoney = new BigDecimal[]{new BigDecimal(0)};
                //自销负责人应发佣金总额
                BigDecimal[] principalSalary = new BigDecimal[]{new BigDecimal(0)};
                //自销负责人实发佣金总额
                BigDecimal principalPayroll = new BigDecimal(0);
                //自销负责人所在节点的节点总金额
                BigDecimal[] principalRatioNode = new BigDecimal[]{new BigDecimal(0)};

                //节点总和
                BigDecimal[] nodeSumMoney = new BigDecimal[]{new BigDecimal(0)};
                // 支付总金额
                BigDecimal[] nodeSumMoneyTotal = new BigDecimal[]{new BigDecimal(0)};
                //各个节点佣金总和[Map<方案， Map<节点， 节点总和>]
                Map<Long, Map<String, BigDecimal>> nodeMap = new HashMap<>();
                //各个节点的人员类别[Map<方案, Map<节点, 人员类别集合>>]
                Map<Long, Map<String, Set<String>>> personList = new HashMap<>();

                //节点设置之初的金额
                BigDecimal[] nodeTotalAmount = new BigDecimal[]{new BigDecimal(0)};
                // 佣金计发比例
                //销售经理佣金计发比例
                final BigDecimal[] ManagerProportion=new BigDecimal[]{new BigDecimal(0)};

                //后台人员 佣金计发比例
                final BigDecimal[] StagehandProportion=new BigDecimal[]{new BigDecimal(0)};

                // 自销负责人 佣金计发比例
                final BigDecimal[] PrincipalProportion=new BigDecimal[]{new BigDecimal(0)};

                //策划人员 佣金计发比例
                final BigDecimal[] PlannerProportion = new BigDecimal[]{new BigDecimal(0)};
                //佣金计发比例


                //根据节点分组
                collect2.entrySet().forEach(c2 -> {

                    Map<String, BigDecimal> map = new HashMap<>();
                    Map<String, Set<String>> perList = new HashMap<>();
                    Map<String, List<Paymentdetails>> collect3 = c2.getValue().stream().collect(groupingBy(Paymentdetails::getNodeid));
                    collect3.entrySet().forEach(el -> {
                        nodeTotalAmount[0] = nodeTotalAmount[0].add(el.getValue().get(0).getPlantype() == 2 ?
                                el.getValue().get(0).getNodeTotalAmount() : new BigDecimal(0));
                        BigDecimal[] nodeMoney = new BigDecimal[]{new BigDecimal(0)};
                        Set<String> perSet = new HashSet<>();
                        List<String> marketerSet1 = new ArrayList<>();
                        List<String> executiveSet1 = new ArrayList<>();
                        List<String> principalSet1 = new ArrayList<>();
                        List<String> managerSet1 = new ArrayList<>();
                        List<String> stagehandSet1 = new ArrayList<>();
                        List<String> plannerSet1 = new ArrayList<>();

                        // 根据节点下人员分组去重
                        el.getValue().stream().collect(Collectors.collectingAndThen(Collectors.toCollection(() ->
                                new TreeSet<>(Comparator.comparing(ell -> ell.getUserid()))), ArrayList::new))
                                .forEach(pl -> {
                                    nodeSumMoneyTotal[0] = nodeSumMoneyTotal[0].add(pl.getPaytotal() == null ? new BigDecimal(0) : pl.getPaytotal());
                                });

                        el.getValue().forEach(pl -> {

                            if (el.getKey().equals("f7a85e11-5827-49c4-9709-399b37629bfc")) {
                                jiaofang[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                            }
                            nodeMoney[0] = nodeMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                            nodeSumMoney[0] = nodeSumMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                            perSet.add(pl.getUsertypeid());
                            //销售代表
                            if (pl.getUsertypeid().equals("5a58ad4a9388420bb58e408f06259295") || pl.getUsertypeid().equals("8f2fc0d6-eeb3-4d7b-9a0a-971806cb7c51")) {
                                marketerSet.add(pl.getUser());
                                marketerMoney[0] = marketerMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                                if (!marketerSet1.contains(pl.getUser())) {
                                    marketerSalary[0] = marketerSalary[0].add(pl.getPaytotal());
                                }
                                marketerSet1.add(pl.getUser());
                            }
                            //销售主管
                            if (pl.getUsertypeid().equals("53f9d01b5ff24e2d8781ffd29acfd009")) {
                                executiveSet.add(pl.getUser());
                                executiveMoney[0] = executiveMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                                if (!executiveSet1.contains(pl.getUser())) {
                                    executiveSalary[0] = executiveSalary[0].add(pl.getPaytotal());
                                }
                                executiveSet1.add(pl.getUser());
                            }
                            //自销负责人
                            if (pl.getUsertypeid().equals("51b52b21c1bc4e6e8eaad07c44b32303")) {
                                principalSet.add(pl.getUser());
                                principalMoney[0] = principalMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                                if (!principalSet1.contains(pl.getUser())) {
                                    principalSalary[0] = principalSalary[0].add(pl.getPaytotal());
                                }
                                if(pl.getPayableRatio()!=null&&(PrincipalProportion[0].compareTo(new BigDecimal(0))==0 || PrincipalProportion[0].compareTo(pl.getPayableRatio()) == -1)){
                                    PrincipalProportion[0] = pl.getPayableRatio();
                                }

                                principalSet1.add(pl.getUser());
                            }
                            //销售经理
                            if (pl.getUsertypeid().equals("7f2fc0d6-eeb3-4d7b-9a0a-971806cb7c52")) {
                                managerSet.add(pl.getUser());
                                managerMoney[0] = managerMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                                if (!managerSet1.contains(pl.getUser())) {
                                    managerSalary[0] = managerSalary[0].add(pl.getPaytotal());
                                }
                                if(pl.getPayableRatio()!=null&&(ManagerProportion[0].compareTo(new BigDecimal(0))==0 || ManagerProportion[0].compareTo(pl.getPayableRatio()) == -1)){
                                    ManagerProportion[0] = pl.getPayableRatio();
                                }

                                managerSet1.add(pl.getUser());
                            }
                            //后台人员
                            if (pl.getUsertypeid().equals("e58ff7b907074a539f85ec8a3f05d149")) {
                                stagehandSet.add(pl.getUser());
                                stagehandMoney[0] = stagehandMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                                if (!stagehandSet1.contains(pl.getUser())) {
                                    stagehandSalary[0] = stagehandSalary[0].add(pl.getPaytotal());
                                }
                                if(pl.getPayableRatio()!=null&&(StagehandProportion[0].compareTo(new BigDecimal(0))==0 || StagehandProportion[0].compareTo(pl.getPayableRatio()) == -1)){
                                    StagehandProportion[0] = pl.getPayableRatio();
                                }

                                stagehandSet1.add(pl.getUser());
                            }
                            //策划人员
                            if (pl.getUsertypeid().equals("40bde8137914415eb141cbc65356784c")) {
                                plannerSet.add(pl.getUser());
                                plannerMoney[0] = plannerMoney[0].add(pl.getPayable() == null ? pl.getPaytotal() : pl.getPayable());
                                if (!plannerSet1.contains(pl.getUser())) {
                                    plannerSalary[0] = plannerSalary[0].add(pl.getPaytotal());
                                }
                                if(pl.getPayableRatio()!=null&&(PlannerProportion[0].compareTo(new BigDecimal(0))==0 || PlannerProportion[0].compareTo(pl.getPayableRatio()) == -1)){
                                    PlannerProportion[0] = pl.getPayableRatio();
                                }

                                plannerSet1.add(pl.getUser());
                            }

                        });
                        map.put(el.getKey(), nodeMoney[0]);
                        perList.put(el.getKey(), perSet);

                    });
                    nodeMap.put(c2.getKey(), map);
                    personList.put(c2.getKey(), perList);
                });

                if (excelExamineBill.getAgentfee() != null) {
                    excelExamineBill.setTransferRatio(excelExamineBill.getAgentfee().compareTo(new BigDecimal(0)) == 0 ?
                            new BigDecimal(0) : nodeTotalAmount[0].divide(excelExamineBill.getAgentfee(), 4,
                            RoundingMode.HALF_EVEN).multiply(new BigDecimal(100)).setScale(2, RoundingMode.HALF_EVEN));
                } else {
                    excelExamineBill.setTransferRatio(null);
                }
//                nodeMap.entrySet().forEach(n ->{
//                    n.getValue().entrySet().forEach(nn ->{
//                        //销售代表
//                        if(personList.get(n.getKey()).get(nn.getKey()).contains("5a58ad4a9388420bb58e408f06259295")){
//                            marketerRatioNode[0] = marketerRatioNode[0].add(nn.getValue());
//                        }
//                        //销售主管
//                        if(personList.get(n.getKey()).get(nn.getKey()).contains("53f9d01b5ff24e2d8781ffd29acfd009")){
//                            executiveRatioNode[0] = executiveRatioNode[0].add(nn.getValue());
//                        }
//                        //自销负责人
//                        if(personList.get(n.getKey()).get(nn.getKey()).contains("51b52b21c1bc4e6e8eaad07c44b32303")){
//                            principalRatioNode[0] = principalRatioNode[0].add(nn.getValue());
//                        }
//                        //销售经理
//                        if(personList.get(n.getKey()).get(nn.getKey()).contains("7f2fc0d6-eeb3-4d7b-9a0a-971806cb7c52")){
//                            managerRatioNode[0] = managerRatioNode[0].add(nn.getValue());
//                        }
//                        //后台人员
//                        if(personList.get(n.getKey()).get(nn.getKey()).contains("e58ff7b907074a539f85ec8a3f05d149")){
//                            stagehandRatioNode[0] = stagehandRatioNode[0].add(nn.getValue());
//                        }
//                        //策划人员
//                        if(personList.get(n.getKey()).get(nn.getKey()).contains("40bde8137914415eb141cbc65356784c")){
//                            plannerRatioNode[0] = plannerRatioNode[0].add(nn.getValue());
//                        }
//                    });
//                });

                // excelExamineBill.setNodeSumMoneyTotal(nodeSumMoneyTotal[0]); // 有问题，弃用
                excelExamineBill.setNodeSumMoneyTotal(nodeSumMoneyTotal1.getNodeTotal()); // 重新计算的

                //佣金包金额（不含收楼控存）
                excelExamineBill.setNodeSumMoney(nodeSumMoney[0]);
                //本次计发比例
                BigDecimal sum = new BigDecimal(0);

                if (excelExamineBill.getAgentfee() != null
                        && excelExamineBill.getAgentfee().compareTo(new BigDecimal(0)) == 1
                        && dlSum.compareTo(new BigDecimal(0)) == 1) {
                    sum = sum.add(excelExamineBill.getAgentfee());
                }
                if (excelExamineBill.getTgfee() != null
                        && excelExamineBill.getTgfee().compareTo(new BigDecimal(0)) == 1
                        && tgSum.compareTo(new BigDecimal(0)) == 1) {
                    sum = sum.add(excelExamineBill.getTgfee());
                }

                excelExamineBill.setNodeSumMoneyAll(sum);

                if (sum.compareTo(new BigDecimal(0)) == 1) {
                    // nodeSumMoneyTotal[0] 有问题，弃用
                    // excelExamineBill.setCommissionRatio(nodeSumMoneyTotal[0].divide(sum, 4, RoundingMode.HALF_EVEN).multiply(new BigDecimal(100)).setScale(0, RoundingMode.HALF_EVEN));
                    excelExamineBill.setCommissionRatio(nodeSumMoneyTotal1.getPayRatio());
                } else {
                    excelExamineBill.setCommissionRatio(null);
                }

                //销售代表
                excelExamineBill.setMarketer(marketerSet.size() <= 0 ? null : StringUtils.strip(marketerSet.toString(), "[]"));
                //销售代表佣金总额(暂定等于应发金额)
                excelExamineBill.setMarketerSalary(marketerSalary[0]);
                //销售代表实发佣金总额
                excelExamineBill.setMarketerPayroll(marketerMoney[0]);
                //销售代表佣金比
//                excelExamineBill.setMarketerRatio(marketerMoney[0].compareTo(new BigDecimal(0)) != 1 ? new BigDecimal(0) :
//                        (nodeTotalAmount[0].compareTo(new BigDecimal(0)) == 0 ? new BigDecimal(0) :
//                                (marketerPlanMoney[0].divide(nodeTotalAmount[0], 4,  RoundingMode.HALF_EVEN)
//                                        .multiply(new BigDecimal(100))).setScale(2, RoundingMode.HALF_EVEN)));
                excelExamineBill.setMarketerRatio(new BigDecimal(0));
                if (tgmarketerPlanRatio[0] != null && tgmarketerPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setMarketerRatio(tgmarketerPlanRatio[0]);
                } else if (dlmarketerPlanRatio[0] != null && dlmarketerPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setMarketerRatio(dlmarketerPlanRatio[0]);
                }


                //销售主管StringUtils.strip(list.toString(),"[]")
                excelExamineBill.setExecutive(executiveSet.size() <= 0 ? null : StringUtils.strip(executiveSet.toString(), "[]"));
                //销售主管佣金总额(暂定等于应发金额)
                excelExamineBill.setExecutiveSalary(executiveSalary[0]);
                //销售主管实发佣金总额
                excelExamineBill.setExecutivePayroll(executiveMoney[0]);
                //销售主管佣金比
//                excelExamineBill.setExecutiveRatio(executiveMoney[0].compareTo(new BigDecimal(0)) != 1 ? new BigDecimal(0) :
//                        (nodeTotalAmount[0].compareTo(new BigDecimal(0)) == 0 ? new BigDecimal(0) :
//                                (executivePlanMoney[0].divide(nodeTotalAmount[0],4, RoundingMode.HALF_EVEN)
//                        .multiply(new BigDecimal(100))).setScale(2, RoundingMode.HALF_EVEN)));
                excelExamineBill.setExecutiveRatio(new BigDecimal(0));
                if (tgexecutivePlanRatio[0] != null && tgexecutivePlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setExecutiveRatio(tgexecutivePlanRatio[0]);
                } else if (dlexecutivePlanRatio[0] != null && dlexecutivePlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setExecutiveRatio(dlexecutivePlanRatio[0]);
                }

                //销售经理
                excelExamineBill.setManager(managerSet.size() <= 0 ? null : StringUtils.strip(managerSet.toString(), "[]"));
                //销售经理佣金总额(暂定等于应发金额)
                excelExamineBill.setManagerSalary(managerSalary[0]);
                //销售经理实发佣金总额
                excelExamineBill.setManagerPayroll(managerMoney[0]);
                //月度佣金占比
                excelExamineBill.setManagerProportion(ManagerProportion[0]);
                //销售经理佣金比
//                excelExamineBill.setManagerRatio(managerMoney[0].compareTo(new BigDecimal(0)) != 1 ? new BigDecimal(0) :
//                        (nodeTotalAmount[0].compareTo(new BigDecimal(0)) == 0 ? new BigDecimal(0) :
//                                (managerPlanMoney[0].divide(nodeTotalAmount[0],4, RoundingMode.HALF_EVEN)
//                                        .multiply(new BigDecimal(100))).setScale(2, RoundingMode.HALF_EVEN)));
                excelExamineBill.setManagerRatio(new BigDecimal(0));
                if (tgmanagerPlanRatio[0] != null && tgmanagerPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setManagerRatio(tgmanagerPlanRatio[0]);
                } else if (dlmanagerPlanRatio[0] != null && dlmanagerPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setManagerRatio(dlmanagerPlanRatio[0]);
                }

                //后台人员
                excelExamineBill.setStagehand(stagehandSet.size() <= 0 ? null : StringUtils.strip(stagehandSet.toString(), "[]"));
                //后台人员佣金总额(暂定等于应发金额)
                excelExamineBill.setStagehandSalary(stagehandSalary[0]);
                //后台人员实发佣金总额
                excelExamineBill.setStagehandPayroll(stagehandMoney[0]);
                //月度佣金占比
                excelExamineBill.setStagehandProportion(StagehandProportion[0]);
                //后台人员佣金比
//                excelExamineBill.setStagehandRatio(stagehandMoney[0].compareTo(new BigDecimal(0)) != 1 ? new BigDecimal(0) :
//                        (nodeTotalAmount[0].compareTo(new BigDecimal(0)) == 0 ? new BigDecimal(0) :
//                                (stagehandPlanMoney[0].divide(nodeTotalAmount[0],4, RoundingMode.HALF_EVEN)
//                                        .multiply(new BigDecimal(100))).setScale(2, RoundingMode.HALF_EVEN)));
                excelExamineBill.setStagehandRatio(new BigDecimal(0));
                if (tgstagehandPlanRatio[0] != null && tgstagehandPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setStagehandRatio(tgstagehandPlanRatio[0]);
                } else if (dlstagehandPlanRatio[0] != null && dlstagehandPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setStagehandRatio(dlstagehandPlanRatio[0]);
                }

                //策划人员
                excelExamineBill.setPlanner(plannerSet.size() <= 0 ? null : StringUtils.strip(plannerSet.toString(), "[]"));
                //策划人员佣金总额(暂定等于应发金额)
                excelExamineBill.setPlannerSalary(plannerSalary[0]);
                //策划人员实发佣金总额
                excelExamineBill.setPlannerPayroll(plannerMoney[0]);
                //月度佣金占比
                excelExamineBill.setPlannerProportion(PlannerProportion[0]);
                //策划人员佣金比
//                excelExamineBill.setPlannerRatio(plannerMoney[0].compareTo(new BigDecimal(0)) != 1 ? new BigDecimal(0) :
//                        (nodeTotalAmount[0].compareTo(new BigDecimal(0)) == 0 ? new BigDecimal(0) :
//                                (plannerPlanMoney[0].divide(nodeTotalAmount[0], 4, RoundingMode.HALF_EVEN)
//                                        .multiply(new BigDecimal(100))).setScale(2, RoundingMode.HALF_EVEN)));
                excelExamineBill.setPlannerRatio(new BigDecimal(0));
                if (tgplannerPlanRatio[0] != null && tgplannerPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setPlannerRatio(tgplannerPlanRatio[0]);
                } else if (dlplannerPlanRatio[0] != null && dlplannerPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setPlannerRatio(dlplannerPlanRatio[0]);
                }

                //自销负责人
                excelExamineBill.setPrincipal(principalSet.size() <= 0 ? null : StringUtils.strip(principalSet.toString(), "[]"));
                //自销负责人佣金总额(暂定等于应发金额)
                excelExamineBill.setPrincipalSalary(principalSalary[0]);
                //自销负责人实发佣金总额
                excelExamineBill.setPrincipalPayroll(principalMoney[0]);
                //月度佣金占比
                excelExamineBill.setPrincipalProportion(PrincipalProportion[0]);
                //自销负责人佣金比
//                excelExamineBill.setPrincipalRatio(principalMoney[0].compareTo(new BigDecimal(0)) != 1 ? new BigDecimal(0) :
//                        (nodeTotalAmount[0].compareTo(new BigDecimal(0)) == 0 ? new BigDecimal(0) :
//                                (principalMoney[0].divide(nodeTotalAmount[0], 4, RoundingMode.HALF_EVEN)
//                                        .multiply(new BigDecimal(100))).setScale(2, RoundingMode.HALF_EVEN)));
                excelExamineBill.setPrincipalRatio(new BigDecimal(0));
                if (tgprincipalPlanRatio[0] != null && tgprincipalPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setPrincipalRatio(tgprincipalPlanRatio[0]);
                } else if (dlprincipalPlanRatio[0] != null && dlprincipalPlanRatio[0].compareTo(new BigDecimal(0)) == 1) {
                    excelExamineBill.setPrincipalRatio(dlprincipalPlanRatio[0]);
                }
                //本次佣金实发计发金额（代理费佣金+团购费佣金）
                excelExamineBill.setDlTgSumMoney(nodeSumMoney[0]);
            });
            list.add(excelExamineBill);
        });

        //代理费结算标准总和
        BigDecimal AgencyFeeSum = new BigDecimal(0);
        //代理费划拨金额总和、或、佣金包金额（含收楼控存）
        BigDecimal agentfeeSum = new BigDecimal(0);
        //税金总和
        BigDecimal taxesMoneySum = new BigDecimal(0);
        //自销管理费总和
        BigDecimal manageratioMoneySum = new BigDecimal(0);
        //可支配收入
        BigDecimal controlratioMoneySum = new BigDecimal(0);
        //佣金包金额（不含收楼控存）
        BigDecimal nodeSumMoneySum = new BigDecimal(0);
        //佣金包金额（不含收楼控存）
        BigDecimal nodeSumMoneySumAll = new BigDecimal(0);
        //本次佣金实发计发金额
        BigDecimal DlTgSumMoneySum = new BigDecimal(0);
        //销售代表佣金实发金额
        BigDecimal marketerPayrollSum = new BigDecimal(0);
        //销售主管佣金实发金额
        BigDecimal executivePayrollSum = new BigDecimal(0);
        //销售经理佣金实发金额
        BigDecimal managerPayrollSum = new BigDecimal(0);
        //后台人员佣金实发金额
        BigDecimal stagehandPayrollSum = new BigDecimal(0);
        //策划人员佣金实发金额
        BigDecimal plannerPayrollSum = new BigDecimal(0);
        //自销负责人佣金实发金额
        BigDecimal principalPayrollSum = new BigDecimal(0);
        for (ExcelExamineBill excelExamineBill : list) {
            AgencyFeeSum = AgencyFeeSum.add(excelExamineBill.getAgencyFee() == null ? new BigDecimal(0) : excelExamineBill.getAgencyFee());
            agentfeeSum = agentfeeSum.add(excelExamineBill.getAgentfee() == null ? new BigDecimal(0) : excelExamineBill.getAgentfee());
            taxesMoneySum = taxesMoneySum.add(excelExamineBill.getTaxesMoney() == null ? new BigDecimal(0) : excelExamineBill.getTaxesMoney());
            manageratioMoneySum = manageratioMoneySum.add(excelExamineBill.getManageratioMoney() == null ? new BigDecimal(0) : excelExamineBill.getManageratioMoney());
            controlratioMoneySum = controlratioMoneySum.add(excelExamineBill.getControlratioMoney() == null ? new BigDecimal(0) : excelExamineBill.getControlratioMoney());
            nodeSumMoneySum = nodeSumMoneySum.add(excelExamineBill.getNodeSumMoney() == null ? new BigDecimal(0) : excelExamineBill.getNodeSumMoney());
            nodeSumMoneySumAll = nodeSumMoneySumAll.add(excelExamineBill.getNodeSumMoneyAll() == null ? new BigDecimal(0) : excelExamineBill.getNodeSumMoneyAll());
            DlTgSumMoneySum = DlTgSumMoneySum.add(excelExamineBill.getDlTgSumMoney() == null ? new BigDecimal(0) : excelExamineBill.getDlTgSumMoney());
            marketerPayrollSum = marketerPayrollSum.add(excelExamineBill.getMarketerPayroll() == null ? new BigDecimal(0) : excelExamineBill.getMarketerPayroll());
            executivePayrollSum = executivePayrollSum.add(excelExamineBill.getExecutivePayroll() == null ? new BigDecimal(0) : excelExamineBill.getExecutivePayroll());
            managerPayrollSum = managerPayrollSum.add(excelExamineBill.getManagerPayroll() == null ? new BigDecimal(0) : excelExamineBill.getManagerPayroll());
            stagehandPayrollSum = stagehandPayrollSum.add(excelExamineBill.getStagehandPayroll() == null ? new BigDecimal(0) : excelExamineBill.getStagehandPayroll());
            plannerPayrollSum = plannerPayrollSum.add(excelExamineBill.getPlannerPayroll() == null ? new BigDecimal(0) : excelExamineBill.getPlannerPayroll());
            principalPayrollSum = principalPayrollSum.add(excelExamineBill.getPrincipalPayroll() == null ? new BigDecimal(0) : excelExamineBill.getPrincipalPayroll());

        }
        ExcelExamineBill excelExamineBill = new ExcelExamineBill();
        excelExamineBill.setOrgName("总计");
        excelExamineBill.setAgentfee(agentfeeSum);
        excelExamineBill.setAgencyFee(null);
        excelExamineBill.setTaxesMoney(taxesMoneySum);
        excelExamineBill.setManageratioMoney(manageratioMoneySum);
        excelExamineBill.setControlratioMoney(controlratioMoneySum);
        excelExamineBill.setNodeSumMoney(nodeSumMoneySum);
        excelExamineBill.setNodeSumMoneyAll(nodeSumMoneySumAll);
        excelExamineBill.setDlTgSumMoney(DlTgSumMoneySum);
        excelExamineBill.setMarketerPayroll(marketerPayrollSum);
        excelExamineBill.setExecutivePayroll(executivePayrollSum);
        excelExamineBill.setManagerPayroll(managerPayrollSum);
        excelExamineBill.setStagehandPayroll(stagehandPayrollSum);
        excelExamineBill.setPlannerPayroll(plannerPayrollSum);
        excelExamineBill.setPrincipalPayroll(principalPayrollSum);
        list.add(excelExamineBill);
        return list;
    }

    /**
     * 是否跳转页面
     *
     * @param tradeIds
     * @return
     */
    @Override
    public Integer jumpOrNo(List<String> tradeIds) {
        List<TradeVo> list = paymentdetailsMapper.selectPaymentdetailsByTradeIds(tradeIds);
        List<String> payIds = new ArrayList<>();
        for (TradeVo tradeVo : list) {
            if (tradeVo.getIshouse().equals("否")) {
                return 4;
            }
            for (Paymentdetails t : tradeVo.getPaymentdetailsList()) {
                if (t.getStatusDetail().equals(PlanEnum.PaymentDetailsStatusDetail.STATUS_203.getCode()) || t.getStatusDetail().equals(SettleEnum.SettleBillStatus.STATUS_DSH.getCode())) {
                    return 3;
                }
            }
            if (tradeVo.getPlanStatus().equals(PlanEnum.PlanStatus.STATUS_CG.getCode()) || tradeVo.getPlanStatus().equals(PlanEnum.PlanStatus.STATUS_ZF.getCode())) {
                return 2;
            }
            for (Paymentdetails paymentdetails : tradeVo.getPaymentdetailsList()) {
                if (paymentdetails.getStatusDetail().equals(PlanEnum.PaymentDetailsStatusDetail.STATUS_301.getCode())) {
                    return 0;
                } else {
                    payIds.add(paymentdetails.getPayid());
                }
            }

        }
        //将方案状态改为退房
        tradeMapper.updateStatusByTradeIds(tradeIds);
        //将方案详情状态改为退房
        Long status = PlanEnum.PaymentDetailsStatusDetail.STATUS_104.getCode();
        paymentdetailsMapper.updatePaymentdetailsStatusByPayIds(payIds, status);
        return 1;
    }

    /**
     * 核算单导出
     *
     * @param examineBillVo
     * @return
     */
    @Override
    public AjaxResult examineBillExport(ExamineBillVo examineBillVo, OutputStream out) {
        List<ExcelExamineBill> list = this.examineBillDetailsNew(examineBillVo);
        if (list == null || list.size() <= 0) {
            this.excelPort(examineBillVo, out);
            return AjaxResult.success();
        } else {
            this.excelPort1(examineBillVo, list, out);
            return AjaxResult.success();
        }
    }

    public void excelPort(ExamineBillVo examineBillVo, OutputStream out) {
        try {
            // Excel模板文件路径
            ClassPathResource classPathResource = new ClassPathResource("static/excel/examineBill.xlsx");
            InputStream stream1 = classPathResource.getStream();
            //读取模板文件创建Excel表格对象
            XSSFWorkbook workbook1 = new XSSFWorkbook(stream1);
            try {
                //当前用户桌面
                File desktopDir = FileSystemView.getFileSystemView()
                        .getHomeDirectory();
                String desktopPath = desktopDir.getAbsolutePath();
                File file = new File(desktopPath + "\\examineBill1.xlsx");
                if (examineBillVo.getExportPositionPath() != null && examineBillVo.getExportPositionPath() != "") {
                    file = new File(examineBillVo.getExportPositionPath() + "\\examineBill1.xlsx");
                }
//                FileOutputStream fileOutputStream =new FileOutputStream(file);
                workbook1.write(out);
                out.close();

            } catch (IOException e) {
                System.err.println(e.getMessage());

            }
        } catch (IOException e) {
            e.printStackTrace();

        }
    }


    public void excelPort1(ExamineBillVo examineBillVo, List<ExcelExamineBill> list, OutputStream out) {
        try {
            // Excel模板文件路径
            ClassPathResource classPathResource = new ClassPathResource("static/excel/examineBill.xlsx");
            InputStream stream = classPathResource.getStream();
            //读取模板文件创建Excel表格对象
            XSSFWorkbook workbook = new XSSFWorkbook(stream);
//
//            String temlateRealPath = "D:\\examineBill.xlsx";
//            XSSFWorkbook workbook = new XSSFWorkbook(new FileInputStream(new File(temlateRealPath)));
            // 获取模板文件第一个sheet，对应Excel文件中的sheet
            XSSFSheet sheet = workbook.getSheetAt(0);
            // 设置单元格格式居中
            XSSFCellStyle cellStyle = workbook.createCellStyle();
            cellStyle.setAlignment(HorizontalAlignment.CENTER);
            //新增单元格格式
            cellStyle.setBorderTop(BorderStyle.THIN);
            cellStyle.setBorderBottom(BorderStyle.THIN);
            cellStyle.setBorderLeft(BorderStyle.THIN);
            cellStyle.setBorderRight(BorderStyle.THIN);
            cellStyle.setTopBorderColor(HSSFColor.BLACK.index);
            cellStyle.setBottomBorderColor(HSSFColor.BLACK.index);
            cellStyle.setLeftBorderColor(HSSFColor.BLACK.index);
            cellStyle.setRightBorderColor(HSSFColor.BLACK.index);
            cellStyle.setWrapText(true);
            cellStyle.setDataFormat(workbook.createDataFormat().getFormat("@"));

            XSSFCellStyle cellStyle_date = workbook.createCellStyle();
            cellStyle_date.setAlignment(HorizontalAlignment.CENTER);
            cellStyle_date.setBorderTop(BorderStyle.THIN);
            cellStyle_date.setBorderBottom(BorderStyle.THIN);
            cellStyle_date.setBorderLeft(BorderStyle.THIN);
            cellStyle_date.setBorderRight(BorderStyle.THIN);
            cellStyle_date.setTopBorderColor(HSSFColor.BLACK.index);
            cellStyle_date.setBottomBorderColor(HSSFColor.BLACK.index);
            cellStyle_date.setLeftBorderColor(HSSFColor.BLACK.index);
            cellStyle_date.setRightBorderColor(HSSFColor.BLACK.index);
            cellStyle_date.setWrapText(true);
            cellStyle_date.setDataFormat(workbook.createDataFormat().getFormat("yyyy-MM-dd"));

            XSSFCellStyle cellStyle_double = workbook.createCellStyle();
            cellStyle_double.setAlignment(HorizontalAlignment.CENTER);
            cellStyle_double.setBorderTop(BorderStyle.THIN);
            cellStyle_double.setBorderBottom(BorderStyle.THIN);
            cellStyle_double.setBorderLeft(BorderStyle.THIN);
            cellStyle_double.setBorderRight(BorderStyle.THIN);
            cellStyle_double.setTopBorderColor(HSSFColor.BLACK.index);
            cellStyle_double.setBottomBorderColor(HSSFColor.BLACK.index);
            cellStyle_double.setLeftBorderColor(HSSFColor.BLACK.index);
            cellStyle_double.setRightBorderColor(HSSFColor.BLACK.index);
            cellStyle_double.setWrapText(true);
            cellStyle_double.setDataFormat(workbook.createDataFormat().getFormat("0.00"));

            // 获取对应行号
            XSSFRow row = sheet.getRow(0);
            XSSFRow row1 = sheet.getRow(0);
            XSSFCell cell1 = row.createCell(0);
            XSSFCellStyle cellStyle1 = workbook.createCellStyle();
            cellStyle1.setAlignment(HorizontalAlignment.CENTER);
            CellRangeAddress region1 = new CellRangeAddress(0, 1, 0, 64);
            cell1.setCellValue(list.get(0).getExamineName());
            cell1.setCellStyle(cellStyle1);
            sheet.addMergedRegion(region1);
            // 对应单元格填入数据
            for (int i = 0; i < list.size(); i++) {
                row = sheet.createRow((int) i + 5);
                ExcelExamineBill excelExamineBill = list.get(i);
                // 创建单元格，并设置值
                XSSFCell cell = row.createCell(0);
                if (i == list.size() - 1) {
                    cell.setCellValue("合计");
                    cell.setCellStyle(cellStyle);
                    CellRangeAddress region = new CellRangeAddress(i + 5, i + 5, 0, 5);
                    // 使用RegionUtil类为合并后的单元格添加边框
                    RegionUtil.setBorderBottom(1, region, sheet); // 下边框
                    RegionUtil.setBorderLeft(1, region, sheet); // 左边框
                    RegionUtil.setBorderRight(1, region, sheet); // 有边框
                    RegionUtil.setBorderTop(1, region, sheet); // 上边框
                    sheet.addMergedRegion(region);
                } else {
                    cell.setCellValue(String.valueOf(i + 1));
                    cell.setCellStyle(cellStyle);
                    sheet.autoSizeColumn(0, true);

                    cell = row.createCell(1);
                    cell.setCellValue(excelExamineBill.getOrgName());
                    cell.setCellStyle(cellStyle);
                    sheet.autoSizeColumn(1, true);

                    cell = row.createCell(2);
                    cell.setCellValue(excelExamineBill.getProjname());
                    cell.setCellStyle(cellStyle);
                    sheet.autoSizeColumn(2, true);

                    cell = row.createCell(3);
                    cell.setCellValue(excelExamineBill.getProductName());
                    cell.setCellStyle(cellStyle);
                    sheet.autoSizeColumn(3, true);

                    cell = row.createCell(4);
                    cell.setCellValue(excelExamineBill.getCstname());
                    cell.setCellStyle(cellStyle);
                    sheet.autoSizeColumn(4, true);

                    cell = row.createCell(5);
                    cell.setCellValue(excelExamineBill.getRoominfo());
                    cell.setCellStyle(cellStyle);
                    sheet.autoSizeColumn(5, true);
                }


                cell = row.createCell(6);
                cell.setCellValue(excelExamineBill.getOrderQsdate());
                cell.setCellStyle(cellStyle_date);
                sheet.autoSizeColumn(6, true);

                cell = row.createCell(7);
                cell.setCellValue(excelExamineBill.getContractQsdate());
                cell.setCellStyle(cellStyle_date);
                sheet.autoSizeColumn(7, true);

                cell = row.createCell(8);
//                cell.setCellValue(excelExamineBill.getRmbhttotal() == null ? null : excelExamineBill.getRmbhttotal().toString());
                if (excelExamineBill.getRmbhttotal() != null) {
                    cell.setCellValue(excelExamineBill.getRmbhttotal().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(8, true);

                cell = row.createCell(9);
//                cell.setCellValue(excelExamineBill.getOffsetMoney() == null ? null : excelExamineBill.getOffsetMoney().toString());
                if (excelExamineBill.getOffsetMoney() != null) {
                    cell.setCellValue(excelExamineBill.getOffsetMoney().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(9, true);

                cell = row.createCell(10);
                cell.setCellValue(excelExamineBill.getLastOffsetDate());
                cell.setCellStyle(cellStyle_date);
                sheet.autoSizeColumn(10, true);

                cell = row.createCell(11);
                cell.setCellValue(excelExamineBill.getPayFormClass());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(11, true);

                cell = row.createCell(12);
                cell.setCellValue(excelExamineBill.getReferagentname());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(12, true);

                cell = row.createCell(13);
                cell.setCellValue(excelExamineBill.getServiceFeeSettlementStandard()); // 费用收入
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(13, true);

                cell = row.createCell(14);
                cell.setCellValue(excelExamineBill.getTokerfee() == null ? null : excelExamineBill.getTokerfee().toString());
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(14, true);

                cell = row.createCell(15);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(15, true);

                cell = row.createCell(16);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle_date);
                sheet.autoSizeColumn(16, true);

                cell = row.createCell(17);
                if (excelExamineBill.getAgencyfeetype() != null && excelExamineBill.getAgencyfeetype() == 1) {
                    cell.setCellValue(excelExamineBill.getAgencyFee() == null ? null :
                            (excelExamineBill.getAgencyFee().toString() + "%"));
                    cell.setCellStyle(cellStyle);
                } else {
//                    cell.setCellValue(excelExamineBill.getAgencyFee() == null ? null : excelExamineBill.getAgencyFee().toString());
                    if (excelExamineBill.getAgencyFee() != null) {
                        cell.setCellValue(excelExamineBill.getAgencyFee().doubleValue());
                    }else {
                        cell.setCellValue("");
                    }
                    cell.setCellStyle(cellStyle_double);
                }
                sheet.autoSizeColumn(17, true);

                cell = row.createCell(18);
//                cell.setCellValue(excelExamineBill.getAgencyFeeSum() == null ? null : excelExamineBill.getAgencyFeeSum().toString());
                if (excelExamineBill.getAgencyFeeSum() != null) {
                    cell.setCellValue(excelExamineBill.getAgencyFeeSum().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(18, true);

                cell = row.createCell(19);
//                cell.setCellValue(excelExamineBill.getForesightMoney() == null ? null : excelExamineBill.getForesightMoney().toString());
                if (excelExamineBill.getForesightMoney() != null) {
                    cell.setCellValue(excelExamineBill.getForesightMoney().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(19, true);

                cell = row.createCell(20);
//                cell.setCellValue(excelExamineBill.getJfbond() == null ? null : excelExamineBill.getJfbond().toString());
                if (excelExamineBill.getJfbond() != null) {
                    cell.setCellValue(excelExamineBill.getJfbond().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(20, true);

                cell = row.createCell(21);
//                cell.setCellValue(excelExamineBill.getAgentfee() == null ? null : excelExamineBill.getAgentfee().toString());
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(21, true);

                cell = row.createCell(22);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(22, true);

                cell = row.createCell(23);
//                cell.setCellValue(excelExamineBill.getTransferRatio() == null ? null : excelExamineBill.getTransferRatio().toString());
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(23, true);

                cell = row.createCell(24);
//                cell.setCellValue(excelExamineBill.getTaxesMoney() == null ? null : excelExamineBill.getTaxesMoney().toString());
                if (excelExamineBill.getTaxesMoney() != null) {
                    cell.setCellValue(excelExamineBill.getTaxesMoney().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(24, true);

                cell = row.createCell(25);
//                cell.setCellValue(excelExamineBill.getManageratioMoney() == null ? null : excelExamineBill.getManageratioMoney().toString());
                if (excelExamineBill.getManageratioMoney() != null) {
                    cell.setCellValue(excelExamineBill.getManageratioMoney().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(25, true);

                cell = row.createCell(26);
//                cell.setCellValue(excelExamineBill.getControlratioMoney() == null ? null : excelExamineBill.getControlratioMoney().toString());
                if (excelExamineBill.getControlratioMoney() != null) {
                    cell.setCellValue(excelExamineBill.getControlratioMoney().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(26, true);

                cell = row.createCell(27);
                cell.setCellValue(excelExamineBill.getPaymentpackAmount() == null ? null : excelExamineBill.getPaymentpackAmount().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(27, true);

                cell = row.createCell(28);
//                cell.setCellValue(excelExamineBill.getNodeSumMoneyAll() == null ? null : excelExamineBill.getNodeSumMoneyAll().toString());
                if (excelExamineBill.getNodeSumMoneyAll() != null) {
                    cell.setCellValue(excelExamineBill.getNodeSumMoneyAll().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(28, true);

                cell = row.createCell(29);
                cell.setCellValue(excelExamineBill.getCommissionRatio() == null ? null : excelExamineBill.getCommissionRatio().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(29, true);

                cell = row.createCell(30);
//                cell.setCellValue(excelExamineBill.getNodeSumMoneyTotal() == null ? null : excelExamineBill.getNodeSumMoneyTotal().toString());
                if (excelExamineBill.getNodeSumMoneyTotal() != null) {
                    cell.setCellValue(excelExamineBill.getNodeSumMoneyTotal().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(30, true);

                cell = row.createCell(31);
//                cell.setCellValue(excelExamineBill.getNodeSumMoney() == null ? null : excelExamineBill.getNodeSumMoney().toString());
                if (excelExamineBill.getNodeSumMoney() != null) {
                    cell.setCellValue(excelExamineBill.getNodeSumMoney().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(31, true);

                cell = row.createCell(32);
                cell.setCellValue(excelExamineBill.getMarketer());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(32, true);

                cell = row.createCell(33);
                cell.setCellValue(excelExamineBill.getExecutive());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(33, true);

                cell = row.createCell(34);
                cell.setCellValue(excelExamineBill.getManager());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(34, true);

                cell = row.createCell(35);
                cell.setCellValue(excelExamineBill.getStagehand());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(35, true);

                cell = row.createCell(36);
                cell.setCellValue(excelExamineBill.getPlanner());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(36, true);

                cell = row.createCell(37);
                cell.setCellValue(excelExamineBill.getPrincipal());
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(37, true);

                cell = row.createCell(38);
//                cell.setCellValue(excelExamineBill.getDlTgSumMoney() == null ? null : excelExamineBill.getDlTgSumMoney().toString());
                if(excelExamineBill.getDlTgSumMoney() != null){
                    cell.setCellValue(excelExamineBill.getDlTgSumMoney().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(38, true);

                cell = row.createCell(39);
                cell.setCellValue(excelExamineBill.getMarketerRatio() == null ? null : excelExamineBill.getMarketerRatio().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(39, true);

                cell = row.createCell(40);
//                cell.setCellValue(excelExamineBill.getMarketerSalary() == null ? null : excelExamineBill.getMarketerSalary().toString());
                if (excelExamineBill.getMarketerSalary() != null) {
                    cell.setCellValue(excelExamineBill.getMarketerSalary().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(40, true);

                cell = row.createCell(41);
//                cell.setCellValue(excelExamineBill.getMarketerPayroll() == null ? null : excelExamineBill.getMarketerPayroll().toString());
                if (excelExamineBill.getMarketerPayroll() != null) {
                    cell.setCellValue(excelExamineBill.getMarketerPayroll().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(41, true);

                cell = row.createCell(42);
                cell.setCellValue(excelExamineBill.getExecutiveRatio() == null ? null : excelExamineBill.getExecutiveRatio().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(42, true);

                cell = row.createCell(43);
//                cell.setCellValue(excelExamineBill.getExecutiveSalary() == null ? null : excelExamineBill.getExecutiveSalary().toString());
                if (excelExamineBill.getExecutiveSalary() != null) {
                    cell.setCellValue(excelExamineBill.getExecutiveSalary().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(43, true);

                cell = row.createCell(44);
//                cell.setCellValue(excelExamineBill.getExecutivePayroll() == null ? null : excelExamineBill.getExecutivePayroll().toString());
                if (excelExamineBill.getExecutivePayroll() != null) {
                    cell.setCellValue(excelExamineBill.getExecutivePayroll().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(44, true);

                cell = row.createCell(45);
                cell.setCellValue(excelExamineBill.getManagerRatio() == null ? null : excelExamineBill.getManagerRatio().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(45, true);

                cell = row.createCell(46);
//                cell.setCellValue(excelExamineBill.getManagerSalary() == null ? null : excelExamineBill.getManagerSalary().toString());
                if (excelExamineBill.getManagerSalary() != null) {
                    cell.setCellValue(excelExamineBill.getManagerSalary().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(46, true);

                cell = row.createCell(47);
                cell.setCellValue(excelExamineBill.getManagerProportion() == null ? null : excelExamineBill.getManagerProportion().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(47, true);

                cell = row.createCell(48);
//                cell.setCellValue(excelExamineBill.getManagerPayroll() == null ? null : excelExamineBill.getManagerPayroll().toString());
                if (excelExamineBill.getManagerPayroll() != null) {
                    cell.setCellValue(excelExamineBill.getManagerPayroll().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(48, true);

                cell = row.createCell(49);
                cell.setCellValue(excelExamineBill.getStagehandRatio() == null ? null : excelExamineBill.getStagehandRatio().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(49, true);

                cell = row.createCell(50);
//                cell.setCellValue(excelExamineBill.getStagehandSalary() == null ? null : excelExamineBill.getStagehandSalary().toString());
                if (excelExamineBill.getStagehandSalary() != null) {
                    cell.setCellValue(excelExamineBill.getStagehandSalary().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(50, true);

                cell = row.createCell(51);
                cell.setCellValue(excelExamineBill.getStagehandProportion() == null ? null : excelExamineBill.getStagehandProportion().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(51, true);

                cell = row.createCell(52);
//                cell.setCellValue(excelExamineBill.getStagehandPayroll() == null ? null : excelExamineBill.getStagehandPayroll().toString());
                if (excelExamineBill.getStagehandPayroll() != null) {
                    cell.setCellValue(excelExamineBill.getStagehandPayroll().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(52, true);

                cell = row.createCell(53);
                cell.setCellValue(excelExamineBill.getPlannerRatio() == null ? null : excelExamineBill.getPlannerRatio().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(53, true);

                cell = row.createCell(54);
//                cell.setCellValue(excelExamineBill.getPlannerSalary() == null ? null : excelExamineBill.getPlannerSalary().toString());
                if (excelExamineBill.getPlannerSalary() != null) {
                    cell.setCellValue(excelExamineBill.getPlannerSalary().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(54, true);

                cell = row.createCell(55);
                cell.setCellValue(excelExamineBill.getPlannerProportion() == null ? null : excelExamineBill.getPlannerProportion().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(55, true);

                cell = row.createCell(56);
//                cell.setCellValue(excelExamineBill.getPlannerPayroll() == null ? null : excelExamineBill.getPlannerPayroll().toString());
                if (excelExamineBill.getPlannerPayroll() != null) {
                    cell.setCellValue(excelExamineBill.getPlannerPayroll().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(56, true);

                cell = row.createCell(57);
                cell.setCellValue(excelExamineBill.getPrincipalRatio() == null ? null : excelExamineBill.getPrincipalRatio().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(57, true);

                cell = row.createCell(58);
//                cell.setCellValue(excelExamineBill.getPrincipalSalary() == null ? null : excelExamineBill.getPrincipalSalary().toString());
                if (excelExamineBill.getPrincipalSalary() != null) {
                    cell.setCellValue(excelExamineBill.getPrincipalSalary().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(58, true);

                cell = row.createCell(59);
                cell.setCellValue(excelExamineBill.getPrincipalProportion() == null ? null : excelExamineBill.getPrincipalProportion().toString() + "%");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(59, true);

                cell = row.createCell(60);
//                cell.setCellValue(excelExamineBill.getPrincipalPayroll() == null ? null : excelExamineBill.getPrincipalPayroll().toString());
                if (excelExamineBill.getPrincipalPayroll() != null) {
                    cell.setCellValue(excelExamineBill.getPrincipalPayroll().doubleValue());
                }else {
                    cell.setCellValue("");
                }
                cell.setCellStyle(cellStyle_double);
                sheet.autoSizeColumn(60, true);

                cell = row.createCell(61);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(61, true);

                cell = row.createCell(62);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(62, true);

                cell = row.createCell(63);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(63, true);

                cell = row.createCell(64);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(64, true);

                cell = row.createCell(65);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(65, true);

                cell = row.createCell(66);
                cell.setCellValue("");
                cell.setCellStyle(cellStyle);
                sheet.autoSizeColumn(66, true);
            }
            row = sheet.createRow((int) list.size() + 7);
            // 创建单元格，并设置值
            XSSFCell cell = row.createCell(0);
            cell = row.createCell(23);
            cell.setCellValue("制表人：");
            cell = row.createCell(43);
            cell.setCellValue("负责人：");
            try {
                // 输出流
//                FileOutputStream fout = new FileOutputStream("D:/examineBill1.xlsx");
                workbook.write(out);
                out.close();
            } catch (Exception e) {
                e.printStackTrace();
            }

        } catch (IOException e) {
            e.printStackTrace();

        }

    }



    /**
     * 根据交易ID查询方案追加的模板列表
     *
     * @param tradeguId
     * @return 集合
     */
    @Override
    public List<Paymenttemp> selectAppendListByTradeguId(String tradeguId) {
        List<String> tradeList= new ArrayList<String>();
        tradeList.add(tradeguId);
        List<Paymenttemp> paymenttemps = paymenttempMapper.selectListByTradeguId(tradeList);
        List<Paymenttemp> collect = paymenttemps.stream().filter(paymenttemp ->
                (paymenttemp.getStopUsing() != PaymenttempEnum.PlanStatus.STATUS_STOP_USING.getCode() ||
                        paymenttemp.getTempid().equals(paymenttemp.getTgtempid()) ||
                        paymenttemp.getTempid().equals(paymenttemp.getDlftempid()))
                && (paymenttemp.getAppendType()==paymenttemp.getPlantype()
                        ||
                        ( paymenttemp.getPlantype()== (paymenttemp.getTgtempid().equals("")?1:2)
                                &&(paymenttemp.getTgtempid().equals("")||paymenttemp.getDlftempid().equals(""))
                        )
                        )
        ).collect(Collectors.toList());
        return collect;
    }

    /**
     * 核算单统计视图数据服务计算后的数据
     *
     * @param examineBillVo
     * @return
     */
    @Override
    public List<ExcelExamineBill> examineBillDetailsNew(ExamineBillVo examineBillVo) {
        /*List<TradeVo> tradeVoList = paymentdetailsMapper.workTradeByExamineBillId(examineBillVo);
        if (tradeVoList == null || tradeVoList.size() <= 0) {
            return null;
        }*/
        List<ExcelExamineBill> list = new ArrayList<>();
        ExamineReportDetails info=new ExamineReportDetails();
        info.setExamineID(examineBillVo.getExamineId());
        log.error("begin");
        List<ExamineReportDetails> detailsList=examineReportDetailsMapper.selectExamineReportDetailsList(info);
        log.error("begin1");
        detailsList.stream().forEach(p -> {
            list.add(JSON.parseObject(p.getData(),ExcelExamineBill.class));
        });
        log.error("end");
        if(1 > 2 &&list != null && list.size()>0) {
            //代理费结算标准总和
            BigDecimal AgencyFeeSum = new BigDecimal(0);
            //代理费划拨金额总和、或、佣金包金额（含收楼控存）
            BigDecimal agentfeeSum = new BigDecimal(0);
            //税金总和
            BigDecimal taxesMoneySum = new BigDecimal(0);
            //自销管理费总和
            BigDecimal manageratioMoneySum = new BigDecimal(0);
            //可支配收入
            BigDecimal controlratioMoneySum = new BigDecimal(0);
            //佣金包金额（不含收楼控存）
            BigDecimal nodeSumMoneySum = new BigDecimal(0);
            //佣金包金额（不含收楼控存）
            BigDecimal nodeSumMoneySumAll = new BigDecimal(0);
            //本次佣金实发计发金额
            BigDecimal DlTgSumMoneySum = new BigDecimal(0);
            //销售代表佣金实发金额
            BigDecimal marketerPayrollSum = new BigDecimal(0);
            //销售主管佣金实发金额
            BigDecimal executivePayrollSum = new BigDecimal(0);
            //销售经理佣金实发金额
            BigDecimal managerPayrollSum = new BigDecimal(0);
            //后台人员佣金实发金额
            BigDecimal stagehandPayrollSum = new BigDecimal(0);
            //策划人员佣金实发金额
            BigDecimal plannerPayrollSum = new BigDecimal(0);
            //自销负责人佣金实发金额
            BigDecimal principalPayrollSum = new BigDecimal(0);
            for (ExcelExamineBill excelExamineBill : list) {
                AgencyFeeSum = AgencyFeeSum.add(excelExamineBill.getAgencyFee() == null ? new BigDecimal(0) : excelExamineBill.getAgencyFee());
                agentfeeSum = agentfeeSum.add(excelExamineBill.getAgentfee() == null ? new BigDecimal(0) : excelExamineBill.getAgentfee());
                taxesMoneySum = taxesMoneySum.add(excelExamineBill.getTaxesMoney() == null ? new BigDecimal(0) : excelExamineBill.getTaxesMoney());
                manageratioMoneySum = manageratioMoneySum.add(excelExamineBill.getManageratioMoney() == null ? new BigDecimal(0) : excelExamineBill.getManageratioMoney());
                controlratioMoneySum = controlratioMoneySum.add(excelExamineBill.getControlratioMoney() == null ? new BigDecimal(0) : excelExamineBill.getControlratioMoney());
                nodeSumMoneySum = nodeSumMoneySum.add(excelExamineBill.getNodeSumMoney() == null ? new BigDecimal(0) : excelExamineBill.getNodeSumMoney());
                nodeSumMoneySumAll = nodeSumMoneySumAll.add(excelExamineBill.getNodeSumMoneyAll() == null ? new BigDecimal(0) : excelExamineBill.getNodeSumMoneyAll());
                DlTgSumMoneySum = DlTgSumMoneySum.add(excelExamineBill.getDlTgSumMoney() == null ? new BigDecimal(0) : excelExamineBill.getDlTgSumMoney());
                marketerPayrollSum = marketerPayrollSum.add(excelExamineBill.getMarketerPayroll() == null ? new BigDecimal(0) : excelExamineBill.getMarketerPayroll());
                executivePayrollSum = executivePayrollSum.add(excelExamineBill.getExecutivePayroll() == null ? new BigDecimal(0) : excelExamineBill.getExecutivePayroll());
                managerPayrollSum = managerPayrollSum.add(excelExamineBill.getManagerPayroll() == null ? new BigDecimal(0) : excelExamineBill.getManagerPayroll());
                stagehandPayrollSum = stagehandPayrollSum.add(excelExamineBill.getStagehandPayroll() == null ? new BigDecimal(0) : excelExamineBill.getStagehandPayroll());
                plannerPayrollSum = plannerPayrollSum.add(excelExamineBill.getPlannerPayroll() == null ? new BigDecimal(0) : excelExamineBill.getPlannerPayroll());
                principalPayrollSum = principalPayrollSum.add(excelExamineBill.getPrincipalPayroll() == null ? new BigDecimal(0) : excelExamineBill.getPrincipalPayroll());

            }
            ExcelExamineBill excelExamineBill = new ExcelExamineBill();
            excelExamineBill.setOrgName("总计");
            excelExamineBill.setAgentfee(agentfeeSum);
            excelExamineBill.setAgencyFee(null);
            excelExamineBill.setTaxesMoney(taxesMoneySum);
            excelExamineBill.setManageratioMoney(manageratioMoneySum);
            excelExamineBill.setControlratioMoney(controlratioMoneySum);
            excelExamineBill.setNodeSumMoney(nodeSumMoneySum);
            excelExamineBill.setNodeSumMoneyAll(nodeSumMoneySumAll);
            excelExamineBill.setDlTgSumMoney(DlTgSumMoneySum);
            excelExamineBill.setMarketerPayroll(marketerPayrollSum);
            excelExamineBill.setExecutivePayroll(executivePayrollSum);
            excelExamineBill.setManagerPayroll(managerPayrollSum);
            excelExamineBill.setStagehandPayroll(stagehandPayrollSum);
            excelExamineBill.setPlannerPayroll(plannerPayrollSum);
            excelExamineBill.setPrincipalPayroll(principalPayrollSum);
            list.add(excelExamineBill);
        }
        return list;
    }
    /**
     * 核算单统计视图数据examineBillDetailsFind
     *
     * @param examineBillVo
     * @return
     */
    @Override
    public List<ExcelExamineBill> examineBillDetailsFind(ExamineBillVo examineBillVo) {

        List<ExcelExamineBill> list=new ArrayList<>();
        ExamineBill report = examinebillMapper.examineBillShowReportstatus(examineBillVo);
        if(report.getStatus()<203 || report.getStatus()==205){
            list=examineBillDetailsShow(examineBillVo);
        }else  if(report.getReportstatus()==20){
            list=examineBillDetailsNew(examineBillVo);
        }
/*
        List<ExcelExamineBill> list=examineBillDetailsNew(examineBillVo);
        if (list == null || list.size() <= 0) {
            list=examineBillDetailsShow(examineBillVo);
        }
 */
        return list;
    }

    /*
    * 统计试图导出功能
    *
    * */


    /*
     * 核发汇总试图导出功能
     *
     * */
}

