package com.huaxia.hx_sell_commission.service.impl;

import java.lang.reflect.Array;
import java.math.BigDecimal;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;
import java.util.stream.Collectors;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.huaxia.hx_sell_commission.constant.Constants;
import com.huaxia.hx_sell_commission.domain.*;
import com.huaxia.hx_sell_commission.domain.csm.CsmSUser;
import com.huaxia.hx_sell_commission.enums.ButtonEnum;
import com.huaxia.hx_sell_commission.enums.PaymenttempEnum;
import com.huaxia.hx_sell_commission.enums.PlanEnum;
import com.huaxia.hx_sell_commission.enums.UserTypeEnum;
import com.huaxia.hx_sell_commission.exception.CustomException;
import com.huaxia.hx_sell_commission.mapper.db1.*;
import com.huaxia.hx_sell_commission.service.ICsmSUserService;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.MoneyUtils;
import com.huaxia.hx_sell_commission.vo.*;
import lombok.Data;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.huaxia.hx_sell_commission.service.IPlanService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;

/**
 * 佣金方案Service业务层处理
 *
 * @author shilei
 * @date 2020-11-18
 */
@Service
@Slf4j
public class PlanServiceImpl implements IPlanService {
    @Autowired
    private PlanMapper planMapper;

    @Autowired
    private PlanfeeMapper planfeeMapper;

    @Autowired
    private PlanfeeLogMapper planfeeLogMapper;

    @Autowired
    private TradeMapper tradeMapper;

    @Autowired
    private ICsmSUserService csmSUserService;

    @Autowired
    private PlanbalanceMapper planbalanceMapper;

    @Autowired
    private PlanbalanceLogMapper planbalanceLogMapper;

    @Autowired
    private PlanPaynodeMapper planPaynodeMapper;

    @Autowired
    private PlanPaynodeLogMapper planPaynodeLogMapper;

    @Autowired
    private PaymentdetailsMapper paymentdetailsMapper;

    @Autowired
    private PaymentdetailsLogMapper paymentdetailsLogMapper;

    /**
     * 查询佣金方案管理列表
     *
     * @param trade 佣金方案列表查询参数
     * @return 佣金方案列表
     */
    @Override
    public List<TradeVo> selectTradeList(TradeVo trade) {
        if (trade.getStatusList() != null && trade.getStatusList().size() > 0) {
            for (int i = 0; i < trade.getStatusList().size(); i++) {
                if (trade.getStatusList().get(i) == 0) {
                    trade.setPlanStatus(0);
                    trade.getStatusList().remove(i);
                }
            }
        }
        List<TradeVo> tradeVos = tradeMapper.selectTradeAllList(trade);
        if (tradeVos != null && tradeVos.size() > 0) {
            CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
            tradeVos.stream().forEach(t -> {
                getButtonList(t, csmSUser);
            });
        }
        return tradeVos;
    }

    /**
     * 查询按钮权限
     *
     * @param t
     * @return
     */
    private TradeVo getButtonList(TradeVo t, CsmSUser csmSUser) {
        List<String> button = new ArrayList<>();
        PlanVo planVo = t.getPlanVo();
        if (planVo == null) {
            // 未生成状态
            button.add(ButtonEnum.PlanBtn.ADD_BTN.getCode());
        } else {
            if (PlanEnum.PlanStatus.STATUS_CG.getCode() == planVo.getStatus()) { // 草稿
                if (planVo.getCreateuserid().equals(csmSUser != null ? csmSUser.getId() : "")) {
                    button.add(ButtonEnum.PlanBtn.UPDATE_BTN.getCode());
                }
            } else if (PlanEnum.PlanStatus.STATUS_WFQ.getCode() == planVo.getStatus()) { // 已生成
                if (planVo.getCreateuserid().equals(csmSUser != null ? csmSUser.getId() : "")) {

                    button.add(ButtonEnum.PlanBtn.INVALID_BTN.getCode());
                    if(planVo.getAppendStatus()!= PlanEnum.PlanAppendStatus.AppendIng.getCode()){
                        button.add(ButtonEnum.PlanBtn.UPDATE_BTN.getCode());
                    }

                    //待处理追加按钮
                    if(planVo.getTgtempid().equals("") || planVo.getDlftempid().equals("")||planVo.getAppendStatus()== PlanEnum.PlanAppendStatus.AppendIng.getCode()) {
                        button.add(ButtonEnum.PlanBtn.Append_Temp_BTN.getCode());
                    }
                }
                if (t.getIshouse().equals("是")) {
                    button.add(ButtonEnum.PlanBtn.RECEDE_HOUSE_ACCOUNTS_BTN.getCode());
                }
            } else if (PlanEnum.PlanStatus.STATUS_ZF.getCode() == planVo.getStatus()) { // 作废
                button.add(ButtonEnum.PlanBtn.ADD_BTN.getCode());
            } else if (PlanEnum.PlanStatus.STATUS_TF.getCode() == planVo.getStatus()) { // 退房
                button.add(ButtonEnum.PlanBtn.VIEW_BTN.getCode());
            }
        }
        t.setButton(button);
        return t;
    }

    /**
     * 新增佣金方案-1.保存修改佣金方案模板
     *
     * @param plan 佣金方案详情
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult insertPlan(List<Plan> plan) {
        if (plan != null && plan.size() > 0) {
            plan.stream().forEach(p -> {
                // 查询历史方案
                Plan plan1 = new Plan();
                plan1.setTradeguid(p.getTradeguid());
                plan1.setStatus(PlanEnum.PlanStatus.STATUS_ZF.getCode()); // 作废状态
                List<PlanVo> plans = planMapper.selectPlanListByStatus(plan1);

                CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
                Date date = new Date();

                // 新增参数
                p.setPlanid(IdUtil.simpleUUID());
                p.setStatus(PlanEnum.PlanStatus.STATUS_CG.getCode()); // 草稿状态
                p.setCreatedate(date);
                p.setCreateuser(csmSUser != null ? csmSUser.getUsername() : "");
                p.setCreateuserid(csmSUser != null ? csmSUser.getId() : "");

                if(p.getDlftempid()==null){
                    p.setDlftempid("");
                }
                if(p.getTgtempid()==null){
                    p.setTgtempid("");
                }

                if (plans != null && plans.size() > 0) { // 存在方案
                    PlanVo plan2 = plans.get(0);

                    if ("Y".equals(plan2.getExamStatus())) {
                        throw new CustomException("方案已进核算，不能修改模板", Constants.ERROR);
                    } else {
                        // 团购或代理模板变更
                        // 作废旧方案
                        plan2.setUpdateDate(date);
                        plan2.setStatus(PlanEnum.PlanStatus.STATUS_ZF.getCode());
                        plan2.setUpdateUser(csmSUser != null ? csmSUser.getUsername() : "");
                        plan2.setUpdateUserID(csmSUser != null ? csmSUser.getId() : "");
                        planMapper.updatePlan(plan2);

                        // 清除历史方案调整记录
                        planfeeMapper.deletePlanfeeById(plan2.getPlanid());
                        planPaynodeMapper.deletePlanPaynodeById(plan2.getPlanid());
                        Paymentdetails paymentdetails = new Paymentdetails();
                        paymentdetails.setPlanid(plan2.getPlanid());
                        paymentdetails.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_N.getCode());
                        paymentdetails.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_103.getCode());
                        paymentdetails.setUpdatedate(date);
                        paymentdetails.setUpdatereason("方案模板变更，历史明细作废");
                        paymentdetailsMapper.updatePaymentdetails2(paymentdetails);

                        // 保存新方案
                        planMapper.insertPlan(p);
                    }
//                    }
                } else {
                    // 保存新方案
                    planMapper.insertPlan(p);
                }
            });
        } else {
            throw new CustomException("方案详情不能为空", Constants.ERROR);
        }
        return new AjaxResult(Constants.SUCCESS, "保存成功");
    }

    /**
     * 新增佣金方案-2.查询调整佣金
     *
     * @param tradeguidList 佣金方案查询参数
     * @return 佣金方案
     */
    @Override
    public List<TradeVo> getRegulateBrokerage(List<String> tradeguidList) {
        TradeVo vo = new TradeVo();
        vo.setTradeguidList(tradeguidList);
        List<TradeVo> regulateBrokerage = tradeMapper.getRegulateBrokerage(vo);
        if (regulateBrokerage != null && regulateBrokerage.size() > 0) {
            regulateBrokerage.stream().forEach(t -> {
                List<Paymenttemp> paymenttemps = t.getPaymenttemps();
                if (paymenttemps != null && paymenttemps.size() > 0) {
                    paymenttemps.stream().forEach(p -> {
                        if (1 == p.getPlantype()) { // 团购费
                            // 拓客费用系统抓取时从交易中取否则在模板取
                            // 佣金池可用费用=团购服务费第三方销售费用*可支配费用占销售费用比例*佣金包占可支配费用比例
                            if (1 == p.getTokerfeetype()) {
                                // 团购费服务费第三方拓客费用
                                p.setTokerfee(t.getTkAmount().subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            } else if (3 == p.getTokerfeetype()){
                                // 服务费签约金额比例
                                p.setTokerFeeRatio(p.getTokerfee());
                                p.setTokerfee(MoneyUtils.multiplyHalfEven(
                                        t.getRmbhttotal().toString(), p.getTokerfee().toString(), "0.01", 0).subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }
                            else {
                                p.setTokerfee(p.getTokerfee().subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }

                            // 自销管理费
                            p.setManageAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getManageratio().toString(), "0.01", 0));

                            // 税金金额
                            p.setTaxesAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getTaxes().toString(), "0.01", 0));

                            // 可支配收入占第三方拓客费
                            p.setControlAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getControlratio().toString(), "0.01", 0));

                            // 佣金包占可支配费用
                            p.setPaymentpackAmount(MoneyUtils.multiplyHalfEven(
                                    p.getControlAmount().toString(), p.getPaymentpack().toString(), "0.01", 0));

                            // 团购费佣金
                            p.setTkAmount(p.getPaymentpackAmount());

                            if (1 == p.getTokerfeetype()) {
                                // 团购费服务费第三方拓客费用
                                p.setTokerfee(t.getTkAmount());
                            } else if (3 == p.getTokerfeetype()){
                                // 服务费签约金额比例
                                p.setTokerfee(p.getTokerfee().add(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }
                            else{
                                p.setTokerfee(p.getTokerfee().add(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }

                        } else { // 代理费
                            // 佣金池可用费用=[代理费-代理费*（自销管理费比例+税金比例）-交房保证金]*佣金包占可支配收入比例

                            // 代理费
                            if (1 == p.getAgencyfeetype()) {
                                p.setAgencyFeeRatio(p.getAgencyFee());
                                p.setAgencyFee(MoneyUtils.multiplyHalfEven(
                                        t.getRmbhttotal().toString(), p.getAgencyFee().toString(), "0.01", 0).subtract(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            else{
                                p.setAgencyFee(p.getAgencyFee().subtract(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            // 交房保证金
                            if (1 == p.getJfbondtype()) {
                                p.setJfbond(MoneyUtils.multiplyHalfEven(
                                        p.getAgencyFee().toString(), p.getJfbond().toString(), "0.01", 0));
                            }

                            // 代理费-代理费*（自销管理费比例+税金比例）-交房保证金
                            BigDecimal sum = p.getAgencyFee().subtract(MoneyUtils.multiplyHalfEven(p.getAgencyFee().toString(),
                                    String.valueOf(p.getTaxes().add(p.getManageratio())), "0.01", 0));

                            if (p.getJfbondIsDeduct() != null && p.getJfbondIsDeduct() == 1) { // 扣除交房保证金
                                sum = sum.subtract(p.getJfbond());
                            }
                            // 代理费佣金
                            p.setAgencyAmount(MoneyUtils.multiplyHalfEven(sum.toString(), p.getPaymentpack().toString(), "0.01", 0));

                            // 自销管理费
                            p.setManageAmount(MoneyUtils.multiplyHalfEven(
                                    p.getAgencyFee().toString(), p.getManageratio().toString(), "0.01", 0));

                            // 税金金额
                            p.setTaxesAmount(MoneyUtils.multiplyHalfEven(
                                    p.getAgencyFee().toString(), p.getTaxes().toString(), "0.01", 0));

                            // 佣金包占可支配费用
                            p.setPaymentpackAmount(MoneyUtils.multiplyHalfEven(
                                    sum.toString(), p.getPaymentpack().toString(), "0.01", 0));

                            if (1 == p.getAgencyfeetype()) {
                                p.setAgencyFee(p.getAgencyFee().add(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            else{
                                p.setAgencyFee(p.getAgencyFee().add(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                        }
                    });
                }
            });
        }
        return regulateBrokerage;
    }

    @Override
    public List<TradeVo> getRegulateBrokerage2(List<String> tradeguidList, ExamineBillVo examineBillVo) {
        TradeVo vo = new TradeVo();
        vo.setTradeguidList(tradeguidList);
        vo.setExamineid(examineBillVo.getExamineId());
        List<TradeVo> regulateBrokerage = tradeMapper.getRegulateBrokerage2(vo);
        if (regulateBrokerage != null && regulateBrokerage.size() > 0) {
            regulateBrokerage.stream().forEach(t -> {
                List<Paymenttemp> paymenttemps = t.getPaymenttemps();
                if (paymenttemps != null && paymenttemps.size() > 0) {
                    paymenttemps.stream().forEach(p -> {
                        if (1 == p.getPlantype()) { // 团购费
                            // 拓客费用系统抓取时从交易中取否则在模板取
                            // 佣金池可用费用=团购服务费第三方销售费用*可支配费用占销售费用比例*佣金包占可支配费用比例
                            if (1 == p.getTokerfeetype()) {
                                // 团购费服务费第三方拓客费用
                                // p.setTokerfee(t.getTkAmount());
                                p.setServiceFeeSettlementStandard(t.getTkAmount() + "");
                            } else if (3 == p.getTokerfeetype()){
                                // 服务费签约金额比例
                                // p.setTokerfee(p.getTokerfee());
                                p.setServiceFeeSettlementStandard(p.getTokerfee() + "%");
                            }else {
                                // p.setTokerfee(p.getTokerfee());
                                p.setServiceFeeSettlementStandard(p.getTokerfee() + "");
                            }
                        }
                    });
                }
            });
        }
        return regulateBrokerage;
    }

    @Override
    public List<TradeVo> getRegulateBrokerage3(List<String> tradeguidList, ExamineBillVo examineBillVo) {
        TradeVo vo = new TradeVo();
        vo.setTradeguidList(tradeguidList);
        vo.setExamineid(examineBillVo.getExamineId());
        List<TradeVo> regulateBrokerage = tradeMapper.getRegulateBrokerage2(vo);
        if (regulateBrokerage != null && regulateBrokerage.size() > 0) {
            regulateBrokerage.stream().forEach(t -> {
                List<Paymenttemp> paymenttemps = t.getPaymenttemps();
                if (paymenttemps != null && paymenttemps.size() > 0) {
                    paymenttemps.stream().forEach(p -> {
                        if (1 == p.getPlantype()) { // 团购费
                            p.setDeuctVal(t.getPlanVo().getTgdeuctval()); //回写自定义扣减金额
                            // 拓客费用系统抓取时从交易中取否则在模板取
                            // 佣金池可用费用=团购服务费第三方销售费用*可支配费用占销售费用比例*佣金包占可支配费用比例
                            if (1 == p.getTokerfeetype()) {
                                // 团购费服务费第三方拓客费用
                                p.setTokerfee(t.getTkAmount().subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            } else if (3 == p.getTokerfeetype()){
                                // 服务费签约金额比例
                                p.setTokerFeeRatio(p.getTokerfee());
                                p.setTokerfee(MoneyUtils.multiplyHalfEven(
                                        t.getRmbhttotal().toString(), p.getTokerfee().toString(), "0.01", 0).subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }
                            else {
                                p.setTokerfee(p.getTokerfee().subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }

                            // 自销管理费
                            p.setManageAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getManageratio().toString(), "0.01", 0));

                            // 税金金额
                            p.setTaxesAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getTaxes().toString(), "0.01", 0));

                            // 可支配收入占第三方拓客费
                            p.setControlAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getControlratio().toString(), "0.01", 0));

                            // 佣金包占可支配费用
                            p.setPaymentpackAmount(MoneyUtils.multiplyHalfEven(
                                    p.getControlAmount().toString(), p.getPaymentpack().toString(), "0.01", 0));

                            // 团购费佣金
                            p.setTkAmount(p.getPaymentpackAmount());


                            if (1 == p.getTokerfeetype()) {
                                // 团购费服务费第三方拓客费用
                                p.setTokerfee(t.getTkAmount());
                            } else if (3 == p.getTokerfeetype()){
                                // 服务费签约金额比例
                                p.setTokerfee(p.getTokerfee().add(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }
                            else{
                                p.setTokerfee(p.getTokerfee().add(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }

                        } else { // 代理费
                            // 佣金池可用费用=[代理费-代理费*（自销管理费比例+税金比例）-交房保证金]*佣金包占可支配收入比例
                            p.setDeuctVal(t.getPlanVo().getDlfdeuctval()); //回写自定义扣减金额
                            // 代理费
                            if (1 == p.getAgencyfeetype()) {
                                p.setAgencyFeeRatio(p.getAgencyFee());
                                p.setAgencyFee(MoneyUtils.multiplyHalfEven(
                                        t.getRmbhttotal().toString(), p.getAgencyFee().toString(), "0.01", 0).subtract(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            else{
                                p.setAgencyFee(p.getAgencyFee().subtract(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            // 交房保证金
                            if (1 == p.getJfbondtype()) {
                                p.setJfbond(MoneyUtils.multiplyHalfEven(
                                        p.getAgencyFee().toString(), p.getJfbond().toString(), "0.01", 0));
                            }

                            // 代理费-代理费*（自销管理费比例+税金比例）-交房保证金
                            BigDecimal sum = p.getAgencyFee().subtract(MoneyUtils.multiplyHalfEven(p.getAgencyFee().toString(),
                                    String.valueOf(p.getTaxes().add(p.getManageratio())), "0.01", 0));

                            if (p.getJfbondIsDeduct() != null && p.getJfbondIsDeduct() == 1) { // 扣除交房保证金
                                sum = sum.subtract(p.getJfbond());
                            }
                            // 代理费佣金
                            p.setAgencyAmount(MoneyUtils.multiplyHalfEven(sum.toString(), p.getPaymentpack().toString(), "0.01", 0));

                            // 自销管理费
                            p.setManageAmount(MoneyUtils.multiplyHalfEven(
                                    p.getAgencyFee().toString(), p.getManageratio().toString(), "0.01", 0));

                            // 税金金额
                            p.setTaxesAmount(MoneyUtils.multiplyHalfEven(
                                    p.getAgencyFee().toString(), p.getTaxes().toString(), "0.01", 0));

                            // 佣金包占可支配费用
                            p.setPaymentpackAmount(MoneyUtils.multiplyHalfEven(
                                    sum.toString(), p.getPaymentpack().toString(), "0.01", 0));

                            if (1 == p.getAgencyfeetype()) {
                                p.setAgencyFee(p.getAgencyFee().add(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            else{
                                p.setAgencyFee(p.getAgencyFee().add(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                        }
                    });
                }
            });
        }
        return regulateBrokerage;
    }

    /**
     * 新增修改佣金方案-2.保存调整佣金
     *
     * @param planfees
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult insertPlanfee(List<Planfee> planfees) {
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        Date date = new Date();
        if (planfees != null && planfees.size() > 0) {
            planfees.stream().forEach(p -> {
                p.setCreatedate(date);
                p.setCreateuser(csmSUser != null ? csmSUser.getUsername() : "");
                p.setCreateuserid(csmSUser != null ? csmSUser.getId() : "");

                Planfee planfee = planfeeMapper.selectPlanfeeById(p.getPlanid());
                if (planfee != null) {
                    //修改调整佣金
                    planfeeMapper.updatePlanfee(p);
                } else {
                    //新增调整佣金
                    planfeeMapper.insertPlanfee(p);
                }
                // 保存记录
                PlanfeeLog planfeeLog = new PlanfeeLog();
                planfeeLog.setPlanid(p.getPlanid());
                planfeeLog.setTradeguid(p.getTradeguid());
                planfeeLog.setTgfee(p.getTgfee());
                planfeeLog.setTgremarks(p.getTgremarks());
                planfeeLog.setAgentfee(p.getAgentfee());
                planfeeLog.setAgentremarks(p.getAgentremarks());
                planfeeLog.setCreateuser(p.getCreateuser());
                planfeeLog.setCreatedate(p.getCreatedate());
                planfeeLog.setCreateuserid(p.getCreateuserid());
                planfeeLogMapper.insertPlanfeeLog(planfeeLog);
            });
        } else {
            throw new CustomException("方案详情不能为空", Constants.ERROR);
        }
        return new AjaxResult(Constants.SUCCESS, "保存成功");
    }

    /**
     * 新增佣金方案-3.查询结算方案
     *
     * @param tradeguidList 佣金方案查询参数
     * @return 佣金方案
     */
    @Override
    public List<TradeVo> getSettlePlan(List<String> tradeguidList) {
        if (tradeguidList == null || tradeguidList.size() < 1) {
            log.error("交易ID不能为空");
            return null;
        }
        TradeVo vo = new TradeVo();
        vo.setTradeguidList(tradeguidList);
        List<TradeVo> settlePlan = tradeMapper.getRegulateBrokerage(vo);
        if (settlePlan != null && settlePlan.size() > 0) {
            settlePlan.stream().forEach(t -> {
                // 佣金方案详情
                PlanVo planVo = t.getPlanVo();
                // 方案支付节点信息
                List<PlanPaynodeVo> planPaynodeVos1 = planVo != null ? planVo.getPlanPaynodeVos() : null;
                if (planPaynodeVos1 == null || planPaynodeVos1.size() < 1) {
                    // 佣金方案费用信息
                    Planfee planfee = t.getPlanfee();
                    // 佣金方案_支付节点对象集合
                    List<PlanPaynodeVo> planPaynodeVos = new ArrayList<>();
                    List<Paymenttemp> paymenttemps = t.getPaymenttemps();
                    if (paymenttemps != null && paymenttemps.size() > 0) {
                        paymenttemps.stream().forEach(p -> {
                            List<PaymenttempNode> nodes = p.getNodes();
                            List<PaymenttempDistribution> distributions = p.getDistributions();
                            if (t.getPlanVo().getTgtempid().equals(p.getTempid())) { // 团购费模板
                                if (nodes != null && nodes.size() > 0) {
                                    AtomicLong tgTotal = new AtomicLong(planfee.getTgfee().longValue());
                                    nodes.stream().forEach(node -> {
                                        PlanPaynodeVo planPaynodeVo = new PlanPaynodeVo();
                                        planPaynodeVo.setPlanid(planVo.getPlanid());
                                        planPaynodeVo.setTradeguid(t.getTradeguid());

                                        // 团购费支付节点总额
                                        planPaynodeVo.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                planfee.getTgfee().toString(), node.getPayratio().toString(), "0.01", 0));

                                        if (nodes.get(nodes.size() - 1).getNodeid().equals(node.getNodeid())) {
                                            planPaynodeVo.setPaytotal(new BigDecimal(tgTotal.toString()));
                                        } else { // 非最后一个节点
                                            // 除最后一个节点外，其余节点金额求和
                                            tgTotal.set(tgTotal.longValue() - planPaynodeVo.getPaytotal().longValue());
                                        }

                                        // 报备人分配
                                        if (null != p.getFixedratio()) {
                                            planPaynodeVo.setFixfee(MoneyUtils.multiplyHalfEven(
                                                    planPaynodeVo.getPaytotal().toString(), p.getFixedratio().toString(), "0.01", 2));
                                        }

                                        // 团购费节点
                                        planPaynodeVo.setPlantype(1L);
                                        planPaynodeVo.setNodeid(node.getNodeid());
                                        planPaynodeVo.setNodename(node.getNodename());
                                        planPaynodeVo.setFixFeeEdit(1);
                                        planPaynodeVo.setUser(t.getRefer());
                                        planPaynodeVo.setUserId(t.getReferid());
                                        planPaynodeVo.setPayRatio(node.getPayratio());
                                        planPaynodeVo.setFixFeeRatio(p.getFixedratio());
                                        planPaynodeVo.setNoPayRatio(p.getNopay());

                                        List<Planbalance> planbalances = new ArrayList<>();

                                        // 添加后台人员结算方案明细
                                        if (distributions != null && distributions.size() > 0) {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), p.getNopay().toString(), "0.01", 2));
                                            }

                                            final BigDecimal[] sum = {(planPaynodeVo.getPaytotal()
                                                    .subtract(planPaynodeVo.getFixfee() != null ? planPaynodeVo.getFixfee() : new BigDecimal(0))
                                                    .subtract(planPaynodeVo.getNopay() != null ? planPaynodeVo.getNopay() : new BigDecimal(0)))};
                                            AtomicInteger i = new AtomicInteger(distributions.size());
                                            distributions.stream().sorted(Comparator.comparing(PaymenttempDistribution :: getPayratio)).forEach(d -> {
                                                Planbalance planbalance = new Planbalance();
                                                planbalance.setPlanid(planVo.getPlanid());
                                                planbalance.setTradeguid(t.getTradeguid());
                                                planbalance.setNodeid(node.getNodeid());
                                                planbalance.setUsertypeid(d.getUsertypeid());
                                                planbalance.setUsertypename(d.getUsertypename());
                                                planbalance.setJobname(d.getJobname());
                                                planbalance.setUser(d.getUser());
                                                planbalance.setUserid(d.getUserid());

                                                planbalance.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), d.getPayratio().toString(), "0.01", 2));
                                                // 20210521
                                                if (planbalance.getPaytotal().compareTo(new BigDecimal(0)) == 0) {
                                                    planbalance.setPaytotal(new BigDecimal("0.01"));
                                                }
                                                i.set(i.get() - 1);
                                                // 判断是否循环末尾
                                                if (i.get() == 0) {
                                                    planbalance.setPaytotal(sum[0]);
                                                } else { // 非循环末尾
                                                    sum[0] =(sum[0].subtract(planbalance.getPaytotal()));
                                                }

                                                if (null != d.getSfratio()) {
                                                    planbalance.setFirstpay(MoneyUtils.multiplyHalfEven(
                                                            planbalance.getPaytotal().toString(), d.getSfratio().toString(), "0.01", 2));
                                                }

                                                // 末批 = 总额 - 首批
                                                planbalance.setLastpay(planbalance.getPaytotal().subtract(planbalance.getFirstpay()));

                                                planbalance.setPlanType(1L);
                                                planbalance.setFirstEdit(1L);
                                                planbalance.setLastEdit(1L);
                                                planbalance.setPayRatio(d.getPayratio());
                                                planbalance.setFirstPayRatio(d.getSfratio());
                                                planbalance.setLastPayRatio(d.getMfratio());
                                                planbalances.add(planbalance);
                                            });
                                        } else {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(planPaynodeVo.getPaytotal().subtract(planPaynodeVo.getFixfee()));
                                            }
                                        }
                                        planPaynodeVo.setPlanbalances(planbalances);
                                        planPaynodeVos.add(planPaynodeVo);
                                    });
                                }
                            } else if (t.getPlanVo().getDlftempid().equals(p.getTempid())) { // 代理费模板
                                if (nodes != null && nodes.size() > 0) {
                                    AtomicLong dlTotal = new AtomicLong(planfee.getAgentfee().longValue());
                                    nodes.stream().forEach(node -> {
                                        PlanPaynodeVo planPaynodeVo = new PlanPaynodeVo();
                                        planPaynodeVo.setPlanid(planVo.getPlanid());
                                        planPaynodeVo.setTradeguid(t.getTradeguid());
                                        // 代理费支付节点总额
                                        planPaynodeVo.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                planfee.getAgentfee().toString(), node.getPayratio().toString(), "0.01", 0));

                                        if (nodes.get(nodes.size() - 1).getNodeid().equals(node.getNodeid())) {
                                            planPaynodeVo.setPaytotal(new BigDecimal(dlTotal.toString()));
                                        } else { // 非最后一个节点
                                            // 除最后一个节点外，其余节点金额求和
                                            dlTotal.set(dlTotal.get() - planPaynodeVo.getPaytotal().longValue());
                                        }

                                        // 接待人分配
                                        if (null != p.getFixedratio()) {
                                            planPaynodeVo.setFixfee(MoneyUtils.multiplyHalfEven(
                                                    planPaynodeVo.getPaytotal().toString(), p.getFixedratio().toString(), "0.01", 2));
                                        }

                                        // 代理费节点
                                        planPaynodeVo.setPlantype(2L);
                                        planPaynodeVo.setNodeid(node.getNodeid());
                                        planPaynodeVo.setNodename(node.getNodename());
                                        planPaynodeVo.setFixFeeEdit(1);
                                        planPaynodeVo.setUser(t.getYwy());
                                        planPaynodeVo.setUserId(t.getYwyid());
                                        planPaynodeVo.setPayRatio(node.getPayratio());
                                        planPaynodeVo.setFixFeeRatio(p.getFixedratio());
                                        planPaynodeVo.setNoPayRatio(p.getNopay());

                                        List<Planbalance> planbalances = new ArrayList<>();

                                        // 添加后台人员结算方案明细
                                        if (distributions != null && distributions.size() > 0) {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), p.getNopay().toString(), "0.01", 2));
                                            }

                                            final BigDecimal[] sum = {(planPaynodeVo.getPaytotal()
                                                    .subtract(planPaynodeVo.getFixfee() != null ? planPaynodeVo.getFixfee() : new BigDecimal(0))
                                                    .subtract(planPaynodeVo.getNopay() != null ? planPaynodeVo.getNopay() : new BigDecimal(0)))};
                                            AtomicInteger i = new AtomicInteger(distributions.size());
                                            distributions.stream().sorted(Comparator.comparing(PaymenttempDistribution :: getPayratio)).forEach(d -> {
                                                Planbalance planbalance = new Planbalance();
                                                planbalance.setPlanid(planVo.getPlanid());
                                                planbalance.setTradeguid(t.getTradeguid());
                                                planbalance.setNodeid(node.getNodeid());
                                                planbalance.setUsertypeid(d.getUsertypeid());
                                                planbalance.setUsertypename(d.getUsertypename());
                                                planbalance.setJobname(d.getJobname());
                                                planbalance.setUser(d.getUser());
                                                planbalance.setUserid(d.getUserid());

                                                planbalance.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), d.getPayratio().toString(), "0.01", 2));
                                                // 20210521
                                                if (planbalance.getPaytotal().compareTo(new BigDecimal(0)) == 0) {
                                                    planbalance.setPaytotal(new BigDecimal("0.01"));
                                                }
                                                i.set(i.get() - 1);
                                                // 判断是否循环末尾
                                                if (i.get() == 0) {
                                                    planbalance.setPaytotal(sum[0]);
                                                } else { // 非循环末尾
                                                    sum[0] =(sum[0].subtract(planbalance.getPaytotal()));
                                                }

                                                if (null != d.getSfratio()) {
                                                    planbalance.setFirstpay(MoneyUtils.multiplyHalfEven(
                                                            planbalance.getPaytotal().toString(), d.getSfratio().toString(), "0.01", 2));
                                                }

                                                // 末批 = 总额 - 首批
                                                planbalance.setLastpay(planbalance.getPaytotal().subtract(planbalance.getFirstpay()));

                                                planbalance.setPlanType(1L);
                                                planbalance.setFirstEdit(1L);
                                                planbalance.setLastEdit(1L);
                                                planbalance.setPayRatio(d.getPayratio());
                                                planbalance.setFirstPayRatio(d.getSfratio());
                                                planbalance.setLastPayRatio(d.getMfratio());
                                                planbalances.add(planbalance);
                                            });
                                        } else {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(planPaynodeVo.getPaytotal().subtract(planPaynodeVo.getFixfee()));
                                            }
                                        }
                                        planPaynodeVo.setPlanbalances(planbalances);
                                        planPaynodeVos.add(planPaynodeVo);
                                    });
                                }
                            }
                        });
                    }
                    planVo.setPlanPaynodeVos(planPaynodeVos);
                }
            });
        }
        return settlePlan;
    }

    /**
     * 新增佣金方案-3.方案试算
     *
     * @param tradeVoList 佣金方案试算 参数
     * @return 佣金方案
     */
    @Override
    public List<TradeVo> planCalculation(List<TradeVo> tradeVoList) {
        if (tradeVoList == null || tradeVoList.size() < 1) {
            throw new CustomException("交易信息不能为空", Constants.ERROR);
        }
        tradeVoList.stream().forEach(t -> {
            PlanVo plan = t.getPlanVo();
            if (plan == null) {
                throw new CustomException("方案信息不能为空", Constants.ERROR);
            }

            List<PlanPaynodeVo> planPaynodeVos = plan.getPlanPaynodeVos();
            if (planPaynodeVos == null || planPaynodeVos.size() < 1) {
                throw new CustomException("支付节点信息不能为空", Constants.ERROR);
            }

            Planfee planfee = t.getPlanfee();
            if (planfee == null) {
                throw new CustomException("费用信息不能为空", Constants.ERROR);
            }

            BigDecimal tgTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 1).map(n -> n.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add);

            BigDecimal dlTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 2).map(n -> n.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if (tgTotal.compareTo(new BigDecimal(0)) != 0 && tgTotal.compareTo(new BigDecimal(100)) != 0) {
                throw new CustomException("团购节点比例之和不等于100%", Constants.ERROR);
            }

            if (dlTotal.compareTo(new BigDecimal(0)) != 0 && dlTotal.compareTo(new BigDecimal(100)) != 0) {
                throw new CustomException("代理节点比例之和不等于100%", Constants.ERROR);
            }

            // 团购节点数
            AtomicLong tgSum = new AtomicLong(planPaynodeVos.stream().filter(n -> n.getPlantype() == 1).count());
            // 团购费
            AtomicLong tgf = new AtomicLong(planfee.getTgfee() != null ? planfee.getTgfee().longValue() : 0);
            // 代理节点数
            AtomicLong dlSum = new AtomicLong(planPaynodeVos.stream().filter(n -> n.getPlantype() == 2).count());
            // 代理费
            AtomicLong dlf = new AtomicLong(planfee.getAgentfee() != null ? planfee.getAgentfee().longValue() : 0);

            planPaynodeVos.stream().forEach(node -> {
                List<Planbalance> planbalances = node.getPlanbalances();
                // 节点下人员分配比例之和
                BigDecimal balancesTotal = new BigDecimal(0);
                balancesTotal = balancesTotal.add(node.getFixFeeRatio() != null ? node.getFixFeeRatio() : new BigDecimal(0))
                        .add(node.getNoPayRatio() != null ? node.getNoPayRatio() : new BigDecimal(0));

                // 计算节点
                if (node.getPlantype() == 1) { // 团购节点
                    tgSum.set(tgSum.get() - 1);
                    // 判断是否循环末尾
                    if (tgSum.get() == 0) {
                        node.setPaytotal(new BigDecimal(tgf.toString()));
                    } else { // 非循环末尾
                        node.setPaytotal(MoneyUtils.multiplyHalfEven(
                                planfee.getTgfee().toString(), node.getPayRatio().toString(), "0.01", 0));
                        tgf.set(tgf.longValue() - node.getPaytotal().longValue());
                    }
                } else { // 代理节点
                    dlSum.set(dlSum.get() - 1);
                    // 判断是否循环末尾
                    if (dlSum.get() == 0) {
                        node.setPaytotal(new BigDecimal(dlf.toString()));
                    } else { // 非循环末尾
                        node.setPaytotal(MoneyUtils.multiplyHalfEven(
                                planfee.getAgentfee().toString(), node.getPayRatio() != null ? node.getPayRatio().toString() : "0"
                                , "0.01", 0));
                        dlf.set(dlf.longValue() - node.getPaytotal().longValue());
                    }
                }

                if (node.getFixFeeEdit() == 1) { // 可编辑
                    // 计算报备人分配金额
                    node.setFixfee(MoneyUtils.multiplyHalfEven(
                            node.getPaytotal().toString(), node.getFixFeeRatio() != null ? node.getFixFeeRatio().toString() : "0"
                            , "0.01", 2));
                }

                if (planbalances != null && planbalances.size() > 0) {

                    balancesTotal = balancesTotal.add(planbalances.stream().filter(b -> b.getPayRatio() != null)
                            .map(b -> b.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add));

                    // 计算不予结算金额
                    node.setNopay(MoneyUtils.multiplyHalfEven(
                            node.getPaytotal().toString(), node.getNoPayRatio() != null ? node.getNoPayRatio().toString() : "0"
                            , "0.01", 2));

                    // 计算节点下人员分配金额
                    AtomicLong bcount = new AtomicLong(planbalances.size());
                    // 总金额
                    final BigDecimal[] countM = {node.getPaytotal()
                            .subtract(node.getFixfee() != null ? node.getFixfee() : new BigDecimal(0))
                            .subtract(node.getNopay() != null ? node.getNopay() : new BigDecimal(0))};
                    planbalances.stream().sorted(Comparator.comparing(Planbalance::getPayRatio)).forEach(b -> {
                        BigDecimal fb = b.getFirstPayRatio() != null ? b.getFirstPayRatio() : new BigDecimal(0);
                        BigDecimal lb = b.getLastPayRatio() != null ? b.getLastPayRatio() : new BigDecimal(0);
                        if (fb.add(lb).compareTo(new BigDecimal(100)) != 0) {
                            throw new CustomException("人员首批末批比例之和不等于100%", Constants.ERROR);
                        }
                        bcount.set(bcount.get() - 1);
                        // 判断是否循环末尾
                        if (bcount.get() == 0) {
                            b.setPaytotal(countM[0]);
                        } else { // 非循环末尾
                            b.setPaytotal(MoneyUtils.multiplyHalfEven(
                                    node.getPaytotal().toString(), b.getPayRatio() != null ? b.getPayRatio().toString() : "0"
                                    , "0.01", 2));
                            // 20210519
                            if (b.getPaytotal().compareTo(new BigDecimal(0)) == 0) {
                                    b.setPaytotal(new BigDecimal("0.01"));
                            }

                            countM[0] =(countM[0].subtract(b.getPaytotal() != null ? b.getPaytotal() :  new BigDecimal(0)));
                        }
                        if (b.getFirstEdit() == 1) { // 首批可编辑
                            b.setFirstpay(MoneyUtils.multiplyHalfEven(
                                    b.getPaytotal() != null ? b.getPaytotal().toString() : "0", fb.toString(), "0.01", 2));
                        }
                        if (b.getFirstEdit() == 1) { // 末批可编辑
                            b.setLastpay(b.getPaytotal().subtract(b.getFirstpay()));
                        }
                    });
                } else {
                    // 计算不予结算金额
                    node.setNopay(node.getPaytotal().subtract(node.getFixfee()));
                }
                if (balancesTotal.compareTo(new BigDecimal(100)) != 0) {
                    throw new CustomException("节点人员分配比例之和不等于100%", Constants.ERROR);
                }
            });
        });
        return tradeVoList;
    }

    /**
     * 新增佣金方案-3.保存修改结算方案
     *
     * @param tradeVoList
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult insertSettlePlan(List<TradeVo> tradeVoList) {
        if (tradeVoList == null || tradeVoList.size() < 1) {
            throw new CustomException("交易信息不能为空", Constants.ERROR);
        }
        tradeVoList.stream().forEach(t -> {
            PlanVo plan = t.getPlanVo();
            if (plan == null) {
                throw new CustomException("方案信息不能为空", Constants.ERROR);
            }

            List<PlanPaynodeVo> planPaynodeVos = plan.getPlanPaynodeVos();
            if (planPaynodeVos == null || planPaynodeVos.size() < 1) {
                throw new CustomException("支付节点信息不能为空", Constants.ERROR);
            }

            Planfee planfee = t.getPlanfee();
            if (planfee == null) {
                throw new CustomException("费用信息不能为空", Constants.ERROR);
            }

            // 删除旧节点
            planPaynodeMapper.deletePlanPaynodeById(plan.getPlanid());

            BigDecimal tgTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 1).map(n -> n.getPaytotal()).reduce(BigDecimal.ZERO, BigDecimal::add);

            BigDecimal dlTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 2).map(n -> n.getPaytotal()).reduce(BigDecimal.ZERO, BigDecimal::add);

            BigDecimal tgRatioTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 1).map(n -> n.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add);

            BigDecimal dlRatioTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 2).map(n -> n.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if (tgRatioTotal != null && tgRatioTotal.compareTo(new BigDecimal(0)) == 1 && tgRatioTotal.compareTo(new BigDecimal(100)) != 0) {
                throw new CustomException("团购节点比例之和不等于100%", Constants.ERROR);
            }

            if (dlRatioTotal != null && dlRatioTotal.compareTo(new BigDecimal(0)) == 1 && dlRatioTotal.compareTo(new BigDecimal(100)) != 0) {
                throw new CustomException("代理节点比例之和不等于100%", Constants.ERROR);
            }

            planPaynodeVos.stream().forEach(node -> {

                ArrayList<String> addOrUpdatePayIds = new ArrayList<>();

                Date date = new Date();

                // 保存支付节点数据
                addplanPaynodeVos(plan, node, date);

                // 添加修改不予结算数据
                editNoPayDetails(plan, node, date);

                // 添加修改报备人员明细 PaymentDetails
                editReferDetails(t, plan, node, date);

                List<Planbalance> planbalances = node.getPlanbalances();

                // 新增或变更的人员ID集合
                List<String> userIds = new ArrayList<>();

                // 删除旧人员方案明细
                deletePlanbalance(plan, node);

                // 节点下人员分配比例之和
                BigDecimal balancesTotal = new BigDecimal(0);
                balancesTotal = balancesTotal.add(node.getFixFeeRatio() != null ? node.getFixFeeRatio() : new BigDecimal(0))
                        .add(node.getNoPayRatio() != null ? node.getNoPayRatio() : new BigDecimal(0));

                BigDecimal nodeTotal = new BigDecimal(0);
                if (planbalances != null && planbalances.size() > 0) {
                    balancesTotal = balancesTotal.add(planbalances.stream().filter(b -> b.getPayRatio() != null)
                            .map(b -> b.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add));

                    AtomicLong i = new AtomicLong();
                    planbalances.stream().forEach(balance -> {
                        i.addAndGet(1);
                        balance.setSort(i.get());
                        BigDecimal sum = new BigDecimal(0);
                        sum = sum.add(balance.getFirstpay() != null ? balance.getFirstpay() : new BigDecimal(0));
                        sum = sum.add(balance.getLastpay() != null ? balance.getLastpay() : new BigDecimal(0));

                        if (balance.getPaytotal().compareTo(sum) != 0) {
                            throw new CustomException("人员首期加末期费用不等于总支付金额", Constants.ERROR);
                        }

                        BigDecimal fb = balance.getFirstPayRatio() != null ? balance.getFirstPayRatio() : new BigDecimal(0);
                        BigDecimal lb = balance.getLastPayRatio() != null ? balance.getLastPayRatio() : new BigDecimal(0);
                        if (fb.add(lb).compareTo(new BigDecimal(100)) != 0) {
                            throw new CustomException("人员首批末批比例之和不等于100%", Constants.ERROR);
                        }

                        userIds.add(balance.getUserid());

//                        nodeTotal.addAndGet(balance.getPaytotal().longValue());

                        if (StrUtil.isBlank(balance.getUser()) || StrUtil.isBlank(balance.getUserid())) {
                            throw new CustomException("引入人员信息不能为空", Constants.ERROR);
                        }

                        // 后台人员结算方案明细保存
                        addPlanbalance(plan, node, balance, date);
                        // 添加修改方案预览
                        ArrayList<String> payIdList = addOrUpdatePaymentdetails(plan, node, balance, date);
                        addOrUpdatePayIds.addAll(payIdList);

                    });
                    nodeTotal = planbalances.stream().filter(
                            b -> b.getPaytotal() != null).map(b -> b.getPaytotal()).reduce(BigDecimal.ZERO, BigDecimal::add);
                }

                if (balancesTotal.compareTo(new BigDecimal(100)) != 0) {
                    throw new CustomException("节点人员分配比例之和不等于100%", Constants.ERROR);
                }

                if (null != node.getFixfee()) {
                    nodeTotal = nodeTotal.add(node.getFixfee());
                }
                if (null != node.getNopay()) {
                    nodeTotal = nodeTotal.add(node.getNopay());
                }

                if (node.getPaytotal().compareTo(nodeTotal) != 0) {
                    throw new CustomException("各费用相加不等于节点总金额", Constants.ERROR);
                }

                // 明细删除
                deletePaymentdetails(node, userIds, date, addOrUpdatePayIds);
            });
            if ((null != dlTotal && null != planfee.getAgentfee() && planfee.getAgentfee().compareTo(dlTotal) != 0) ||
                    (null != tgTotal && null != planfee.getTgfee() && planfee.getTgfee().compareTo(tgTotal) != 0)) {
                throw new CustomException("各支付节点费用相加不等于佣金总费用", Constants.ERROR);
            }
        });
        return new AjaxResult(Constants.SUCCESS, "保存成功");
    }

    /**
     * 保存支付节点数据
     *
     * @param plan
     * @param node
     * @param date
     */
    private void addplanPaynodeVos(PlanVo plan, PlanPaynodeVo node, Date date) {
        PlanPaynode planPaynode = node;
        planPaynode.setPlanid(plan.getPlanid());
        planPaynode.setTradeguid(plan.getTradeguid());
        planPaynode.setCreateDate(date);
        planPaynode.setFixFeeEdit(node.getFixFeeEdit());
        // 添加新节点
        planPaynodeMapper.insertPlanPaynode(planPaynode);
        // 保存支付节点log
        savePlanPaynodeLog(planPaynode);
    }

    /**
     * 添加修改不予结算数据
     *
     * @param plan
     * @param node
     * @param date
     */
    private void editNoPayDetails(PlanVo plan, PlanPaynodeVo node, Date date) {
        Paymentdetails paymentdetails_n = new Paymentdetails();
        paymentdetails_n.setPlanid(plan.getPlanid());
        paymentdetails_n.setTradeguid(plan.getTradeguid());
        paymentdetails_n.setPlantype(node.getPlantype());
        paymentdetails_n.setNodeid(node.getNodeid());
        paymentdetails_n.setNodename(node.getNodename());
        paymentdetails_n.setUsertypeid(UserTypeEnum.UserType.USER_TYPE_02.getCode());
        paymentdetails_n.setUsertypename(UserTypeEnum.UserType.USER_TYPE_02.getInfo());
        paymentdetails_n.setPaytotal(node.getNopay());
        paymentdetails_n.setPayTotalRatio(node.getNoPayRatio());
        paymentdetails_n.setUpdatedate(date);
        paymentdetails_n.setUpdatereason("方案明细不予结算部分");
        List<Paymentdetails> paymentdetails_no = paymentdetailsMapper.selectPaymentdetailsList2(paymentdetails_n);
        if (paymentdetails_no != null && paymentdetails_no.size() > 0) {
            // 修改
            if (null != node.getNopay() && node.getNopay().compareTo(new BigDecimal(0)) != 0) {
                paymentdetails_n.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_Y.getCode());
            } else {
                paymentdetails_n.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_N.getCode());
            }
            paymentdetails_n.setPayid(paymentdetails_no.get(0).getPayid());
            paymentdetailsMapper.updatePaymentdetails(paymentdetails_n);
        } else {
            if (null != node.getNopay() && node.getNopay().compareTo(new BigDecimal(0)) != 0) {
                // 新增
                paymentdetails_n.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_Y.getCode());
                paymentdetails_n.setPayid(IdUtil.simpleUUID());
                paymentdetails_n.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_101.getCode());
                paymentdetailsMapper.insertPaymentdetails(paymentdetails_n);
            }
        }
        // 方案预览明细log保存
        savePaymentdetailsLog(paymentdetails_n);
    }

    /**
     * 添加修改报备人员明细 PaymentDetails
     *
     * @param t
     * @param plan
     * @param node
     * @param date
     */
    private void editReferDetails(TradeVo t, PlanVo plan, PlanPaynodeVo node, Date date) {
        Paymentdetails paymentdetails_b = new Paymentdetails();
        paymentdetails_b.setPlanid(plan.getPlanid());
        paymentdetails_b.setTradeguid(plan.getTradeguid());
        paymentdetails_b.setPlantype(node.getPlantype());
        paymentdetails_b.setNodeid(node.getNodeid());
        paymentdetails_b.setNodename(node.getNodename());
        paymentdetails_b.setUsertypeid(UserTypeEnum.UserType.USER_TYPE_01.getCode());
        if (1 == node.getPlantype()) {
            paymentdetails_b.setJobname(t.getReferJobName());
            paymentdetails_b.setUser(node.getUser());
            paymentdetails_b.setUserid(node.getUserId());
            paymentdetails_b.setUsertypename("报备人员");
        } else {
            paymentdetails_b.setJobname(t.getYwyJobName());
            paymentdetails_b.setUser(node.getUser());
            paymentdetails_b.setUserid(node.getUserId());
            paymentdetails_b.setUsertypename("接待人员");
        }
        paymentdetails_b.setPaytotal(node.getFixfee());
        paymentdetails_b.setPayTotalRatio(node.getFixFeeRatio());
        paymentdetails_b.setUpdatedate(date);

        List<Paymentdetails> paymentdetails2 = paymentdetailsMapper.selectPaymentdetailsList2(paymentdetails_b);
        if (paymentdetails2 != null && paymentdetails2.size() > 0) {
            // 修改
            if (null != node.getFixfee() && node.getFixfee().compareTo(new BigDecimal(0)) != 0) {
                paymentdetails_b.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_Y.getCode());
            } else {
                paymentdetails_b.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_N.getCode());
            }
            paymentdetails_b.setPayid(paymentdetails2.get(0).getPayid());
            if (1 == node.getPlantype()) {
                paymentdetails_b.setUpdatereason("方案明细报备人修改");
            } else {
                paymentdetails_b.setUpdatereason("方案明细接待人修改");
            }
            paymentdetailsMapper.updatePaymentdetails(paymentdetails_b);
        } else {
            if (null != node.getFixfee() && node.getFixfee().compareTo(new BigDecimal(0)) != 0) {
                paymentdetails_b.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_Y.getCode());
                // 新增
                paymentdetails_b.setPayid(IdUtil.simpleUUID());
                paymentdetails_b.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_101.getCode());
                if (1 == node.getPlantype()) {
                    paymentdetails_b.setUpdatereason("方案明细报备人新增");
                } else {
                    paymentdetails_b.setUpdatereason("方案明细接待人新增");
                }
                paymentdetailsMapper.insertPaymentdetails(paymentdetails_b);
            }
        }
        paymentdetailsMapper.deletePaymentdetailsList2(paymentdetails_b);
        // 方案预览明细log保存
        savePaymentdetailsLog(paymentdetails_b);
    }

    /**
     * 删除旧人员方案明细
     *
     * @param plan
     * @param node
     */
    private void deletePlanbalance(PlanVo plan, PlanPaynodeVo node) {
        Planbalance b2 = new Planbalance();
        b2.setPlanType(node.getPlantype());
        b2.setPlanid(plan.getPlanid());
        b2.setNodeid(node.getNodeid());
        planbalanceMapper.deletePlanbalanceByIdAndType(b2);
    }

    /**
     * 后台人员结算方案明细保存
     *
     * @param plan
     * @param node
     * @param balance
     * @param date
     */
    private void addPlanbalance(PlanVo plan, PlanPaynodeVo node, Planbalance balance, Date date) {
        Planbalance planbalance = balance;
        planbalance.setPlanid(plan.getPlanid());
        planbalance.setPlanType(node.getPlantype());
        planbalance.setTradeguid(plan.getTradeguid());
        planbalance.setNodeid(node.getNodeid());
        planbalance.setCreateDate(date);
        planbalanceMapper.insertPlanbalance(planbalance);
        // 后台人员结算方案明细log保存
        savePlanbalanceLog(planbalance);
    }

    // 添加修改方案预览
    private ArrayList<String> addOrUpdatePaymentdetails(PlanVo plan, PlanPaynodeVo node, Planbalance balance, Date date) {
        ArrayList<String> payIdList = new ArrayList<>();
        Paymentdetails paymentdetails = new Paymentdetails();
        paymentdetails.setPlanid(plan.getPlanid());
        paymentdetails.setTradeguid(plan.getTradeguid());
        paymentdetails.setPlantype(balance.getPlanType());
        paymentdetails.setNodeid(node.getNodeid());
        paymentdetails.setNodename(node.getNodename());
        paymentdetails.setUsertypeid(balance.getUsertypeid());
        paymentdetails.setUsertypename(balance.getUsertypename());
        paymentdetails.setJobname(balance.getJobname());
        paymentdetails.setUser(balance.getUser());
        paymentdetails.setUserid(balance.getUserid());
        paymentdetails.setPaytotal(balance.getPaytotal());
        paymentdetails.setPayTotalRatio(balance.getPayRatio());
        paymentdetails.setUpdatedate(date);
        paymentdetails.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_Y.getCode());

        // 按支付批次分条保存
        // 支付批次 10 首批
        paymentdetails.setPaybatch(PlanEnum.PaymentDetailsPayBatch.PAY_FIRST.getCode());
        paymentdetails.setPayable(balance.getFirstpay());
        paymentdetails.setPayableRatio(balance.getFirstPayRatio());
        List<Paymentdetails> paymentdetails1 = paymentdetailsMapper.selectPaymentdetailsList2(paymentdetails);
        if (paymentdetails1 != null && paymentdetails1.size() > 0) {
            // 修改
            if (balance.getFirstpay() == null || balance.getFirstpay().compareTo(BigDecimal.ZERO) == 0) {
                paymentdetails.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_N.getCode());
            }
            paymentdetails.setPayid(paymentdetails1.get(0).getPayid());
            paymentdetails.setUpdatereason("方案明细修改");
            paymentdetailsMapper.updatePaymentdetails(paymentdetails);
            payIdList.add(paymentdetails.getPayid());
        } else {
            if (balance.getFirstpay() != null && balance.getFirstpay().compareTo(BigDecimal.ZERO) != 0) {
                // 新增
                paymentdetails.setPayid(IdUtil.simpleUUID());
                paymentdetails.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_101.getCode());
                paymentdetails.setUpdatereason("方案明细新增");
                paymentdetailsMapper.insertPaymentdetails(paymentdetails);
                payIdList.add(paymentdetails.getPayid());
            }
        }
        // 方案预览明细log保存
        savePaymentdetailsLog(paymentdetails);
        paymentdetails.setStatusDetail(null); // 重置
        // 支付批次 20 末批
        paymentdetails.setPaybatch(PlanEnum.PaymentDetailsPayBatch.PAY_LAST.getCode());
        paymentdetails.setPayable(balance.getLastpay());
        paymentdetails.setPayableRatio(balance.getLastPayRatio());
        paymentdetails1 = paymentdetailsMapper.selectPaymentdetailsList2(paymentdetails);
        if (paymentdetails1 != null && paymentdetails1.size() > 0) {
            if (balance.getLastpay() == null || balance.getLastpay().compareTo(BigDecimal.ZERO) == 0) {
                paymentdetails.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_N.getCode());
            }
            // 修改
            paymentdetails.setPayid(paymentdetails1.get(0).getPayid());
            paymentdetails.setUpdatereason("方案明细修改");
            paymentdetailsMapper.updatePaymentdetails(paymentdetails);
            payIdList.add(paymentdetails.getPayid());
        } else {
            if (balance.getLastpay() != null && balance.getLastpay().compareTo(BigDecimal.ZERO) != 0) {
                // 新增
                paymentdetails.setPayid(IdUtil.simpleUUID());
                paymentdetails.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_101.getCode());
                paymentdetails.setUpdatereason("方案明细新增");
                paymentdetailsMapper.insertPaymentdetails(paymentdetails);
                payIdList.add(paymentdetails.getPayid());
            }
        }
        // 方案预览明细log保存
        savePaymentdetailsLog(paymentdetails);
        return payIdList;
    }

    // 明细删除
    private void deletePaymentdetails(PlanPaynodeVo node, List<String> userIds, Date date, List<String> payIdList) {
        PaymentdetailsVo paymentdetailsVo = new PaymentdetailsVo();
        paymentdetailsVo.setPlanid(node.getPlanid());
        paymentdetailsVo.setPlantype(node.getPlantype());
        paymentdetailsVo.setNodeid(node.getNodeid());
        paymentdetailsVo.setUserIds(userIds);
        paymentdetailsVo.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_N.getCode());
        paymentdetailsVo.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_103.getCode());
        List<String> list = new ArrayList<>();
        list.add(UserTypeEnum.UserType.USER_TYPE_01.getCode());
        list.add(UserTypeEnum.UserType.USER_TYPE_02.getCode());
        paymentdetailsVo.setUsertypeids(list);
        paymentdetailsVo.setUpdatereason("方案删除");
        paymentdetailsVo.setUpdatedate(date);
        paymentdetailsVo.setPayIdList(payIdList);
        paymentdetailsMapper.updatePaymentdetails3(paymentdetailsVo);
    }

    /**
     * 佣金方案-作废
     *
     * @param tradeguid
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult delTradePlan(String tradeguid) {
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        Date date = new Date();
        // 查询方案
        Plan plan = new Plan();
        plan.setTradeguid(tradeguid);
        plan.setStatus(PlanEnum.PlanStatus.STATUS_ZF.getCode()); // 作废状态
        List<PlanVo> plans = planMapper.selectPlanListByStatus(plan);
        if (plans == null || plans.size() < 1) {
            throw new CustomException("方案不存在，作废失败", Constants.ERROR);
        }
        String examStatus = "N";
        for (PlanVo planVo : plans) {
            if ("Y".equals(planVo.getExamStatus())) {
                examStatus = planVo.getExamStatus();
                break;
            }
        }
        if ("Y".equals(examStatus)) {
            throw new CustomException("方案已进核算，不能作废", Constants.ERROR);
        }
        // 作废明细表
        Paymentdetails paymentdetails = new Paymentdetails();
        paymentdetails.setPlanid(plans.get(0).getPlanid());
        paymentdetails.setStatus(PlanEnum.PaymentDetailsStatus.STATUS_N.getCode());
        paymentdetails.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_103.getCode());
        paymentdetails.setUpdatedate(date);
        paymentdetails.setUpdatereason("方案作废");
        paymentdetailsMapper.updatePaymentdetails2(paymentdetails);

        // 作废方案表
        plan.setStatus(PlanEnum.PlanStatus.STATUS_ZF.getCode());
        plan.setUpdateUserID(csmSUser != null ? csmSUser.getId() : "");
        plan.setUpdateUser(csmSUser != null ? csmSUser.getUsername() : "");
        plan.setUpdateDate(date);
        plan.setPlanid(plans.get(0).getPlanid());
        planMapper.updatePlan(plan);
        return new AjaxResult(Constants.SUCCESS, "修改成功");
    }

    /**
     * 佣金方案-提交
     *
     * @param planIds
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult tradePlanSubmit(List<String> planIds) {
        if (planIds == null || planIds.size() < 1) {
            throw new CustomException("方案ID不能为空", Constants.ERROR);
        }
        planIds.stream().forEach(p -> {
            // 查询方案
            Plan plan = planMapper.selectPlanById(p);
            if (plan == null) {
                throw new CustomException("方案不存在", Constants.ERROR);
            }
            CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
            Date date = new Date();
            if (20 != plan.getStatus() && 30 != plan.getStatus()) {
                // 更新方案状态
                plan.setStatus(PlanEnum.PlanStatus.STATUS_WFQ.getCode());
                plan.setUpdateUserID(csmSUser != null ? csmSUser.getId() : "");
                plan.setUpdateUser(csmSUser != null ? csmSUser.getUsername() : "");
                plan.setUpdateDate(date);
                planMapper.updatePlan(plan);
            }
            // 更新方案明细状态
            Paymentdetails paymentdetails = new Paymentdetails();
            paymentdetails.setPlanid(plan.getPlanid());
            paymentdetails.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_102.getCode());
            paymentdetails.setUpdatedate(date);
            paymentdetails.setUpdatereason("方案提交");
            paymentdetailsMapper.updatePaymentdetails4(paymentdetails);
        });
        return new AjaxResult(Constants.SUCCESS, "提交成功");
    }

    /**
     * 佣金方案-查看、预览
     *
     * @param tradeguids 佣金方案查询参数
     * @return 佣金方案
     */
    @Override
    public List<TradeVo> findPlanDetails(List<String> tradeguids) {
        if (tradeguids == null || tradeguids.size() < 1) {
            throw new CustomException("交易ID不能为空", Constants.ERROR);
        }
        TradeVo vo = new TradeVo();
        vo.setTradeguidList(tradeguids);
        List<TradeVo> planDetails = tradeMapper.getPlanDetails(vo);
        return planDetails;
    }

    /**
     * 保存支付节点log
     *
     * @param planPaynode
     */
    private void savePlanPaynodeLog(PlanPaynode planPaynode) {
        PlanPaynodeLog planPaynodeLog = new PlanPaynodeLog();
        planPaynodeLog.setPlanid(planPaynode.getPlanid());
        planPaynodeLog.setTradeguid(planPaynode.getTradeguid());
        planPaynodeLog.setPaytotal(planPaynode.getPaytotal());
        planPaynodeLog.setFixfee(planPaynode.getFixfee());
        planPaynodeLog.setFixFeeEdit(planPaynode.getFixFeeEdit());
        planPaynodeLog.setNopay(planPaynode.getNopay());
        planPaynodeLog.setPlantype(planPaynode.getPlantype());
        planPaynodeLog.setNodeid(planPaynode.getNodeid());
        planPaynodeLog.setNodename(planPaynode.getNodename());
        planPaynodeLog.setCreateDate(planPaynode.getCreateDate());
        planPaynodeLog.setUser(planPaynode.getUser());
        planPaynodeLog.setUserId(planPaynode.getUserId());
        planPaynodeLogMapper.insertPlanPaynodeLog(planPaynodeLog);
    }

    /**
     * 后台人员结算方案明细log保存
     *
     * @param planbalance
     */
    private void savePlanbalanceLog(Planbalance planbalance) {
        PlanbalanceLog planbalanceLog = new PlanbalanceLog();
        planbalanceLog.setPlanid(planbalance.getPlanid());
        planbalanceLog.setTradeguid(planbalance.getTradeguid());
        planbalanceLog.setNodeid(planbalance.getNodeid());
        planbalanceLog.setUsertypeid(planbalance.getUsertypeid());
        planbalanceLog.setUsertypename(planbalance.getUsertypename());
        planbalanceLog.setJobname(planbalance.getJobname());
        planbalanceLog.setUser(planbalance.getUser());
        planbalanceLog.setUserid(planbalance.getUserid());
        planbalanceLog.setPaytotal(planbalance.getPaytotal());
        planbalanceLog.setFirstpay(planbalance.getFirstpay());
        planbalanceLog.setLastpay(planbalance.getLastpay());
        planbalanceLog.setPlanType(planbalance.getPlanType());
        planbalanceLog.setCreateDate(planbalance.getCreateDate());
        planbalanceLogMapper.insertPlanbalanceLog(planbalanceLog);
    }

    /**
     * 方案预览明细log保存
     *
     * @param paymentdetails
     */
    private void savePaymentdetailsLog(Paymentdetails paymentdetails) {
        // 佣金明细log
        PaymentdetailsLog paymentdetailsLog = new PaymentdetailsLog();
        paymentdetailsLog.setPayid(paymentdetails.getPayid());
        paymentdetailsLog.setPlanid(paymentdetails.getPlanid());
        paymentdetailsLog.setTradeguid(paymentdetails.getTradeguid());
        paymentdetailsLog.setPlantype(paymentdetails.getPlantype());
        paymentdetailsLog.setNodeid(paymentdetails.getNodeid());
        paymentdetailsLog.setNodename(paymentdetails.getNodename());
        paymentdetailsLog.setUsertypeid(paymentdetails.getUsertypeid());
        paymentdetailsLog.setUsertypename(paymentdetails.getUsertypename());
        paymentdetailsLog.setJobname(paymentdetails.getJobname());
        paymentdetailsLog.setUser(paymentdetails.getUser());
        paymentdetailsLog.setUserid(paymentdetails.getUserid());
        paymentdetailsLog.setPaytotal(paymentdetails.getPaytotal());
        paymentdetailsLog.setStatus(paymentdetails.getStatus());
        paymentdetailsLog.setUpdatedate(paymentdetails.getUpdatedate());
        paymentdetailsLog.setUpdatereason(paymentdetails.getUpdatereason());
        paymentdetailsLog.setStatusDetail(paymentdetails.getStatusDetail());
        paymentdetailsLog.setPaybatch(paymentdetails.getPaybatch());
        paymentdetailsLog.setPayable(paymentdetails.getPayable());
        paymentdetailsLogMapper.insertPaymentdetailsLog(paymentdetailsLog);
    }
    /**
    * 追加模板【选择佣金方案模板】
    */
    /**
     * 新增佣金方案-2.查询调整佣金
     *
     * @param tradeguidList 佣金方案查询参数
     * @return 佣金方案
     */
    @Override
    public List<TradeVo> AppendgetRegulateBrokerage(List<String> tradeguidList) {
        TradeVo vo = new TradeVo();
        vo.setTradeguidList(tradeguidList);
        List<TradeVo> regulateBrokerage = tradeMapper.getRegulateBrokerageAppend(vo);
        if (regulateBrokerage != null && regulateBrokerage.size() > 0) {
            regulateBrokerage.stream().forEach(t -> {
                List<Paymenttemp> paymenttemps = t.getPaymenttemps().stream()
                        .filter(p->p.getPlantype()==p.getAppendType()).collect(Collectors.toList());
                t.setPaymenttemps(paymenttemps);
                if (paymenttemps != null && paymenttemps.size() > 0) {
                    paymenttemps.stream().forEach(p -> {
                        if (1 == p.getPlantype()) { // 团购费
                            // 拓客费用系统抓取时从交易中取否则在模板取
                            // 佣金池可用费用=团购服务费第三方销售费用*可支配费用占销售费用比例*佣金包占可支配费用比例
                            if (1 == p.getTokerfeetype()) {
                                // 团购费服务费第三方拓客费用
                                p.setTokerfee(t.getTkAmount().subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            } else if (3 == p.getTokerfeetype()){
                                // 服务费签约金额比例
                                p.setTokerFeeRatio(p.getTokerfee());
                                p.setTokerfee(MoneyUtils.multiplyHalfEven(
                                        t.getRmbhttotal().toString(), p.getTokerfee().toString(), "0.01", 0).subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }
                            else {
                                p.setTokerfee(p.getTokerfee().subtract(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }

                            // 自销管理费
                            p.setManageAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getManageratio().toString(), "0.01", 0));

                            // 税金金额
                            p.setTaxesAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getTaxes().toString(), "0.01", 0));

                            // 可支配收入占第三方拓客费
                            p.setControlAmount(MoneyUtils.multiplyHalfEven(
                                    p.getTokerfee().toString(), p.getControlratio().toString(), "0.01", 0));

                            // 佣金包占可支配费用
                            p.setPaymentpackAmount(MoneyUtils.multiplyHalfEven(
                                    p.getControlAmount().toString(), p.getPaymentpack().toString(), "0.01", 0));

                            // 团购费佣金
                            p.setTkAmount(p.getPaymentpackAmount());

                            if (1 == p.getTokerfeetype()) {
                                // 团购费服务费第三方拓客费用
                                p.setTokerfee(t.getTkAmount());
                            } else if (3 == p.getTokerfeetype()){
                                // 服务费签约金额比例
                                p.setTokerfee(p.getTokerfee().add(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }
                            else{
                                p.setTokerfee(p.getTokerfee().add(t.getPlanVo().getTgdeuctval()==null?new BigDecimal(0):t.getPlanVo().getTgdeuctval()));
                            }

                        } else { // 代理费
                            // 佣金池可用费用=[代理费-代理费*（自销管理费比例+税金比例）-交房保证金]*佣金包占可支配收入比例

                            // 代理费
                            if (1 == p.getAgencyfeetype()) {
                                p.setAgencyFeeRatio(p.getAgencyFee());
                                p.setAgencyFee(MoneyUtils.multiplyHalfEven(
                                        t.getRmbhttotal().toString(), p.getAgencyFee().toString(), "0.01", 0).subtract(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            else{
                                p.setAgencyFee(p.getAgencyFee().subtract(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            // 交房保证金
                            if (1 == p.getJfbondtype()) {
                                p.setJfbond(MoneyUtils.multiplyHalfEven(
                                        p.getAgencyFee().toString(), p.getJfbond().toString(), "0.01", 0));
                            }

                            // 代理费-代理费*（自销管理费比例+税金比例）-交房保证金
                            BigDecimal sum = p.getAgencyFee().subtract(MoneyUtils.multiplyHalfEven(p.getAgencyFee().toString(),
                                    String.valueOf(p.getTaxes().add(p.getManageratio())), "0.01", 0));

                            if (p.getJfbondIsDeduct() != null && p.getJfbondIsDeduct() == 1) { // 扣除交房保证金
                                sum = sum.subtract(p.getJfbond());
                            }
                            // 代理费佣金
                            p.setAgencyAmount(MoneyUtils.multiplyHalfEven(sum.toString(), p.getPaymentpack().toString(), "0.01", 0));

                            // 自销管理费
                            p.setManageAmount(MoneyUtils.multiplyHalfEven(
                                    p.getAgencyFee().toString(), p.getManageratio().toString(), "0.01", 0));

                            // 税金金额
                            p.setTaxesAmount(MoneyUtils.multiplyHalfEven(
                                    p.getAgencyFee().toString(), p.getTaxes().toString(), "0.01", 0));

                            // 佣金包占可支配费用
                            p.setPaymentpackAmount(MoneyUtils.multiplyHalfEven(
                                    sum.toString(), p.getPaymentpack().toString(), "0.01", 0));

                            if (1 == p.getAgencyfeetype()) {
                                p.setAgencyFee(p.getAgencyFee().add(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                            else{
                                p.setAgencyFee(p.getAgencyFee().add(t.getPlanVo().getDlfdeuctval()==null?new BigDecimal(0):t.getPlanVo().getDlfdeuctval()));
                            }
                        }
                    });
                }
            });
        }
        return regulateBrokerage;
    }

    /**
     * 追加模板
     * @param plan
     * @return
     */
    @Override
    public AjaxResult AppendTemp(Plan plan){
        /*
        } else {
            throw new CustomException("方案详情不能为空", Constants.ERROR);
        }
         */
        String planid=plan.getPlanid();
        if(planid.equals(""))
        {
            throw new CustomException("参数错误", Constants.ERROR);
        }
        Plan p=planMapper.selectPlanById(planid);
        if(p.getTgtempid().equals("")||p.getDlftempid().equals("")||p.getAppendStatus()== PlanEnum.PlanAppendStatus.AppendIng.getCode())
        {
            Plan plan2=new Plan();
            plan2.setPlanid(planid);
            plan2.setAppendStatus(PlanEnum.PlanAppendStatus.AppendIng.getCode());
            if(!plan.getTgtempid().equals(""))
            {
                if(p.getAppendType()==PaymenttempEnum.PlanType.STATUS_DL.getCode()){
                    throw new CustomException("参数错误", Constants.ERROR);
                }
                plan2.setTgtempid(plan.getTgtempid());
                plan2.setAppendType((int)PaymenttempEnum.PlanType.STATUS_TG.getCode().longValue());
                plan2.setTgdeuctval(plan.getTgdeuctval());
                plan2.setTgdeuctexplan(plan.getTgdeuctexplan());
            }
            else if(!plan.getDlftempid().equals(""))
            {
                if(p.getAppendType()==PaymenttempEnum.PlanType.STATUS_TG.getCode()){
                    throw new CustomException("参数错误", Constants.ERROR);
                }
                plan2.setDlftempid(plan.getDlftempid());
                plan2.setAppendType((int)PaymenttempEnum.PlanType.STATUS_DL.getCode().longValue());
                plan2.setDlfdeuctval(plan.getDlfdeuctval());
                plan2.setDlfdeuctexplan(plan.getDlfdeuctexplan());
            }
            planMapper.updatePlanAppend(plan2);
        }
        else
        {
            return new AjaxResult(Constants.ERROR, "不支持追加模板");
        }
        return new AjaxResult(Constants.SUCCESS, "保存成功");
    }



    /**
     * 新增佣金方案-3.保存修改结算方案
     *
     * @param tradeVoList
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult AppendinsertSettlePlan(List<TradeVo> tradeVoList) {
        if (tradeVoList == null || tradeVoList.size() < 1) {
            throw new CustomException("交易信息不能为空", Constants.ERROR);
        }
        tradeVoList.stream().forEach(t -> {
            PlanVo plan = t.getPlanVo();
            if (plan == null) {
                throw new CustomException("方案信息不能为空", Constants.ERROR);
            }

            List<PlanPaynodeVo> planPaynodeVos = plan.getPlanPaynodeVos();
            if (planPaynodeVos == null || planPaynodeVos.size() < 1) {
                throw new CustomException("支付节点信息不能为空", Constants.ERROR);
            }

            Planfee planfee = t.getPlanfee();
            if (planfee == null) {
                throw new CustomException("费用信息不能为空", Constants.ERROR);
            }

            Plan plan2=new Plan();
            plan2.setPlanid(plan.getPlanid());
            plan2.setAppendStatus(PlanEnum.PlanAppendStatus.AppendEnd.getCode());
            HashMap<String,Object> map=new HashMap<>();
            map.put("planid",plan.getPlanid());
            map.put("plantype",plan.getAppendType());
            // 删除追加的旧节点
            planPaynodeMapper.deletePlanPaynodeByIdAndPlayType(map);

            BigDecimal tgTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 1).map(n -> n.getPaytotal()).reduce(BigDecimal.ZERO, BigDecimal::add);

            BigDecimal dlTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 2).map(n -> n.getPaytotal()).reduce(BigDecimal.ZERO, BigDecimal::add);

            BigDecimal tgRatioTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 1).map(n -> n.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add);

            BigDecimal dlRatioTotal = planPaynodeVos.stream().filter(
                    n -> n.getPlantype() == 2).map(n -> n.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add);

            if (tgRatioTotal != null && tgRatioTotal.compareTo(new BigDecimal(0)) == 1 && tgRatioTotal.compareTo(new BigDecimal(100)) != 0) {
                throw new CustomException("团购节点比例之和不等于100%", Constants.ERROR);
            }

            if (dlRatioTotal != null && dlRatioTotal.compareTo(new BigDecimal(0)) == 1 && dlRatioTotal.compareTo(new BigDecimal(100)) != 0) {
                throw new CustomException("代理节点比例之和不等于100%", Constants.ERROR);
            }
            planMapper.updatePlanAppend(plan2);
            planPaynodeVos.stream().forEach(node -> {

                ArrayList<String> addOrUpdatePayIds = new ArrayList<>();

                Date date = new Date();

                // 保存支付节点数据
                addplanPaynodeVos(plan, node, date);

                // 添加修改不予结算数据
                editNoPayDetails(plan, node, date);

                // 添加修改报备人员明细 PaymentDetails
                editReferDetails(t, plan, node, date);

                List<Planbalance> planbalances = node.getPlanbalances();

                // 新增或变更的人员ID集合
                List<String> userIds = new ArrayList<>();

                // 删除旧人员方案明细
                deletePlanbalance(plan, node);

                // 节点下人员分配比例之和
                BigDecimal balancesTotal = new BigDecimal(0);
                balancesTotal = balancesTotal.add(node.getFixFeeRatio() != null ? node.getFixFeeRatio() : new BigDecimal(0))
                        .add(node.getNoPayRatio() != null ? node.getNoPayRatio() : new BigDecimal(0));

                BigDecimal nodeTotal = new BigDecimal(0);
                if (planbalances != null && planbalances.size() > 0) {
                    balancesTotal = balancesTotal.add(planbalances.stream().filter(b -> b.getPayRatio() != null)
                            .map(b -> b.getPayRatio()).reduce(BigDecimal.ZERO, BigDecimal::add));

                    AtomicLong i = new AtomicLong();
                    planbalances.stream().forEach(balance -> {
                        i.addAndGet(1);
                        balance.setSort(i.get());
                        BigDecimal sum = new BigDecimal(0);
                        sum = sum.add(balance.getFirstpay() != null ? balance.getFirstpay() : new BigDecimal(0));
                        sum = sum.add(balance.getLastpay() != null ? balance.getLastpay() : new BigDecimal(0));

                        if (balance.getPaytotal().compareTo(sum) != 0) {
                            throw new CustomException("人员首期加末期费用不等于总支付金额", Constants.ERROR);
                        }

                        BigDecimal fb = balance.getFirstPayRatio() != null ? balance.getFirstPayRatio() : new BigDecimal(0);
                        BigDecimal lb = balance.getLastPayRatio() != null ? balance.getLastPayRatio() : new BigDecimal(0);
                        if (fb.add(lb).compareTo(new BigDecimal(100)) != 0) {
                            throw new CustomException("人员首批末批比例之和不等于100%", Constants.ERROR);
                        }

                        userIds.add(balance.getUserid());

//                        nodeTotal.addAndGet(balance.getPaytotal().longValue());

                        if (StrUtil.isBlank(balance.getUser()) || StrUtil.isBlank(balance.getUserid())) {
                            throw new CustomException("引入人员信息不能为空", Constants.ERROR);
                        }

                        // 后台人员结算方案明细保存
                        addPlanbalance(plan, node, balance, date);
                        // 添加修改方案预览
                        ArrayList<String> payIdList = addOrUpdatePaymentdetails(plan, node, balance, date);
                        addOrUpdatePayIds.addAll(payIdList);

                    });
                    nodeTotal = planbalances.stream().filter(
                            b -> b.getPaytotal() != null).map(b -> b.getPaytotal()).reduce(BigDecimal.ZERO, BigDecimal::add);
                }

                if (balancesTotal.compareTo(new BigDecimal(100)) != 0) {
                    throw new CustomException("节点人员分配比例之和不等于100%", Constants.ERROR);
                }

                if (null != node.getFixfee()) {
                    nodeTotal = nodeTotal.add(node.getFixfee());
                }
                if (null != node.getNopay()) {
                    nodeTotal = nodeTotal.add(node.getNopay());
                }

                if (node.getPaytotal().compareTo(nodeTotal) != 0) {
                    throw new CustomException("各费用相加不等于节点总金额", Constants.ERROR);
                }

                // 明细删除
                deletePaymentdetails(node, userIds, date, addOrUpdatePayIds);


                // 更新方案明细状态
                Paymentdetails paymentdetails = new Paymentdetails();
                paymentdetails.setPlanid(plan.getPlanid());
                paymentdetails.setPlantype((long)plan.getAppendType());
                paymentdetails.setStatusDetail(PlanEnum.PaymentDetailsStatusDetail.STATUS_102.getCode());
                paymentdetails.setUpdatedate(date);
                paymentdetails.setUpdatereason("方案追加");
                paymentdetailsMapper.updatePaymentdetails4(paymentdetails);

            });
            if (
                    (plan.getAppendType()== PaymenttempEnum.PlanType.STATUS_DL.getCode() &&(null != dlTotal && null != planfee.getAgentfee() && planfee.getAgentfee().compareTo(dlTotal) != 0))
                    ||
                            (plan.getAppendType()== PaymenttempEnum.PlanType.STATUS_TG.getCode() &&(null != tgTotal && null != planfee.getTgfee() && planfee.getTgfee().compareTo(tgTotal) != 0))
            ) {
                throw new CustomException("各支付节点费用相加不等于佣金总费用", Constants.ERROR);
            }
        });
        return new AjaxResult(Constants.SUCCESS, "保存成功");
    }


    /**
     * 新增佣金方案-3.查询结算方案
     *
     * @param tradeguidList 佣金方案查询参数
     * @return 佣金方案
     */
    @Override
    public List<TradeVo> AppendgetSettlePlan(List<String> tradeguidList) {
        if (tradeguidList == null || tradeguidList.size() < 1) {
            log.error("交易ID不能为空");
            return null;
        }
        TradeVo vo = new TradeVo();
        vo.setTradeguidList(tradeguidList);
        List<TradeVo> settlePlan = tradeMapper.getRegulateBrokerageAppend(vo);
        if (settlePlan != null && settlePlan.size() > 0) {
            settlePlan.stream().forEach(t -> {
                // 佣金方案详情
                PlanVo planVo = t.getPlanVo();
                // 方案支付节点信息
                List<PlanPaynodeVo> planPaynodeVos1 = planVo != null ? planVo.getPlanPaynodeVos() : null;
                if (planPaynodeVos1 == null || planPaynodeVos1.size() < 1) {
                    // 佣金方案费用信息
                    Planfee planfee = t.getPlanfee();
                    // 佣金方案_支付节点对象集合
                    List<PlanPaynodeVo> planPaynodeVos = new ArrayList<>();
                    List<Paymenttemp> paymenttemps = t.getPaymenttemps();
                    if (paymenttemps != null && paymenttemps.size() > 0) {
                        paymenttemps.stream().forEach(p -> {
                            List<PaymenttempNode> nodes = p.getNodes();
                            List<PaymenttempDistribution> distributions = p.getDistributions();
                            if (t.getPlanVo().getTgtempid().equals(p.getTempid()) && t.getPlanVo().getAppendType()== PaymenttempEnum.PlanType.STATUS_TG.getCode()) { // 团购费模板
                                if (nodes != null && nodes.size() > 0) {
                                    AtomicLong tgTotal = new AtomicLong(planfee.getTgfee().longValue());
                                    nodes.stream().forEach(node -> {
                                        PlanPaynodeVo planPaynodeVo = new PlanPaynodeVo();
                                        planPaynodeVo.setPlanid(planVo.getPlanid());
                                        planPaynodeVo.setTradeguid(t.getTradeguid());

                                        // 团购费支付节点总额
                                        planPaynodeVo.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                planfee.getTgfee().toString(), node.getPayratio().toString(), "0.01", 0));

                                        if (nodes.get(nodes.size() - 1).getNodeid().equals(node.getNodeid())) {
                                            planPaynodeVo.setPaytotal(new BigDecimal(tgTotal.toString()));
                                        } else { // 非最后一个节点
                                            // 除最后一个节点外，其余节点金额求和
                                            tgTotal.set(tgTotal.longValue() - planPaynodeVo.getPaytotal().longValue());
                                        }

                                        // 报备人分配
                                        if (null != p.getFixedratio()) {
                                            planPaynodeVo.setFixfee(MoneyUtils.multiplyHalfEven(
                                                    planPaynodeVo.getPaytotal().toString(), p.getFixedratio().toString(), "0.01", 0));
                                        }

                                        // 团购费节点
                                        planPaynodeVo.setPlantype(1L);
                                        planPaynodeVo.setNodeid(node.getNodeid());
                                        planPaynodeVo.setNodename(node.getNodename());
                                        planPaynodeVo.setFixFeeEdit(1);
                                        planPaynodeVo.setUser(t.getRefer());
                                        planPaynodeVo.setUserId(t.getReferid());
                                        planPaynodeVo.setPayRatio(node.getPayratio());
                                        planPaynodeVo.setFixFeeRatio(p.getFixedratio());
                                        planPaynodeVo.setNoPayRatio(p.getNopay());

                                        List<Planbalance> planbalances = new ArrayList<>();

                                        // 添加后台人员结算方案明细
                                        if (distributions != null && distributions.size() > 0) {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), p.getNopay().toString(), "0.01", 0));
                                            }

                                            AtomicLong sum = new AtomicLong(planPaynodeVo.getPaytotal()
                                                    .subtract(planPaynodeVo.getFixfee() != null ? planPaynodeVo.getFixfee() : new BigDecimal(0))
                                                    .subtract(planPaynodeVo.getNopay() != null ? planPaynodeVo.getNopay() : new BigDecimal(0)).longValue());
                                            AtomicInteger i = new AtomicInteger(distributions.size());
                                            distributions.stream().sorted(Comparator.comparing(PaymenttempDistribution :: getPayratio)).forEach(d -> {
                                                Planbalance planbalance = new Planbalance();
                                                planbalance.setPlanid(planVo.getPlanid());
                                                planbalance.setTradeguid(t.getTradeguid());
                                                planbalance.setNodeid(node.getNodeid());
                                                planbalance.setUsertypeid(d.getUsertypeid());
                                                planbalance.setUsertypename(d.getUsertypename());
                                                planbalance.setJobname(d.getJobname());
                                                planbalance.setUser(d.getUser());
                                                planbalance.setUserid(d.getUserid());

                                                planbalance.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), d.getPayratio().toString(), "0.01", 0));
                                                // 20210521
                                                if (planbalance.getPaytotal().compareTo(new BigDecimal(0)) == 0) {
                                                    planbalance.setPaytotal(new BigDecimal(1));
                                                }
                                                i.set(i.get() - 1);
                                                // 判断是否循环末尾
                                                if (i.get() == 0) {
                                                    planbalance.setPaytotal(new BigDecimal(sum.toString()));
                                                } else { // 非循环末尾
                                                    sum.set(sum.longValue() - planbalance.getPaytotal().longValue());
                                                }

                                                if (null != d.getSfratio()) {
                                                    planbalance.setFirstpay(MoneyUtils.multiplyHalfEven(
                                                            planbalance.getPaytotal().toString(), d.getSfratio().toString(), "0.01", 0));
                                                }

                                                // 末批 = 总额 - 首批
                                                planbalance.setLastpay(planbalance.getPaytotal().subtract(planbalance.getFirstpay()));

                                                planbalance.setPlanType(1L);
                                                planbalance.setFirstEdit(1L);
                                                planbalance.setLastEdit(1L);
                                                planbalance.setPayRatio(d.getPayratio());
                                                planbalance.setFirstPayRatio(d.getSfratio());
                                                planbalance.setLastPayRatio(d.getMfratio());
                                                planbalances.add(planbalance);
                                            });
                                        } else {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(planPaynodeVo.getPaytotal().subtract(planPaynodeVo.getFixfee()));
                                            }
                                        }
                                        planPaynodeVo.setPlanbalances(planbalances);
                                        planPaynodeVos.add(planPaynodeVo);
                                    });
                                }
                            } else if (t.getPlanVo().getDlftempid().equals(p.getTempid())&& t.getPlanVo().getAppendType()== PaymenttempEnum.PlanType.STATUS_DL.getCode()) { // 代理费模板
                                if (nodes != null && nodes.size() > 0) {
                                    AtomicLong dlTotal = new AtomicLong(planfee.getAgentfee().longValue());
                                    nodes.stream().forEach(node -> {
                                        PlanPaynodeVo planPaynodeVo = new PlanPaynodeVo();
                                        planPaynodeVo.setPlanid(planVo.getPlanid());
                                        planPaynodeVo.setTradeguid(t.getTradeguid());
                                        // 代理费支付节点总额
                                        planPaynodeVo.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                planfee.getAgentfee().toString(), node.getPayratio().toString(), "0.01", 0));

                                        if (nodes.get(nodes.size() - 1).getNodeid().equals(node.getNodeid())) {
                                            planPaynodeVo.setPaytotal(new BigDecimal(dlTotal.toString()));
                                        } else { // 非最后一个节点
                                            // 除最后一个节点外，其余节点金额求和
                                            dlTotal.set(dlTotal.get() - planPaynodeVo.getPaytotal().longValue());
                                        }

                                        // 接待人分配
                                        if (null != p.getFixedratio()) {
                                            planPaynodeVo.setFixfee(MoneyUtils.multiplyHalfEven(
                                                    planPaynodeVo.getPaytotal().toString(), p.getFixedratio().toString(), "0.01", 0));
                                        }

                                        // 代理费节点
                                        planPaynodeVo.setPlantype(2L);
                                        planPaynodeVo.setNodeid(node.getNodeid());
                                        planPaynodeVo.setNodename(node.getNodename());
                                        planPaynodeVo.setFixFeeEdit(1);
                                        planPaynodeVo.setUser(t.getYwy());
                                        planPaynodeVo.setUserId(t.getYwyid());
                                        planPaynodeVo.setPayRatio(node.getPayratio());
                                        planPaynodeVo.setFixFeeRatio(p.getFixedratio());
                                        planPaynodeVo.setNoPayRatio(p.getNopay());

                                        List<Planbalance> planbalances = new ArrayList<>();

                                        // 添加后台人员结算方案明细
                                        if (distributions != null && distributions.size() > 0) {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), p.getNopay().toString(), "0.01", 0));
                                            }

                                            AtomicLong sum = new AtomicLong(planPaynodeVo.getPaytotal()
                                                    .subtract(planPaynodeVo.getFixfee() != null ? planPaynodeVo.getFixfee() : new BigDecimal(0))
                                                    .subtract(planPaynodeVo.getNopay() != null ? planPaynodeVo.getNopay() : new BigDecimal(0)).longValue());
                                            AtomicInteger i = new AtomicInteger(distributions.size());
                                            distributions.stream().sorted(Comparator.comparing(PaymenttempDistribution :: getPayratio)).forEach(d -> {
                                                Planbalance planbalance = new Planbalance();
                                                planbalance.setPlanid(planVo.getPlanid());
                                                planbalance.setTradeguid(t.getTradeguid());
                                                planbalance.setNodeid(node.getNodeid());
                                                planbalance.setUsertypeid(d.getUsertypeid());
                                                planbalance.setUsertypename(d.getUsertypename());
                                                planbalance.setJobname(d.getJobname());
                                                planbalance.setUser(d.getUser());
                                                planbalance.setUserid(d.getUserid());

                                                planbalance.setPaytotal(MoneyUtils.multiplyHalfEven(
                                                        planPaynodeVo.getPaytotal().toString(), d.getPayratio().toString(), "0.01", 0));
                                                // 20210521
                                                if (planbalance.getPaytotal().compareTo(new BigDecimal(0)) == 0) {
                                                    planbalance.setPaytotal(new BigDecimal(1));
                                                }
                                                i.set(i.get() - 1);
                                                // 判断是否循环末尾
                                                if (i.get() == 0) {
                                                    planbalance.setPaytotal(new BigDecimal(sum.toString()));
                                                } else { // 非循环末尾
                                                    sum.set(sum.longValue() - planbalance.getPaytotal().longValue());
                                                }

                                                if (null != d.getSfratio()) {
                                                    planbalance.setFirstpay(MoneyUtils.multiplyHalfEven(
                                                            planbalance.getPaytotal().toString(), d.getSfratio().toString(), "0.01", 0));
                                                }

                                                // 末批 = 总额 - 首批
                                                planbalance.setLastpay(planbalance.getPaytotal().subtract(planbalance.getFirstpay()));

                                                planbalance.setPlanType(1L);
                                                planbalance.setFirstEdit(1L);
                                                planbalance.setLastEdit(1L);
                                                planbalance.setPayRatio(d.getPayratio());
                                                planbalance.setFirstPayRatio(d.getSfratio());
                                                planbalance.setLastPayRatio(d.getMfratio());
                                                planbalances.add(planbalance);
                                            });
                                        } else {
                                            // 不予结算
                                            if (null != p.getNopay()) {
                                                planPaynodeVo.setNopay(planPaynodeVo.getPaytotal().subtract(planPaynodeVo.getFixfee()));
                                            }
                                        }
                                        planPaynodeVo.setPlanbalances(planbalances);
                                        planPaynodeVos.add(planPaynodeVo);
                                    });
                                }
                            }
                        });
                    }
                    planVo.setPlanPaynodeVos(planPaynodeVos);
                }
            });
        }
        return settlePlan;
    }


}
