package com.huaxia.hx_sell_commission.service.impl;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

import com.github.pagehelper.PageHelper;
import com.huaxia.hx_sell_commission.constant.Constants;
import com.huaxia.hx_sell_commission.domain.*;
import com.huaxia.hx_sell_commission.domain.csm.CsmSUser;
import com.huaxia.hx_sell_commission.enums.*;
import com.huaxia.hx_sell_commission.exception.CustomException;
import com.huaxia.hx_sell_commission.mapper.db1.*;
import com.huaxia.hx_sell_commission.mapper.db2.CsmSProjectMapper;
import com.huaxia.hx_sell_commission.service.ICsmSUserService;
import com.huaxia.hx_sell_commission.service.SettlebillService;
import com.huaxia.hx_sell_commission.utils.AjaxResult;
import com.huaxia.hx_sell_commission.utils.StringUtils;
import com.huaxia.hx_sell_commission.utils.page.PageDomain;
import com.huaxia.hx_sell_commission.utils.page.TableSupport;
import com.huaxia.hx_sell_commission.utils.sql.SqlUtil;
import com.huaxia.hx_sell_commission.utils.uuid.UUID;
import com.huaxia.hx_sell_commission.vo.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletRequest;

import static java.util.stream.Collectors.groupingBy;

/**
 * 结算单Service业务层处理
 *
 * @author zcj
 * @date 2020-12.2
 */
@Service
@Slf4j
public class SettleBillServiceImpl implements SettlebillService {

    @Autowired
    private SettlebillMapper settlebillMapper;

    @Autowired
    private SettlebillExaminebillMapper settlebillExaminebillMapper;

    @Autowired
    private SettlebillPaydetailsMapper settlebillPaydetailsMapper;

    @Autowired
    private SettlebillTradeMapper settlebillTradeMapper;

    @Autowired
    private SettlebillThirdbillMapper settlebillThirdbillMapper;

    @Autowired
    private ExamineBillMapper examineBillMapper;

    @Autowired
    private PaymentdetailsMapper paymentdetailsMapper;

    @Autowired
    private ICsmSUserService iCsmSUserService;

    @Autowired
    private CsmSProjectMapper csmSProjectMapper;

//    @Autowired
//    private HttpServletRequest request;

    @Autowired
    private ICsmSUserService csmSUserService;

    @Value("${settleBill.redirect.url}")
    private String redirectUrl;

    /**
     * 结算单管理
     * @param settleBillVo
     * @return
     */
    @Override
    public List<SettleBillVo> settleBillShow(SettleBillVo settleBillVo) {
        CsmSUser csmSUser = iCsmSUserService.selectCsmSUserByUserName();
        settleBillVo.setCreate(csmSUser == null ? "maowei" : csmSUser.getUsername());
        // 查询项目列表
        List<String> projectIds = csmSProjectMapper.getProject(csmSUser == null ? "maowei" : csmSUser.getUsername());
        settleBillVo.setProjectIds(projectIds);
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        if (StringUtils.isNotNull(pageNum) && StringUtils.isNotNull(pageSize))
        {
            String orderBy = SqlUtil.escapeOrderBySql(pageDomain.getOrderBy());
            PageHelper.startPage(pageNum, pageSize, orderBy);
        }
        List<SettleBillVo> list = settlebillExaminebillMapper.settleBillShow(settleBillVo);
        if(list != null ) {
            list.stream().forEach(s ->{
                getButtonList(s, csmSUser);
            });
        }
        return list;
    }
    /**
     * 查询按钮权限
     * @return
     */
    private SettleBillVo getButtonList(SettleBillVo s, CsmSUser csmSUser){
        List<String> button = new ArrayList<>();
        if(s.getStatus() != null) {
            // 驳回 草稿 撤回
            if (SettleEnum.SettleBillStatus.STATUS_BH.getCode().longValue() == s.getStatus().longValue()
                    || SettleEnum.SettleBillStatus.STATUS_CG.getCode().longValue() == s.getStatus().longValue()
                    || SettleEnum.SettleBillStatus.STATUS_CH.getCode().longValue() == s.getStatus().longValue()) {
                if (s.getCreateid() != null && s.getCreateid().equals(csmSUser == null ? "" : csmSUser.getId())) {
                    button.add(ButtonEnum.PlanBtn.UPDATE_BTN.getCode());
                    button.add(ButtonEnum.PlanBtn.INVALID_BTN.getCode());
                }
            } else {
                if(s.getFlowstatus().intValue() == 2L){
                    if (s.getCreateid() != null && s.getCreateid().equals(csmSUser == null ? "" : csmSUser.getId())) {
                        button.add(ButtonEnum.PlanBtn.UPDATE_BTN.getCode());
                        button.add(ButtonEnum.PlanBtn.INVALID_BTN.getCode());
                    }
                }else if (s.getFlowstatus().intValue() == 302L) {
                    button.add(ButtonEnum.PlanBtn.VIEW_BTN.getCode());
                    if (s.getCreateid() != null && s.getCreateid().equals(csmSUser == null ? "" : csmSUser.getId())) {
                        button.add(ButtonEnum.PlanBtn.DEL_BTN.getCode());
                    }
                }else {
                    button.add(ButtonEnum.PlanBtn.VIEW_BTN.getCode());
                }

            }
            s.setButton(button);
        }
        return s;
    }

    /**
     * 查询结算单中核算单
     * @param examineBillVo
     * @return
     */
    @Override
    public List<ExamineBill> ExamineBilDetails(ExamineBillVo examineBillVo) {
        CsmSUser csmSUser = iCsmSUserService.selectCsmSUserByUserName();
        examineBillVo.setUserName(csmSUser == null ? "maowei" : csmSUser.getUsername());
        // 查询项目列表
        List<String> projectIds = csmSProjectMapper.getProject(csmSUser == null ? "maowei" : csmSUser.getUsername());
        examineBillVo.setProjectIds(projectIds);
        //查询所有核算单
        List<ExamineBill> list=examineBillMapper.examineBillShow1(examineBillVo);

        for (ExamineBill examineBill:list) {
            //通过状态的核算单
            examineBill.setIsChecked("0");
            if(examineBill.getStatus()!=null){
                if (examineBill.getStatus().equals(ExamineEnum.ExamineBillStatus.STATUS_PASS.getCode())){
                    List<String> examineBillBySettleid = settlebillExaminebillMapper.findExamineBillBySettleid(examineBillVo.getSettleid());
                    examineBillBySettleid.forEach(s -> {
                        if(examineBill.getExamineId().equals(s)){
                            examineBill.setIsChecked("1");
                        }
                    });

                }
            }
        }
       return list;
    }

//    /**
//     * 查询结算单中核算单0
//     * @param settleBillVo
//     * @return
//     */
//    @Override
//    public List<SettleBillVo> settlebillDetails(SettleBillVo settleBillVo) {
//        return settlebillExaminebillMapper.settlebillDetails(settleBillVo);
//    }

    /**
     * 选择交易条目-结算单人员结算明细
     * @param settleBillVo
     * @return
     */
    @Override
    public List<TradeVo> settlebillTradeShow(SettleBillVo settleBillVo) {
        if(settleBillVo == null){
            return null;
        }
        //查询结算单中核算单
        List<ExamineBillVo> examineBillList = settleBillVo.getExamineBillList();
        //核算单ids
        List<String> examineids = new ArrayList<>();
        for (ExamineBillVo examineBillVo : examineBillList) {
            examineids.add(examineBillVo.getExamineId());
        }
        if(examineids == null || examineids.size() < 1){
            throw new CustomException("核算单信息为空", Constants.ERROR);
        }
        settleBillVo.setExamineids(examineids);
        List<TradeVo>  list1 =settlebillExaminebillMapper.examineBillShow2(settleBillVo);
        //判空
        if(list1 == null || list1.size() <= 0){
            return list1;
        }
        //根据交易分组
        Map<String, List<TradeVo>> collect = list1.stream().collect(groupingBy(TradeVo::getTradeguid));
        collect.entrySet().forEach(t -> {
            t.getValue().forEach(p ->{
                //根据方案类型分组
                Map<Long, List<Paymentdetails>> map = p.getPaymentdetailsList().stream().collect(groupingBy(Paymentdetails::getPlantype));
                map.entrySet().forEach(pl ->{
                    //根据节点分组
                    Map<String, List<Paymentdetails>> nodeList = pl.getValue().stream().collect(groupingBy(Paymentdetails::getNodeid));
                    nodeList.entrySet().forEach(np ->{
                        BigDecimal nodeSum = new BigDecimal(0);
                        for (Paymentdetails paymentdetails : np.getValue()) {
                            nodeSum =  nodeSum.add(paymentdetails.getPayable() == null ? paymentdetails.getPaytotal(): paymentdetails.getPayable());
                        }
                        for (Paymentdetails paymentdetails : np.getValue()) {
                            paymentdetails.setNodeTotalAmount(nodeSum);
                        }

                        /*
                        //明细
                        if(np.getValue() != null && np.getValue().size() > 0){
                            np.getValue().stream().forEach(d ->{
                                d.setIsChecked("0");
                                List<SettlebillTrade> settlebillTrade = settlebillTradeMapper.selectSettlebillTradeById(d.getPayid());
                                if(settlebillTrade!=null&&settlebillTrade.size()>0 ){
                                    for (SettlebillTrade settlebillTrade1:settlebillTrade) {
                                        if(settlebillTrade1.getSettleid().equals(settleBillVo.getSettleid())){
                                            d.setIsChecked("1");
                                            break;
                                        }
                                    }
                                }
                            });
                        }
                        */


                    });
                });
            });
        });

        Integer isCheckedSum = 0;
        for (TradeVo tradeVo : list1) {
            for (Paymentdetails paymentdetails : tradeVo.getPaymentdetailsList()) {
                isCheckedSum += Integer.valueOf(paymentdetails.getIsChecked());
            }

        }
        for (TradeVo li : list1) {
            for (Paymentdetails paymentdetails : li.getPaymentdetailsList()) {
                paymentdetails.setIsCheckedSum(isCheckedSum);
            }
        }

        return list1;
    }

    /**
     * 编辑结算单/查询结算单明细
     * @return
     */
    @Override
    public List<SettlebillPaydetailsVo> settleBillPayDetailsShow(SettlebillPaydetailsVo settleBillVo) {
        //查询结算单明细
        List<SettlebillPaydetailsVo> list=settlebillPaydetailsMapper.SettlebillPaydetailsList(settleBillVo);
        if(list==null ||list.size()<1){
            return list;
        }
//        //佣金金额、扣除金额、支付金额合计
//        BigDecimal sum1 = new BigDecimal(0);
//        BigDecimal sum2 = new BigDecimal(0);
//        BigDecimal sum3 = new BigDecimal(0);
//        BigDecimal sum4 = new BigDecimal(0);
//        for (SettlebillPaydetailsVo settlebillPaydetails:list) {
//            //佣金金额合计
//            if(settlebillPaydetails.getTotal()==null){
//                settlebillPaydetails.setTotal(BigDecimal.valueOf(0));
//            }
//            sum1 = settlebillPaydetails.getTotal().add(sum1);
//            //扣除金额合计
//            if(settlebillPaydetails.getTakeoff()==null){
//                settlebillPaydetails.setTakeoff(BigDecimal.valueOf(0));
//            }
////            if(settlebillPaydetails.getTakeoff() != null){
////                sum2 = settlebillPaydetails.getTakeoff().add(sum2);
////            }
//            sum2 = settlebillPaydetails.getTakeoff().add(sum2);
//            //支付金额
//            sum4 = settlebillPaydetails.getTotal().add(settlebillPaydetails.getTakeoff() != null
//                    ? settlebillPaydetails.getTakeoff(): new BigDecimal(0));
//            //支付金额合计
//            sum3 = sum4.add(sum3);
//            if(settlebillPaydetails.getBankname()==null || settlebillPaydetails.getBankno() == null){
//                settlebillPaydetails.setBankno("");
//                settlebillPaydetails.setBankname("");
//            }
//            if(settlebillPaydetails.getUser().equals("总计")){
//                settlebillPaydetails.setTotal(sum1);
//                settlebillPaydetails.setTakeoff(sum2);
//                settlebillPaydetails.setPay(sum3);
//            }
//            if (settlebillPaydetails.getUser().equals("结算总计")){
//                settlebillPaydetails.setTotal(null);
//                settlebillPaydetails.setTakeoff(null);
//                settlebillPaydetails.setPay(sum3);
//            }
//        }
//        for (SettlebillPaydetailsVo l : list) {
//            l.setSum1(sum1);
//            l.setSum2(sum2);
//            l.setSum3(sum3);
//            l.setSum4(sum4);
//        }

        list.forEach(l ->{
            if(l.getSettleStatus() != null && l.getSettleStatus() == SettleEnum.SettleBillStatus.STATUS_ZF.getCode().intValue()){
                l.setDisplayOrNo("0");
            }
        });
        return list;
    }

    /**
     * 新增/编辑结算单回显
     * @return
     */
    @Override
    public Map<String,Object> settleBillPayDetailsShow0(SettleBillVo settleBillVo) {
        //查看结算单中的核算单
        List<SettleBillVo> list=settlebillExaminebillMapper.settlebillDetails(settleBillVo);
      SettleBillVo settleBillVo1=settlebillExaminebillMapper.selectSettlebillByID(settleBillVo);
        List<SettleBillVo> settleBillVos=new ArrayList<>();
        for (SettleBillVo settleBillVo2:list) {
            if(settleBillVo2.getExamineid()!=null){
                SettleBillVo settleBillVo3 = new SettleBillVo();
                settleBillVo3.setIschecked(1L);
                settleBillVo2.setIschecked(1L);
                settleBillVo3.setExamineid(settleBillVo2.getExamineid());
                settleBillVos.add(settleBillVo3);
            }
        }
        Map<String, Object> map = new HashMap<>();
        map.put("examinebill", list);
            map.put("hxProjectId", settleBillVo1.getHxprojectid() == null ? "" : settleBillVo1.getHxprojectid());
            map.put("companyGuid", settleBillVo1.getCompanyguid() == null ? "" : settleBillVo1.getCompanyguid());
        return map;
    }

    /**
     * 查询结算单是否存在并添加
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult settlebillexits(SettleBillVo settleBillVo) {
        //生成结算单ID
        String Settleid = UUID.randomUUID().toString().replace("-", "");
        Settlebill settlebill= settlebillExaminebillMapper.selectSettlebillByName(settleBillVo);
        if (settlebill!=null){
            if(settleBillVo.getSettlename().equals(settlebill.getSettlename())){
                return AjaxResult.error("结算单名称已存在",settlebill.getSettleid() + "" + settlebill.getSettlename());
            }
        }
        settleBillVo.setSettleid(Settleid);
        // 从缓存中获取 审核人
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        //结算单创建时间
        settleBillVo.setCreatedate(new Date());
        //状态修改时间
        settleBillVo.setUpdatedate(new Date());
        //结算单制单人ID
        settleBillVo.setCreateid(csmSUser == null ? "" : csmSUser.getId());
        //结算单制单人
        settleBillVo.setCreate(csmSUser == null ? "" : csmSUser.getUsername());
        //结算单状态（草稿）
        settleBillVo.setStatus(SettleEnum.SettleBillStatus.STATUS_CG.getCode());
        settlebillMapper.insertSettlebill(settleBillVo);
        return AjaxResult.success("名称可以使用", Settleid);
    }

    /**
     * 新增结算单
     *
     * @param settleBillVo 结算单
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult insertSettlebill(SettleBillVo settleBillVo) {
        if(settleBillVo!=null) {
            List<ExamineBillVo> examineBillList = settleBillVo.getExamineBillList();
            if (examineBillList==null||examineBillList.size()<1){
                throw new CustomException("核算单不能为空",Constants.ERROR);
            }
            //结算单状态（草稿）
            settleBillVo.setStatus(SettleEnum.SettleBillStatus.STATUS_CG.getCode());
//            //流程状态（草稿）
//            settleBillVo.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_CG.getCode());
            //状态修改时间
            settleBillVo.setUpdatedate(new Date());

            // 根据项目ID去重(2021-06-02)
            ArrayList<ExamineBillVo> collect = examineBillList.stream().collect(
                    Collectors.collectingAndThen(
                            Collectors.toCollection(
                                    () -> new TreeSet<>(Comparator.comparing(examineBillVo -> examineBillVo.getHxProjectId()))
                            ), ArrayList::new
                    )
            );
            // 所选的核算单都是同一个项目,如果是相同项目才记录项目ID和项目名称,如果不同项目就把项目ID和名称置空(2021-06-02)
            // 所选的核算单都是同一个项目,如果是相同项目记录项目ID和项目名称,如果不同项目记录项目ID，把项目名称记录为 公司名称 + 项目两个字(2021-06-18)
            if (collect.size() == 1) {
                //项目ID
                settleBillVo.setHxprojectid(examineBillList.get(0).getHxProjectId());
                //项目名称
                settleBillVo.setHxprojectname(examineBillList.get(0).getHxProjectName());
            }else if (collect.size() > 1) {
                //项目ID
                settleBillVo.setHxprojectid(examineBillList.get(0).getHxProjectId());
                //项目名称
                settleBillVo.setHxprojectname(examineBillList.get(0).getCompanyName() + "项目");
            }

            //公司ID
            settleBillVo.setCompanyguid(examineBillList.get(0).getCompanyGuid());
            //公司名称
            settleBillVo.setCompanyname(examineBillList.get(0).getCompanyName());
            //添加结算单(修改)
            settlebillMapper.updateSettlebill(settleBillVo);
            //得到已选中核算单ID
            settlebillExaminebillMapper.deleteSettlebillExaminebillById(settleBillVo.getSettleid());

            List<SettlebillExaminebill> settlebillExaminebillList=new ArrayList<>();
            SettlebillExaminebill settlebillExaminebill;
            //添加结算单中核算单
            for (ExamineBillVo examineBillVo : examineBillList) {
                //添加结算单中核算单ID
                settlebillExaminebill = new SettlebillExaminebill();
                //添加结算单ID
                settlebillExaminebill.setSettleid(settleBillVo.getSettleid());
                //添加核算的ID
                settlebillExaminebill.setExamineid(examineBillVo.getExamineId());
                settlebillExaminebillList.add(settlebillExaminebill);
            }
            //待写入数据大于0
            if(settlebillExaminebillList.stream().count()>0){
                settlebillExaminebillMapper.insertSettlebillExaminebill(settlebillExaminebillList);
            }

        }
        return AjaxResult.success("结算单及结算单中核算单添加成功",null);
    }

    /**
     * 新增结算单中交易
     *
     * @param settleBillVo 结算单
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult  insertSettlebillTrade(List<SettleBillVo> settleBillVo) {
        if (settleBillVo!=null&&settleBillVo.size()>0){
            SettleBillVo settleBillVo2 = new SettleBillVo();
            settleBillVo2.setSettleid(settleBillVo.get(0).getSettleid());
            settleBillVo2.setStatus(PlanEnum.PaymentDetailsStatusDetail.STATUS_204.getCode());
            paymentdetailsMapper.updateSettleStatus(settleBillVo2);
            //A移动位置开始
            SettlebillTrade settlebillTrade0=new SettlebillTrade();
            //交易状态
            settlebillTrade0.setStatus(SettleEnum.TradeStatus.STATUS_N.getCode());
            //结算单ID
            settlebillTrade0.setSettleid(settleBillVo.get(0).getSettleid());
            //修改结算单交易
            settlebillTradeMapper.updateSettlebillTrade(settlebillTrade0);
            //A移动位置结束
            List<SettlebillPaydetails> settlebillPaydetailsArrayListNew = new ArrayList<>();
            List<String> payids = new ArrayList<>();
            for (SettleBillVo settleBillVo1:settleBillVo) {
                //判断交易条目是否为空
                if(settleBillVo1.getPayids() != null && settleBillVo1.getPayids().size() > 0 ) {
                    payids.addAll(settleBillVo1.getPayids());

                    settlebillTradeMapper.insertSettlebillTradeList(settleBillVo1.getPayids(),settleBillVo1.getSettleid());
                    /*
                    //原来A所在的位置
                    for (String payid:settleBillVo1.getPayids()) {
                        SettlebillTrade settlebillTrade=new SettlebillTrade();
                        //根据payid获得核算单的交易
                        SettleBillVo tradeVo=settlebillExaminebillMapper.selectexaminebilltradebypayid(payid);
                        //核算单ID
                        settlebillTrade.setExamineid(settleBillVo1.getExamineids().get(0));
                        //交易ID
                        settlebillTrade.setTradeguid(tradeVo.getTradeguid());
                        //添加结算单ID
                        settlebillTrade.setSettleid(settleBillVo1.getSettleid());
                        //添加佣金明细ID
                        settlebillTrade.setPayid(payid);
//                        //添加交易状态（有效）
//                        settlebillTrade.setStatus(SettleEnum.TradeStatus.STATUS_Y.getCode());
                        //交易状态
                        settlebillTrade.setStatus(SettleEnum.TradeStatus.STATUS_Y.getCode());
//                        if(settlebillTrade.getUpdatedate()!=null){
                        //原因
                        settlebillTrade.setUpdatereason("新保存");
//                        }
                        //添加状态变更时间
                        settlebillTrade.setUpdatedate(new Date());
                        settlebillTradeMapper.insertSettlebillTrade(settlebillTrade);

                        }
                    */

                        //修改小状态(草稿)
                        settleBillVo1.setStatus(PlanEnum.PaymentDetailsStatusDetail.STATUS_300.getCode());
                        settlebillMapper.PaymentDetailsupdateStatus(settleBillVo1);
                    }

            }
            //根据交易id查询明细
            List<Paymentdetails> paymentdetailsList = paymentdetailsMapper.selectPaymentdetailsByPayIds(payids);
            //判断同一个人相加的值没有小于0的
            if(paymentdetailsList != null && paymentdetailsList.size() > 0){
                Map<String,List<Paymentdetails>> userGroupMap = paymentdetailsList.stream().collect(Collectors.groupingBy(Paymentdetails::getUserid));
                List<SettlebillPaydetails> settlebillPaydetailsArrayList = new ArrayList<>();
                userGroupMap.keySet().forEach(k ->{
                    Paymentdetails kitem=  userGroupMap.get(k).stream().max(Comparator.comparing(Paymentdetails::getUpdatedate)).get();
                    SettlebillPaydetails settlebillPaydetails = new SettlebillPaydetails();
                    settlebillPaydetails.setUserid(kitem.getUserid());
                    settlebillPaydetails.setUser(kitem.getUser());
                    settlebillPaydetails.setJobname(kitem.getJobname());
                    settlebillPaydetails.setUsertypeid(kitem.getUsertypeid());
                    settlebillPaydetails.setUsertypename(kitem.getUsertypename());
                    settlebillPaydetails.setSettleid(settleBillVo.get(0).getSettleid());
                    //正数
                    BigDecimal positive = new BigDecimal(0);
                    //负数
                    BigDecimal negative = new BigDecimal(0);
                    for (Paymentdetails s : userGroupMap.get(k)) {
                        if(s.getPayable() != null){
                            if(s.getPayable().compareTo(new BigDecimal(0)) == 1){
                                positive = positive.add(s.getPayable());
                            }else{
                                negative =negative.add(s.getPayable());
                            }
                        }else{
                            if(s.getPaytotal().compareTo(new BigDecimal(0)) == 1){
                                positive =positive.add(s.getPaytotal());
                            }else{
                                negative = negative.add(s.getPaytotal());
                            }
                        }
                    }
                    settlebillPaydetails.setPay(positive);
                    settlebillPaydetails.setTakeoff(negative);
                    settlebillPaydetails.setTotal(positive.add(negative));
                    settlebillPaydetailsArrayList.add(settlebillPaydetails);
                });
                SettlebillPaydetails settlebillPaydetails1 = new SettlebillPaydetails();
                settlebillPaydetails1.setSettleid(settleBillVo.get(0).getSettleid());
                List<SettlebillPaydetails> settlebillPaydetails2 = settlebillPaydetailsMapper.selectSettlebillPaydetailsList(settlebillPaydetails1);
                settlebillPaydetailsArrayList.forEach(se ->{
                    for (SettlebillPaydetails s : settlebillPaydetails2) {
                        if(s.getSettleid().equals(se.getSettleid()) && s.getUserid().equals(se.getUserid()) && s.getUsertypeid().equals(se.getUsertypeid())){
                            se.setBankname(s.getBankname());
                            se.setBankno(s.getBankno());
                        }
                    }
                });
                settlebillPaydetailsArrayListNew.addAll(settlebillPaydetailsArrayList);
            }
            //删除交易明细
            settlebillPaydetailsMapper.deleteSettlebillPaydetailsById(settleBillVo.get(0).getSettleid());
            //添加结算单明细
            settlebillPaydetailsMapper.insertSettlebillPaydetailsList(settlebillPaydetailsArrayListNew);
        }
            return AjaxResult.success("交易条目添加成功",null);
    }

    /**
     * 新增结算单中明细
     *
     * @param settleBill 结算单
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult insertSettlebillPayDetails(SettleBillVo settleBill) {
        //根据核算单id查核算单流程表根据时间倒叙，拿最新的Businesskey
        List<SettlebillThirdbill> settlebillThirdbills1 = settlebillThirdbillMapper.selectSettlebillThirdbillBysettleBillId(settleBill.getSettleBillVo().get(0).getSettleid());

       if(settlebillThirdbills1 == null || settlebillThirdbills1.size() <= 0){

       }else{
//           if(settlebillThirdbills1.get(0).getFlowstatus().longValue() == SettleEnum.ThirdStatus.STATUS_D.getCode().longValue()){
//               throw new CustomException("已经提交过了，不能再次提交",Constants.ERROR);
//           }
           if(settlebillThirdbills1.get(0).getBusinesskey() != null){
               settleBill.setBusinesskey(settlebillThirdbills1.get(0).getBusinesskey());
           }
       }
        CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
        List<SettlebillPaydetailsVo> settleBillVo = settleBill.getSettleBillVo();
        if (settleBillVo!=null&&settleBillVo.size()>0){
            Settlebill settlebill1=new Settlebill();
                //修改结算单状态
                settlebill1.setSettleid(settleBillVo.get(0).getSettleid());
                settlebill1.setFlowstatus(SettleEnum.ThirdStatus.STATUS_D.getCode());
                settlebill1.setStatus(settleBill.getStatus());
                settlebill1.setUpdatedate(new Date());
                settlebillMapper.updateSettlebillStatus(settlebill1);
                settlebillMapper.updateSettlebillFlowStatus(settlebill1);
                //修改详情表状态
                paymentdetailsMapper.updateStatusBySettleId(settleBillVo.get(0).getSettleid(), settleBill.getStatus());
                //修改结算明细（添加银行卡、银行卡号）
            SettlebillPaydetails settlebillPaydetails1 = new SettlebillPaydetails();
            settlebillPaydetails1.setSettleid(settleBillVo.get(0).getSettleid());
            List<SettlebillPaydetails> settlebillPaydetails = settlebillPaydetailsMapper.selectSettlebillPaydetailsList(settlebillPaydetails1);
            for (SettlebillPaydetails paydetails:settlebillPaydetails) {
                for (SettlebillPaydetailsVo settlebillPaydetailsVo: settleBillVo) {
                    if ("结算总计".equals(settlebillPaydetailsVo.getUser()) || "总计".equals(settlebillPaydetailsVo.getUser())){
                        continue;
                    }
                    if (paydetails.getUserid().equals(settlebillPaydetailsVo.getUserid()) && paydetails.getUser().equals(settlebillPaydetailsVo.getUser())) {
                        paydetails.setBankno(settlebillPaydetailsVo.getBankno());
                        paydetails.setBankname(settlebillPaydetailsVo.getBankname());
                        settlebillPaydetailsMapper.updateSettlebillPaydetails((SettlebillPaydetailsVo) paydetails);
                        break;
                    }
                }
            }
        }
        SettlebillThirdbill settlebillThirdbill=new SettlebillThirdbill();
        if(settleBill.getBusinesskey()!=null){
            //根据工作流程参数查询
            List<SettlebillThirdbill> settlebillThirdbills = settlebillThirdbillMapper.selectSettlebillThirdbillBybusinesskey(settleBill.getBusinesskey());
            settlebillThirdbill.setFlowstatus(settlebillThirdbills.get(0).getFlowstatus());
        }
        //如果工作流程参数不存在
        if(settleBill.getBusinesskey()==null || settleBill.getBusinesskey().equals("")){
            //生成工作流程参数
            String businesskey=UUID.randomUUID().toString();
            //如果是提交（待审核状态）,则存入工作流程参数
            if(settleBill.getStatus().equals(PlanEnum.PaymentDetailsStatusDetail.STATUS_DSH.getCode())){
                settlebillThirdbill.setBusinesskey(businesskey);
            }
            //结算单ID
            settlebillThirdbill.setSettleid(settleBillVo.get(0).getSettleid());
            //人力共享流程编号
            settlebillThirdbill.setThirdno(settleBill.getThirdNO());
            //创建人ID
            settlebillThirdbill.setCreateid(csmSUser == null ? "" : csmSUser.getId());
            //创建时间
            settlebillThirdbill.setCreatedate(new Date());
            //审批通过时间
            settlebillThirdbill.setApprovaldate(settleBill.getApprovalDate());
            //创建人
            settlebillThirdbill.setCreate(csmSUser == null ? "" : csmSUser.getUsername());
            //流程状态（待审核）
            settlebillThirdbill.setFlowstatus(SettleEnum.ThirdStatus.STATUS_D.getCode());
            Settlebill settlebill1=new Settlebill();
            settlebill1.setStatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
            settlebill1.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
            settlebill1.setUpdatedate(new Date());
            settlebillMapper.updateSettlebillStatus(settlebill1);
            settlebillMapper.updateSettlebillFlowStatus(settlebill1);
            //流程状态变更时间
            settlebillThirdbill.setFlowupdatedate(new Date());
            //添加结算单审核单据
            settlebillThirdbillMapper.insertSettlebillThirdbill(settlebillThirdbill);
        }else {
            if (settlebillThirdbill.getFlowstatus()==null){
                throw new CustomException("状态不能为空",Constants.ERROR);
            }
            //工作流程参数
            settlebillThirdbill.setBusinesskey(settleBill.getBusinesskey());
            //如果审核通过
            if(settlebillThirdbill.getFlowstatus().equals(SettleEnum.ThirdStatus.STATUS_Y.getCode())){
                settlebillThirdbillMapper.deleteSettlebillThirdbillById(settleBillVo.get(0).getSettleid());
                //结算单ID
                settlebillThirdbill.setSettleid(settleBillVo.get(0).getSettleid());
                //人力共享流程编号
                settlebillThirdbill.setThirdno(settleBill.getThirdNO());
                //创建人ID
                settlebillThirdbill.setCreateid(csmSUser == null ? "" : csmSUser.getId());
                //创建时间
                if (settlebillThirdbill.getFlowupdatedate()==null){
                    settlebillThirdbill.setCreatedate(new Date());
                }
                //创建人
                settlebillThirdbill.setCreate(csmSUser == null ? "" : csmSUser.getUsername());
                //修改结算单审核单据流程状态为通过
                settlebillThirdbill.setFlowstatus(SettleEnum.ThirdStatus.STATUS_Y.getCode());
                //审批通过时间
                settlebillThirdbill.setApprovaldate(new Date());
                //流程状态变更时间
                settlebillThirdbill.setFlowupdatedate(new Date());
                //修改结算单流程状态为通过
                settleBill.setSettleid(settleBillVo.get(0).getSettleid());
                settleBill.setUpdatedate(new Date());
                settleBill.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_PASS.getCode());
                //修改结算单状态为通过
                settleBill.setStatus(SettleEnum.SettleBillStatus.STATUS_PASS.getCode());
                settlebillMapper.updateSettlebillStatus(settleBill);
                settlebillMapper.updateSettlebillFlowStatus(settleBill);
                //明细表状态修改（结算单通过）
                paymentdetailsMapper.updateStatusBySettleId(settleBillVo.get(0).getSettleid(), PlanEnum.PaymentDetailsStatusDetail.STATUS_PASS.getCode());
                settlebillThirdbillMapper.insertSettlebillThirdbill(settlebillThirdbill);
                //如果审核终止或撤回
            }else if (settlebillThirdbill.getFlowstatus().equals(SettleEnum.ThirdStatus.STATUS_Z.getCode())
                    || settlebillThirdbill.getFlowstatus().equals(SettleEnum.ThirdStatus.STATUS_C.getCode())){
                //删除原结算单相关的表
//                settlebillExaminebillMapper.deleteSettlebillExaminebillById(settleBillVo.get(0).getSettleid());
//                settlebillTradeMapper.deleteSettlebillTradeById(settleBillVo.get(0).getSettleid());
//                settlebillPaydetailsMapper.deleteSettlebillPaydetailsById(settleBillVo.get(0).getSettleid());
                //修改结算单流程状态为驳回
                settleBill.setSettleid(settleBillVo.get(0).getSettleid());
                settleBill.setUpdatedate(new Date());
//                settlebillThirdbill.setFlowstatus(SettleEnum.ThirdStatus.STATUS_N.getCode());
                settlebillThirdbill.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
//                settleBill.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_BH.getCode());
                settleBill.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
                settleBill.setStatus(SettleEnum.SettleBillStatus.STATUS_BH.getCode());
                settlebillMapper.updateSettlebillFlowStatus(settleBill);
                settlebillMapper.updateSettlebillStatus(settleBill);
                //明细表状态还原(核算通过)
//                paymentdetailsMapper.updateStatusBySettleId(settleBillVo.get(0).getSettleid(), PlanEnum.PaymentDetailsStatusDetail.STATUS_204.getCode());
//                settlebillThirdbillMapper.deleteSettlebillThirdbillById(settleBillVo.get(0).getSettleid());
//                //重新生成结算单ID
//                String Settleid = UUID.randomUUID().toString().replace("-", "");
//                //添加新的结算单审核单据
//                settlebillThirdbill.setSettleid(Settleid);
//                //工作流程参数
//                settlebillThirdbill.setBusinesskey(settleBill.getBusinesskey());
                //重新生成工作流程参数
                String businesskey=UUID.randomUUID().toString();
                //添加新的工作流程参数
                settlebillThirdbill.setBusinesskey(businesskey);
                settlebillThirdbill.setSettleid(settleBillVo.get(0).getSettleid());
                settlebillThirdbill.setCreateid(csmSUser == null ? "" : csmSUser.getId());
                settlebillThirdbill.setCreate(csmSUser == null ? "" : csmSUser.getUsername());
                if (settlebillThirdbill.getFlowupdatedate()==null){
                    settlebillThirdbill.setCreatedate(new Date());
                }
                settlebillThirdbill.setFlowstatus(SettleEnum.ThirdStatus.STATUS_N.getCode());
                //流程状态变更时间
                settlebillThirdbill.setFlowupdatedate(new Date());
                settlebillThirdbillMapper.insertSettlebillThirdbill(settlebillThirdbill);
                //如果审核驳回
            }else if (settlebillThirdbill.getFlowstatus().equals(SettleEnum.ThirdStatus.STATUS_N.getCode())){
                //工作流程参数
                settlebillThirdbill.setBusinesskey(settleBill.getBusinesskey());
                //修改结算单流程状态为撤回
                settleBill.setSettleid(settleBillVo.get(0).getSettleid());
                settleBill.setUpdatedate(new Date());
//                settlebillThirdbill.setFlowstatus(SettleEnum.ThirdStatus.STATUS_D.getCode());
//                settlebillThirdbill.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
                settlebillThirdbill.setStatus(SettleEnum.SettleBillStatus.STATUS_BH.getCode());
//                settlebillThirdbill.setStatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
                //流程状态变更时间
                settlebillThirdbill.setFlowupdatedate(settleBill.getUpdatedate());
                settlebillMapper.updateSettlebillFlowStatus(settleBill);
                settlebillMapper.updateSettlebillStatus(settleBill);
                //明细表状态修改（结算单撤回）
                paymentdetailsMapper.updateStatusBySettleId(settleBillVo.get(0).getSettleid(), PlanEnum.PaymentDetailsStatusDetail.STATUS_CH.getCode());
//                settlebillThirdbillMapper.insertSettlebillThirdbill(settlebillThirdbill);
//                settlebillThirdbillMapper.updateSettlebillThirdbill(settlebillThirdbill);
            }
        }
//        if(settleBill.getStatus().equals(PlanEnum.PaymentDetailsStatusDetail.STATUS_300.getCode())){
//            return new AjaxResult(200, "结算单草稿已保存", redirectUrl);
//        }

        return new AjaxResult(200, "结算单审核单据(审核中)", redirectUrl + settlebillThirdbill.getBusinesskey());
    }

    /**
     * 修改结算单单据状态
     *
     * @param settlebill 结算单
     * @return 结果
     */
    @Override
    public int updateSettlebillStatus(Settlebill settlebill) {
            return settlebillMapper.updateSettlebillStatus(settlebill);
            }

    /**
     * 修改结算单流程状态
     *
     * @param settlebill 结算单
     * @return 结果
     */
    @Override
    public int updateSettlebillFlowStatus(Settlebill settlebill) {
            return settlebillMapper.updateSettlebillFlowStatus(settlebill);
            }

    /**
     * 修改结算单
     *
     * @param settleBillVo 结算单
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateSettlebill(SettleBillVo settleBillVo) {
            CsmSUser csmSUser = csmSUserService.selectCsmSUserByUserName();
            //通过ID查结算单
            Settlebill settlebil=settlebillMapper.selectSettlebillById(settleBillVo.getSettleid());
            List<String> examineids=new ArrayList();
            //结算单中核算单
            List<SettleBillVo> examinebilllist=settlebillExaminebillMapper.settleBillPayDetailsShow(settleBillVo);
            SettlebillExaminebill settlebillExaminebill=new SettlebillExaminebill();
            settlebillExaminebill.setSettleid(settleBillVo.getSettleid());
            //选择交易条目-结算单人员结算明细(佣金列表)
            List<SettleBillVo> tradelist=settlebillExaminebillMapper.settlebillTradeShow(settleBillVo);
            SettlebillTrade settlebillTrade=new SettlebillTrade();
            settlebillTrade.setSettleid(settleBillVo.getSettleid());
            //结算单人员结算明细
            SettlebillPaydetails settlebillPaydetails= settlebillPaydetailsMapper.selectSettlebillPaydetailsById(settleBillVo.getSettleid());
            for (SettleBillVo settleBillVo1:tradelist) {
                //如果是草稿或驳回状态，则可以修改
                if(settlebil.getFlowstatus().equals(SettleEnum.SettleBillStatus.STATUS_CG.getCode()) || settlebil.getFlowstatus().equals(SettleEnum.SettleBillStatus.STATUS_BH.getCode())){
                    //如果是制单人本人，则可以修改
                    if(settlebil.getCreateid().equals(settleBillVo1.getCreateid())){
                        //修改佣金明细ID
                        if (settlebillTrade.getStatus()!=null){
                            settlebillTrade.setPayid(settleBillVo1.getPayID());
                        }
                        //修改结算单佣金ID
                        settlebillTradeMapper.updateSettlebillTrade(settlebillTrade);
                        //修改算单人员结算明细
                        for (SettleBillVo settleBillVo2:examinebilllist) {
                            examineids.add(settleBillVo2.getExamineid());
                        }
                        for (String exaineid:examineids) {
                            settlebillExaminebill.setExamineid(exaineid);
                            //修改结算中核算单
                            settlebillExaminebillMapper.updateSettlebillExaminebill(settlebillExaminebill);
                        }
                        int  s=settlebillMapper.updateSettlebill(settleBillVo);
                        return  s;
                    }
                }
            }
                return 0;
    }

    /**
     * 删除结算单(删除)
     *
     * @param settleid 需要删除的结算单中的核算单ID
     * @return 结果
     */
    @Override
    public AjaxResult deleteSettlebill2(String settleid) {
        //根据ID查询对应结算单
        Settlebill settlebill=settlebillMapper.selectSettlebillById(settleid);
        //如果是作废状态则可以删除
        if (settlebill.getStatus().equals(SettleEnum.SettleBillStatus.STATUS_ZF.getCode())){
            //结算单状态-已删除
            settlebill.setStatus(SettleEnum.SettleBillStatus.STATUS_DEL.getCode());
            settlebill.setUpdatedate(new Date());
            //修改结算单状态
            settlebillMapper.updateSettlebillStatus(settlebill);
            return AjaxResult.success("已删除",settlebill);
        }
        return AjaxResult.success("已删除",settlebill);
    }

    /**
     * 删除结算单(作废)
     *
     * @param settleid 需要删除的结算单中的核算单ID
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult deleteSettlebill(String settleid){
        //根据ID查询对应结算单
        Settlebill settlebill=settlebillMapper.selectSettlebillById(settleid);
        //如果是草稿或驳回则可以作废
        if (settlebill.getStatus().equals(SettleEnum.SettleBillStatus.STATUS_CG.getCode())||settlebill.getStatus().equals(SettleEnum.SettleBillStatus.STATUS_BH.getCode())){
            //还原详情表状态
            paymentdetailsMapper.updateStatusBySettleId(settleid,PlanEnum.PaymentDetailsStatusDetail.STATUS_204.getCode());
            //删除结算单人员结算明细
            settlebillPaydetailsMapper.deleteSettlebillPaydetailsById(settleid);
            //删除结算单交易佣金列表
            settlebillTradeMapper.deleteSettlebillTradeById(settleid);
            //删除结算单中核算单
            settlebillExaminebillMapper.deleteSettlebillExaminebillById(settleid);
            //结算单状态-作废
            settlebill.setStatus(SettleEnum.SettleBillStatus.STATUS_ZF.getCode());
            settlebill.setFlowstatus(SettleEnum.SettleBillStatus.STATUS_ZF.getCode());
            settlebill.setUpdatedate(new Date());
            //修改结算单状态
             settlebillMapper.updateSettlebillStatus(settlebill);
             settlebillMapper.updateSettlebillFlowStatus(settlebill);
             return AjaxResult.success("作废",settlebill);
        }
        return AjaxResult.success("作废",settlebill);
    }

    /**
     * 结算单审核页面--工作流
     *
     * @param businesskey
     * @return
     */
    @Override
    public Map<String, Object> approvalShow(String businesskey) {
        Map<String, Object> map = new HashMap<>();
        List<SettlebillPaydetails> settlebillPaydetails = settlebillPaydetailsMapper.approvalShow(businesskey);
        if(settlebillPaydetails == null || settlebillPaydetails.size() <= 0){
            return map;
        }
        for (int i = 0; i < settlebillPaydetails.size(); i++) {
            if(settlebillPaydetails.get(i) == null){
                settlebillPaydetails.remove(i);
                i--;
            }
        }
        settlebillPaydetails.forEach(s ->{
            if(s.getNationalId() == null){
                s.setNationalId("");
            }
            if(s.getDataStatus() == null){
                s.setDataStatus("");
            }
        });
        map.put("thirdno", settlebillPaydetails.get(0).getThirdno() == null ? "" : settlebillPaydetails.get(0).getThirdno());
        map.put("settlename", settlebillPaydetails.get(0).getSettlename() == null ? "" : settlebillPaydetails.get(0).getSettlename());
        map.put("companyName", settlebillPaydetails.get(0).getCompanyName() == null ? "" : settlebillPaydetails.get(0).getCompanyName());
        map.put("hxProjectName", settlebillPaydetails.get(0).getHxProjectName() == null ? "" : settlebillPaydetails.get(0).getHxProjectName());
        map.put("createName", settlebillPaydetails.get(0).getCreateName() == null ? "" : settlebillPaydetails.get(0).getCreateName());
        map.put("createDate", settlebillPaydetails.get(0).getCreateDate() == null ? "" : settlebillPaydetails.get(0).getCreateDate());
        map.put("companyGuid", settlebillPaydetails.get(0).getCompanyGuid() == null ? "" : settlebillPaydetails.get(0).getCompanyGuid());
        map.put("hxProjectId", settlebillPaydetails.get(0).getHxProjectId() == null ? "" : settlebillPaydetails.get(0).getHxProjectId());
        map.put("status", settlebillPaydetails.get(0).getStatus() == null ? "" : settlebillPaydetails.get(0).getStatus());
        map.put("list", settlebillPaydetails);
        return map;
    }

    /**
     * 修改结算单和审核单据
     *
     * @param settlebillThirdbill
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public AjaxResult updateThirdAndSettle(SettlebillThirdbill settlebillThirdbill) {
        if(settlebillThirdbill.getBusinesskey() == null || settlebillThirdbill.getBusinesskey().equals("")){
            return AjaxResult.error(500, "businesskey不能为空");
        }
        if(settlebillThirdbill.getFlowstatusChinese() != null && !settlebillThirdbill.getFlowstatusChinese().equals("")){
            if(settlebillThirdbill.getFlowstatusChinese().equals("待审核")){
                settlebillThirdbill.setFlowstatus(2L);
            }
            if(settlebillThirdbill.getFlowstatusChinese().equals("终止")){
                settlebillThirdbill.setFlowstatus(-1L);
            }
            if(settlebillThirdbill.getFlowstatusChinese().equals("已审核")){
                settlebillThirdbill.setFlowstatus(1L);
            }
            if(settlebillThirdbill.getFlowstatusChinese().equals("审批中")){
                settlebillThirdbill.setFlowstatus(3L);
            }
            if(settlebillThirdbill.getFlowstatusChinese().equals("撤回")){
                settlebillThirdbill.setFlowstatus(-2L);
            }
            if(settlebillThirdbill.getFlowstatusChinese().equals("驳回")){
                settlebillThirdbill.setFlowstatus(0L);
            }
        }

        if(settlebillThirdbill.getThirdstatusChinese() != null && !settlebillThirdbill.getThirdstatusChinese().equals("")){
            if(settlebillThirdbill.getThirdstatusChinese().equals("V")){
                settlebillThirdbill.setThirdstatus(601L);
            }
            if(settlebillThirdbill.getThirdstatusChinese().equals("S")){
                settlebillThirdbill.setThirdstatus(602L);
            }
            if(settlebillThirdbill.getThirdstatusChinese().equals("I")){
                settlebillThirdbill.setThirdstatus(603L);
            }
            if(settlebillThirdbill.getThirdstatusChinese().equals("A")){
                settlebillThirdbill.setThirdstatus(604L);
            }
            if(settlebillThirdbill.getThirdstatusChinese().equals("D")){
                settlebillThirdbill.setThirdstatus(605L);
            }
        }
        if(settlebillThirdbill.getThirdstatus() != null){
            settlebillThirdbill.setThirdupdatedate(new Date());
        }
        if(settlebillThirdbill.getThirdno() != null && !settlebillThirdbill.getThirdno().equals("")){
            Settlebill settlebill = settlebillMapper.selectSettlebillByThirdno(settlebillThirdbill.getThirdno());
            if(settlebill != null){
                return AjaxResult.error("人力共享编号已存在");
            }
        }
        settlebillThirdbill.setUpdatedate(new Date());
        if(settlebillThirdbill.getThirdstatus() != null){
            if(settlebillThirdbill.getThirdstatus().longValue() == SettleEnum.ThirdStatusLong.STATUS_N.getCode().longValue()){
                settlebillThirdbill.setApprovaldate(new Date());
            }
        }

        int i = settlebillThirdbillMapper.updateSettlebillThirdbill(settlebillThirdbill);
        if(settlebillThirdbill.getFlowstatus() != null){
            if(settlebillThirdbill.getFlowstatus() <= 0L){
                settlebillThirdbill.setStatus(SettleEnum.SettleBillStatus.STATUS_CH.getCode());
                //修正---业务可编辑
                SettlebillThirdbill settlebillThirdbill1 = new SettlebillThirdbill();
                settlebillThirdbill1.setBusinesskey(settlebillThirdbill.getBusinesskey());
                settlebillThirdbill1.setStatus(PlanEnum.PaymentDetailsStatusDetail.STATUS_204.getCode());
                paymentdetailsMapper.updatePaymentdetailsByBusinesskey(settlebillThirdbill1);
                //修正结束

            }else if(settlebillThirdbill.getFlowstatus().equals(SettleEnum.ThirdStatus.STATUS_Y.getCode())){
                settlebillThirdbill.setStatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
            }else if(settlebillThirdbill.getFlowstatus().longValue() == SettleEnum.ThirdStatus.STATUS_D.getCode().longValue()){
                settlebillThirdbill.setStatus(SettleEnum.SettleBillStatus.STATUS_DSH.getCode());
            }
        }else if(settlebillThirdbill.getThirdstatus() != null){
            if(settlebillThirdbill.getThirdstatus().longValue() == SettleEnum.ThirdStatusLong.STATUS_N.getCode().longValue()){
                settlebillThirdbill.setStatus(SettleEnum.SettleBillStatus.STATUS_PASS.getCode());
               SettlebillThirdbill settlebillThirdbill1 = new SettlebillThirdbill();
                settlebillThirdbill1.setBusinesskey(settlebillThirdbill.getBusinesskey());
                settlebillThirdbill1.setStatus(PlanEnum.PaymentDetailsStatusDetail.STATUS_301.getCode());
                paymentdetailsMapper.updatePaymentdetailsByBusinesskey(settlebillThirdbill1);
            }
        }


        int i1 = settlebillMapper.updateThirdAndSettle(settlebillThirdbill);
        return AjaxResult.success("修改成功");
    }

    /**
     * 删除结算单中的核算单
     *
     * @param settleBillVo
     * @return
     */
    @Override
    public AjaxResult deleteEmail(SettleBillVo settleBillVo) {
        if(settleBillVo.getSettleid()  == null || settleBillVo.getSettleid().equals("")){
            AjaxResult.error("结算单id不能为空");
        }
        if(settleBillVo.getExamineid()  == null || settleBillVo.getExamineid().equals("")){
            AjaxResult.error("核算单id不能为空");
        }
        settlebillMapper.deleteEmail(settleBillVo);
        settleBillVo.setStatus(PlanEnum.PaymentDetailsStatusDetail.STATUS_204.getCode());
        paymentdetailsMapper.updateSettleStatus(settleBillVo);
        return AjaxResult.success("删除成功");
    }
}
