package com.huaxia.hx_sell_commission.utils;

import java.awt.Image;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.imageio.ImageIO;

import cn.hutool.core.lang.UUID;
import cn.hutool.core.util.IdUtil;
import net.coobird.thumbnailator.Thumbnails;
import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.web.multipart.MultipartFile;

/**
 * 图片处理工具类
 * @author jfxie
 * @date 2018年12月27日 下午4:40:52
 * @version 1.0
 */
public class ThumbnailatorUtil {
    /**
     * 日志
     */
    private static final Log log = LogFactory.getLog(ThumbnailatorUtil.class);

    private static final long WX_SIZE = 131072;

    /**
     * 将文件sourceFile重命名为path，如果path已存在，则删除
     * @param sourceFile
     * @param path
     */
    public static void renameTo(File sourceFile, String path) {
        File check = new File(path);
        if (check.exists()) {
            check.delete();
        }
        sourceFile.renameTo(check);
    }

    /**
     * 删除文件列表
     * @param files
     */
    public static void delete(List<File> files) {
        for (File temp : files) {
            temp.delete();
        }
    }

    /**
     * 将sourceFile压缩至128k以下，并保存为新文件
     * @param sourceFile 已存在的文件
     * @param path 新文件完整路径(不能是已存在的文件，否则renameTo会失效)
     */
    public static void compressUploadFile(File sourceFile, String path) {
        renameTo(sourceFile, path);
        return;
    }
    
    public static void compressUploadFile(File sourceFile, String path, boolean check) {
        if (!check) {
            renameTo(sourceFile, path);
            return;
        }
        // 如果源文件小于128k，则直接将源文件更名为目标文件
        /*if (sourceFile.length() < WX_SIZE) {
            renameTo(sourceFile, path);
            return;
        }*/
        // 临时文件列表
        List<File> listTemp = new ArrayList<File>();
        // 临时中间文件
        File temp;
        // 目标文件
        File target = new File(path);
        do {
            // /opt/wx/userfiles/项目id/UUID+UUID文件名
            temp = new File(target.getParent(), IdUtil.simpleUUID() + target.getName());
            Image img;
            try {
                //读取为图片对象
                img = ImageIO.read(sourceFile);
                //读取尺寸
                int width = img.getWidth(null);
                int height = img.getHeight(null);
                //压缩尺寸
                if (sourceFile.length() < WX_SIZE) {
                    //不压缩图片 依然有（Y）
                }else if (width > 14000 || height > 14000) {
                    width = width / 12;
                    height = height / 12;
                } else if (width > 8000 || height > 8000) {
                    width = width / 7;
                    height = height / 7;
                } else if (width > 7000 || height > 7000) {
                    width = width / 6;
                    height = height / 6;
                } else if (width > 6000 || height > 6000) {
                    width = width / 5;
                    height = height / 5;
                } else if (width > 5000 || height > 5000) {
                    width = width / 4;
                    height = height / 4;
                } else if (width > 4000 || height > 4000) {
                    width = width / 3;
                    height = height / 3;
                } else {
                    width = width / 2;
                    height = height / 2;
                }
                Thumbnails.of(sourceFile).size(width, height).keepAspectRatio(false).allowOverwrite(true).toFile(temp);
            } catch (IOException e) {
                log.error(e.getMessage(), e);
            }
            if (temp.length() < WX_SIZE) {
                listTemp.add(temp);
                renameTo(temp, path);
                break;
            }
            listTemp.add(temp);
            sourceFile = temp;
        } while (true);
        // 删除临时文件列表
        delete(listTemp);
    }


    /**
     *
     * @Description:保存图片并且生成缩略图
     * @param imageFile 图片文件
     * @param request 请求对象
     * @param uploadPath 上传目录
     * @return
     */
    /**
     * @author  jcli
     * @create  2020/11/17 0017 9:57
     * 入参说明：
     * imageFile 文件对象
     * opt 文件上传的最终保存服务器路径  /opt/wx/userfiles/项目ID/
     * optOldFileName  原文件加新文件名全路径 /opt/wx/userfiles/项目id/UUID(y).jpg
     * optUuidFileType  缩略图全路径  /opt/wx/userfiles/项目id/UUID.jpg
     * @desc
     **/
    public static Map<String,String> uploadFileAndCreateThumbnail(
            MultipartFile imageFile,
            String optOldFileName,
            String optUuidFileType
    ) throws Exception {
        if(imageFile == null ){
            throw new Exception("imageFile不能为空");
        }
        if (imageFile.getSize() >= 100*1024*1024) {
            throw new Exception( "文件不能大于100M");
        }
        String uuid = IdUtil.simpleUUID();
        //构建保存文件路劲
        //修改上传路径为服务器上
        //String realPath = request.getServletContext().getRealPath("uploadPath");
        //获取服务器绝对路径 linux 服务器地址  获取当前使用的配置文件配置
        //String urlString=PropertiesUtil.getInstance().getSysPro("uploadPath");
        //拼接文件路劲
        // /opt/wx/userfiles/项目ID/uuid.jpg
        String filePathName = optOldFileName;
        //判断文件保存是否存在
        File file = new File(filePathName);
        if (file.getParentFile() != null || !file.getParentFile().isDirectory()) {
            //创建文件
            file.getParentFile().mkdirs();
        }
        InputStream inputStream = null;
        FileOutputStream fileOutputStream = null;
        try {
            inputStream = imageFile.getInputStream();
            fileOutputStream = new FileOutputStream(file);
            //写出文件
            //2016-05-12 yangkang 改为增加缓存
            //IOUtils.copy(inputStream, fileOutputStream);
            byte[] buffer = new byte[2048];
            IOUtils.copyLarge(inputStream, fileOutputStream, buffer);
            buffer = null;
        } catch (IOException e) {
            filePathName = null;
            throw new Exception("操作失败！");
        } finally {
            try {
                if (inputStream != null) {
                    inputStream.close();
                }
                if (fileOutputStream != null) {
                    fileOutputStream.flush();
                    fileOutputStream.close();
                }
            } catch (IOException e) {
                filePathName = null;
                throw new Exception("关闭流异常！");
            }
        }

        //        String fileId = FastDFSClient.uploadFile(file, filePathName);
        /**
         * 缩略图begin
         */
        //拼接后台文件名称
        String thumbnailPathName = optUuidFileType;
        //added by yangkang 2016-3-30 去掉后缀中包含的.png字符串
        if(optUuidFileType.contains(".png")){
            optUuidFileType = optUuidFileType.replace(".png", ".jpg");
        }
        long size = imageFile.getSize();
        double scale = 1.0d ;
        //128000 = 125KB
        if(size >= 128000){
                scale = (128000) / size  ;//例如size是125KB两倍 scale = 0.5 outputQuality压缩为原来0.5
        }
        try {
            //added by chenshun 2016-3-22 注释掉之前长宽的方式，改用大小
//            Thumbnails.of(filePathName).size(width, height).toFile(thumbnailFilePathName);
            //128000 = 125KB
            if(size < 128000){
                Thumbnails.of(filePathName).scale(1f).outputFormat("jpg").toFile(optUuidFileType);
            }else{
                System.out.println(scale);
                //Thumbnails.of(filePathName).scale(1f).outputQuality(scale).outputFormat("jpg").toFile(thumbnailFilePathName);
                Thumbnails.of(filePathName).size(500,500).toFile(optUuidFileType);
            }
        } catch (Exception e1) {
            throw new Exception("压缩异常！");
        }
        /**
         * 缩略图end
         */

        Map<String, String> map = new HashMap<>();
        //原图地址
        map.put("originalUrl", filePathName);
        //缩略图地址
        map.put("thumbnailUrl", thumbnailPathName);
        return map;
    }


    public static void main(String[] args) {
        // File file = new File("C:\\Users\\lenovo\\Desktop\\cc.jpg");
        // System.out.println(file.length()/1024.0/1024.0);

        // System.out.println(128 * 1024);
        /* File file = new File("C:\\Users\\lenovo\\Desktop\\cc.jpg");
        compressUploadFile(file, "C:\\Users\\lenovo\\Desktop\\ccs.jpg");*/

        // File temp = new File(target.getParent(), System.currentTimeMillis() +
        // target.getName());



    }
}
